@@ -1,24 +1,22 @@
 <?php
-/**
- * Copyright (c) 2010 Fabian Graßl
+
+/*
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
- * Permission is hereby granted, free of charge, to any person obtaining a copy
- * of this software and associated documentation files (the "Software"), to deal
- * in the Software without restriction, including without limitation the rights
- * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
- * copies of the Software, and to permit persons to whom the Software is furnished
- * to do so, subject to the following conditions:
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
- * The above copyright notice and this permission notice shall be included in all
- * copies or substantial portions of the Software.
+ * https://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * For more information : contact@centreon.com
  *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
- * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
- * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
- * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
- * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
- * THE SOFTWARE.
  */
 
 /**
@@ -31,9 +29,12 @@
 class Slug implements ArrayAccess
 {
     protected $original = null;
+
     protected $slug = null;
+
     protected $options = ['to_lower'        => true, 'max_length'      => null, 'prefix'          => null, 'postfix'         => null, 'seperator_char'  => '-'];
-    protected $char_map = ['Š'=>'S', 'š'=>'s', 'Ð'=>'Dj', 'Ž'=>'Z', 'ž'=>'z', 'À'=>'A', 'Á'=>'A', 'Â'=>'A', 'Ã'=>'A', 'Ä'=>'Ae', 'Å'=>'A', 'Æ'=>'A', 'Ç'=>'C', 'È'=>'E', 'É'=>'E', 'Ê'=>'E', 'Ë'=>'E', 'Ì'=>'I', 'Í'=>'I', 'Î'=>'I', 'Ï'=>'I', 'Ñ'=>'N', 'Ò'=>'O', 'Ó'=>'O', 'Ô'=>'O', 'Õ'=>'O', 'Ö'=>'Oe', 'Ø'=>'O', 'Ü'=>'Ue', 'Ù'=>'U', 'Ú'=>'U', 'Û'=>'U', 'Ý'=>'Y', 'Þ'=>'B', 'ß'=>'ss', 'à'=>'a', 'á'=>'a', 'â'=>'a', 'ã'=>'a', 'ä'=>'ae', 'å'=>'a', 'æ'=>'a', 'ç'=>'c', 'è'=>'e', 'é'=>'e', 'ê'=>'e', 'ë'=>'e', 'ì'=>'i', 'í'=>'i', 'î'=>'i', 'ï'=>'i', 'ð'=>'o', 'ñ'=>'n', 'ò'=>'o', 'ó'=>'o', 'ô'=>'o', 'õ'=>'o', 'ö'=>'oe', 'ø'=>'o', 'ü'=>'ue', 'ù'=>'u', 'ú'=>'u', 'û'=>'u', 'ý'=>'y', 'ý'=>'y', 'þ'=>'b', 'ÿ'=>'y', 'ƒ'=>'f', 'Ŕ'=>'R', 'ŕ'=>'r'];
+
+    protected $char_map = ['Š' => 'S', 'š' => 's', 'Ð' => 'Dj', 'Ž' => 'Z', 'ž' => 'z', 'À' => 'A', 'Á' => 'A', 'Â' => 'A', 'Ã' => 'A', 'Ä' => 'Ae', 'Å' => 'A', 'Æ' => 'A', 'Ç' => 'C', 'È' => 'E', 'É' => 'E', 'Ê' => 'E', 'Ë' => 'E', 'Ì' => 'I', 'Í' => 'I', 'Î' => 'I', 'Ï' => 'I', 'Ñ' => 'N', 'Ò' => 'O', 'Ó' => 'O', 'Ô' => 'O', 'Õ' => 'O', 'Ö' => 'Oe', 'Ø' => 'O', 'Ü' => 'Ue', 'Ù' => 'U', 'Ú' => 'U', 'Û' => 'U', 'Ý' => 'Y', 'Þ' => 'B', 'ß' => 'ss', 'à' => 'a', 'á' => 'a', 'â' => 'a', 'ã' => 'a', 'ä' => 'ae', 'å' => 'a', 'æ' => 'a', 'ç' => 'c', 'è' => 'e', 'é' => 'e', 'ê' => 'e', 'ë' => 'e', 'ì' => 'i', 'í' => 'i', 'î' => 'i', 'ï' => 'i', 'ð' => 'o', 'ñ' => 'n', 'ò' => 'o', 'ó' => 'o', 'ô' => 'o', 'õ' => 'o', 'ö' => 'oe', 'ø' => 'o', 'ü' => 'ue', 'ù' => 'u', 'ú' => 'u', 'û' => 'u', 'ý' => 'y', 'ý' => 'y', 'þ' => 'b', 'ÿ' => 'y', 'ƒ' => 'f', 'Ŕ' => 'R', 'ŕ' => 'r'];
 
     /**
      * Constructor.
@@ -47,8 +48,8 @@ class Slug implements ArrayAccess
      *  * seperator_char: word seperator char for the slug (default -)
      *
      * @param string $original An array of field default values
-     * @param array  $options  An array of options
-     * @param array  $char_map a char-map-array that is used for the strtr() PHP-function in the slug generation process
+     * @param array $options An array of options
+     * @param array $char_map a char-map-array that is used for the strtr() PHP-function in the slug generation process
      */
     public function __construct($original, $options = [], $char_map = null)
     {
@@ -59,6 +60,17 @@ class Slug implements ArrayAccess
         }
     }
 
+    /**
+     * Returns the slug-string
+     *
+     * @return string the slug
+     * @see    getSlug()
+     */
+    public function __toString()
+    {
+        return $this->getSlug();
+    }
+
     /**
      * Generate the slug.
      */
@@ -75,37 +87,12 @@ class Slug implements ArrayAccess
         // trim the seperator char at the end and teh beginning
         $str = trim($str, $this['seperator_char']);
         // remove duplicate seperator chars
-        $str = preg_replace('/['.preg_quote($this['seperator_char']).']+/', $this['seperator_char'], $str);
+        $str = preg_replace('/[' . preg_quote($this['seperator_char']) . ']+/', $this['seperator_char'], $str);
         if ($this['max_length']) {
-            $str = $this->shortenSlug($str, $this['max_length']-mb_strlen($this['prefix'], 'UTF-8')-mb_strlen($this['postfix'], 'UTF-8'));
+            $str = $this->shortenSlug($str, $this['max_length'] - mb_strlen($this['prefix'], 'UTF-8') - mb_strlen($this['postfix'], 'UTF-8'));
         }
         // Add prefix & postfix
-        $this->slug = $this['prefix'].$str.$this['postfix'];
-    }
-
-    /**
-     * Shorten the slug.
-     */
-    protected function shortenSlug($slug, $maxLen)
-    {
-        // $maxLen must be greater than 1
-        if ($maxLen < 1) {
-            return $slug;
-        }
-        // check whether there is work to do
-        if (strlen($slug) < $maxLen) {
-            return $slug;
-        }
-        // cut to $maxLen
-        $cutted_slug = trim(substr($slug, 0, $maxLen), $this['seperator_char']);
-        // cut to the last position of '-' in cutted string
-        $beautified_slug = trim(preg_replace('/[^'.preg_quote($this['seperator_char']).']*$/', '', $cutted_slug), $this['seperator_char']);
-        // only return the beautified string when it is long enough
-        if (strlen($beautified_slug) < ($maxLen/2)) {
-            return $cutted_slug;
-        } else {
-            return $beautified_slug;
-        }
+        $this->slug = $this['prefix'] . $str . $this['postfix'];
     }
 
     /**
@@ -119,18 +106,8 @@ class Slug implements ArrayAccess
         if (null === $this->slug) {
             $this->generateSlug();
         }
-        return $this->slug;
-    }
 
-    /**
-     * Returns the slug-string
-     *
-     * @return string the slug
-     * @see    getSlug()
-     */
-    public function __toString()
-    {
-        return $this->getSlug();
+        return $this->slug;
     }
 
     /**
@@ -147,7 +124,7 @@ class Slug implements ArrayAccess
      * Sets the option associated with the offset (implements the ArrayAccess interface).
      *
      * @param string $offset The option name
-     * @param string $value  The option value
+     * @param string $value The option value
      */
     public function offsetSet($offset, $value): void
     {
@@ -161,8 +138,9 @@ class Slug implements ArrayAccess
     /**
      * Returns true if the option exists (implements the ArrayAccess interface).
      *
-     * @param  string $name The name of option
-     * @return Boolean true if the option exists, false otherwise
+     * @param string $name The name of option
+     * @param mixed $offset
+     * @return bool true if the option exists, false otherwise
      */
     public function offsetExists($offset)
     {
@@ -182,11 +160,39 @@ class Slug implements ArrayAccess
     /**
      * Returns an option (implements the ArrayAccess interface).
      *
-     * @param  string $name The offset of the option to get
+     * @param string $name The offset of the option to get
+     * @param mixed $offset
      * @return mixed The option if exists, null otherwise
      */
     public function offsetGet($offset)
     {
         return $this->options[$offset] ?? null;
     }
+
+    /**
+     * Shorten the slug.
+     * @param mixed $slug
+     * @param mixed $maxLen
+     */
+    protected function shortenSlug($slug, $maxLen)
+    {
+        // $maxLen must be greater than 1
+        if ($maxLen < 1) {
+            return $slug;
+        }
+        // check whether there is work to do
+        if (strlen($slug) < $maxLen) {
+            return $slug;
+        }
+        // cut to $maxLen
+        $cutted_slug = trim(substr($slug, 0, $maxLen), $this['seperator_char']);
+        // cut to the last position of '-' in cutted string
+        $beautified_slug = trim(preg_replace('/[^' . preg_quote($this['seperator_char']) . ']*$/', '', $cutted_slug), $this['seperator_char']);
+        // only return the beautified string when it is long enough
+        if (strlen($beautified_slug) < ($maxLen / 2)) {
+            return $cutted_slug;
+        }
+
+        return $beautified_slug;
+    }
 }
