@@ -27,7 +27,7 @@ const Grid = ({ width, height, columns }: Props): ReactElement => {
     [width]
   );
 
-  const numberOfRows = Math.floor(height / (rowHeight + 16));
+  const numberOfRows = Math.floor(height / (rowHeight + 8));
 
   const yScale = useMemo(
     () =>
@@ -44,22 +44,22 @@ const Grid = ({ width, height, columns }: Props): ReactElement => {
     .fill(0)
     .map((_, index) => index * tick);
 
+  const yTickValues = Array(numberOfRows)
+    .fill(0)
+    .map((_, index) => index);
+
   return useMemoComponent({
     Component: (
       <svg style={{ height, position: 'absolute', width }}>
-        <VisxGrid.GridColumns
+        <VisxGrid.Grid
+          columnTickValues={xTickValues}
+          rowTickValues={yTickValues}
           height={height}
-          scale={xScale}
+          yScale={yScale}
+          xScale={xScale}
           stroke={theme.palette.divider}
-          tickValues={xTickValues}
-          width={width}
-        />
-        <VisxGrid.GridRows
-          height={height}
-          scale={yScale}
-          stroke={theme.palette.divider}
-          top={-10}
           width={width}
+          left={-8}
         />
       </svg>
     ),
