@@ -1,28 +1,27 @@
-import { memo, useMemo } from 'react';
-
 import { equals, props } from 'ramda';
-
+import { memo, useMemo } from 'react';
 import { useGraphAndLegendStyles } from './BarStack.styles';
 import Graph from './Graph';
 import { gap, legendMaxHeight, legendMaxWidth } from './constants';
 import { BarStackProps } from './models';
 
-interface Props extends Pick<
-  BarStackProps,
-  | 'data'
-  | 'displayValues'
-  | 'onSingleBarClick'
-  | 'unit'
-  | 'TooltipContent'
-  | 'tooltipProps'
-> {
-  colorScale;
-  displayLegend: boolean;
-  height: number;
+interface Props
+  extends Pick<
+    BarStackProps,
+    | 'data'
+    | 'displayValues'
+    | 'onSingleBarClick'
+    | 'unit'
+    | 'TooltipContent'
+    | 'tooltipProps'
+  > {
   isVerticalBar: boolean;
   legend: JSX.Element;
-  total: number;
+  displayLegend: boolean;
+  height: number;
   width: number;
+  colorScale;
+  total: number;
 }
 
 const GraphAndLegend = ({
@@ -74,17 +73,17 @@ const GraphAndLegend = ({
       style={{ height }}
     >
       <Graph
-        TooltipContent={TooltipContent}
-        colorScale={colorScale}
-        data={data}
-        displayValues={displayValues}
-        height={graphHeight}
         isVerticalBar={isVerticalBar}
-        tooltipProps={tooltipProps}
-        total={total}
-        unit={unit}
+        data={data}
         width={graphWidth}
+        height={graphHeight}
+        colorScale={colorScale}
+        unit={unit}
+        total={total}
+        displayValues={displayValues}
         onSingleBarClick={onSingleBarClick}
+        tooltipProps={tooltipProps}
+        TooltipContent={TooltipContent}
       />
       {mustDisplayLegend && (
         <div
