@@ -156,5 +156,8 @@ export const treeWithZoom: Story = {
       getStrokeWidth: ({ target }) => (target.status === 'ok' ? 1 : 2)
     }
   },
-  render: TreeWithZoom
+  render: TreeWithZoom,
+  parameters: {
+    chromatic: { disableSnapshot: true }
+  }
 };
