@@ -8,8 +8,7 @@ import { ChartAxis } from '../../Chart/models';
 import Axes from '../Axes';
 import Grids from '../Grids';
 import { Line, TimeValue } from '../timeSeries/models';
-
-import { extraMargin } from './useComputeBaseChartDimensions';
+import { computeGElementMarginLeft } from '../utils';
 
 interface Props {
   allUnits: Array<string>;
@@ -27,6 +26,8 @@ interface Props {
   svgRef: MutableRefObject<SVGSVGElement | null>;
   timeSeries: Array<TimeValue>;
   xScale;
+  maxAxisCharacters?: number;
+  hasSecondUnit?: boolean;
 }
 
 const ChartSvgWrapper = ({
@@ -44,7 +45,9 @@ const ChartSvgWrapper = ({
   axis,
   children,
   orientation = 'horizontal',
-  allUnits
+  allUnits,
+  maxAxisCharacters = 0,
+  hasSecondUnit
 }: Props): JSX.Element => {
   const isHorizontal = equals(orientation, 'horizontal');
 
@@ -55,7 +58,13 @@ const ChartSvgWrapper = ({
       ref={svgRef}
       width="100%"
     >
-      <Group.Group left={margin.left + extraMargin / 2} top={margin.top}>
+      <Group.Group
+        left={computeGElementMarginLeft({
+          maxCharacters: maxAxisCharacters,
+          hasSecondUnit
+        })}
+        top={margin.top}
+      >
         {showGridLines && (
           <Grids
             gridLinesType={gridLinesType}
