@@ -1,13 +1,15 @@
+import { QueryClient } from '@tanstack/react-query';
 import { Provider as JotaiProvider, createStore } from 'jotai';
 
-import { createGenerateClassName, StylesProvider } from '@mui/styles';
+import { StylesProvider, createGenerateClassName } from '@mui/styles';
 
-import { ThemeProvider, QueryProvider } from '..';
+import { QueryProvider, ThemeProvider } from '..';
 import SnackbarProvider from '../Snackbar/SnackbarProvider';
 
 export interface ModuleProps {
   children: React.ReactElement;
   maxSnackbars?: number;
+  queryClient?: QueryClient;
   seedName: string;
   store: ReturnType<typeof createStore>;
 }
@@ -16,14 +18,15 @@ const Module = ({
   children,
   seedName,
   maxSnackbars = 3,
-  store
+  store,
+  queryClient
 }: ModuleProps): JSX.Element => {
   const generateClassName = createGenerateClassName({
     seed: seedName
   });
 
   return (
-    <QueryProvider>
+    <QueryProvider queryClient={queryClient}>
       <JotaiProvider store={store}>
         <StylesProvider generateClassName={generateClassName}>
           <ThemeProvider>
