@@ -1,4 +1,4 @@
-import { SwitchProps, Switch as MuiSwitch } from '@mui/material';
+import { Switch as MuiSwitch, SwitchProps } from '@mui/material';
 
 import { useSwitchStyles } from './Switch.styles';
 
