@@ -7,7 +7,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -28,18 +28,12 @@ use Adaptation\Database\Connection\Collection\QueryParameters;
 use Adaptation\Database\Exception\DatabaseException;
 
 /**
- * Class
+ * Class.
  *
  * @class   ConnectionException
- * @package Adaptation\Database\Connection\Exception
  */
 class ConnectionException extends DatabaseException
 {
-    /**
-     * @param string $method
-     *
-     * @return ConnectionException
-     */
     public static function notImplemented(string $method): self
     {
         return new self(
@@ -49,10 +43,7 @@ class ConnectionException extends DatabaseException
     }
 
     /**
-     * @param string $message
      * @param array<string,mixed> $context
-     *
-     * @return ConnectionException
      */
     public static function connectionBadUsage(string $message, array $context = []): self
     {
@@ -63,30 +54,20 @@ class ConnectionException extends DatabaseException
         );
     }
 
-    /**
-     * @param \Throwable|null $previous
-     *
-     * @return ConnectionException
-     */
     public static function connectionFailed(?\Throwable $previous = null): self
     {
         $message = 'Error while connecting to the database';
-        if (! is_null($previous) && ! empty($previous->getMessage())) {
+        if ($previous instanceof \Throwable && ! empty($previous->getMessage())) {
             $message .= " : {$previous->getMessage()}";
         }
 
         return new self($message, self::ERROR_CODE_DATABASE, [], $previous);
     }
 
-    /**
-     * @param \Throwable|null $previous
-     *
-     * @return ConnectionException
-     */
     public static function getNativeConnectionFailed(?\Throwable $previous = null): self
     {
         $message = 'Error while retrieving the native connection';
-        if (! is_null($previous) && ! empty($previous->getMessage())) {
+        if ($previous instanceof \Throwable && ! empty($previous->getMessage())) {
             $message .= " : {$previous->getMessage()}";
         }
 
@@ -97,26 +78,16 @@ class ConnectionException extends DatabaseException
         );
     }
 
-    /**
-     * @param \Throwable|null $previous
-     *
-     * @return ConnectionException
-     */
     public static function getDatabaseNameFailed(?\Throwable $previous = null): self
     {
         $message = 'Error while retrieving the database name';
-        if (! is_null($previous) && ! empty($previous->getMessage())) {
+        if ($previous instanceof \Throwable && ! empty($previous->getMessage())) {
             $message .= " : {$previous->getMessage()}";
         }
 
         return new self($message, self::ERROR_CODE_DATABASE);
     }
 
-    /**
-     * @param \Throwable $previous
-     *
-     * @return ConnectionException
-     */
     public static function getLastInsertFailed(\Throwable $previous): self
     {
         return new self(
@@ -128,9 +99,6 @@ class ConnectionException extends DatabaseException
 
     // --------------------------------------- CRUD METHODS -----------------------------------------
 
-    /**
-     * @return ConnectionException
-     */
     public static function notEmptyQuery(): self
     {
         return new self(
@@ -148,34 +116,22 @@ class ConnectionException extends DatabaseException
         );
     }
 
-    /**
-     * @param \Throwable $previous
-     * @param string $query
-     * @param QueryParameters|null $queryParameters
-     *
-     * @return self
-     */
     public static function executeStatementFailed(
         \Throwable $previous,
         string $query,
-        ?QueryParameters $queryParameters = null
+        ?QueryParameters $queryParameters = null,
     ): self {
-        $context['query'] = $query;
-        $context['query_parameters'] = $queryParameters;
-
         return new self(
             message: "Error while executing the statement : {$previous->getMessage()}",
             code: self::ERROR_CODE_DATABASE,
-            context: $context,
+            context: [
+                'query' => $query,
+                'query_parameters' => $queryParameters,
+            ],
             previous: $previous
         );
     }
 
-    /**
-     * @param string $query
-     *
-     * @return ConnectionException
-     */
     public static function insertQueryBadFormat(string $query): self
     {
         return new self(
@@ -185,34 +141,22 @@ class ConnectionException extends DatabaseException
         );
     }
 
-    /**
-     * @param \Throwable $previous
-     * @param string $query
-     * @param QueryParameters|null $queryParameters
-     *
-     * @return ConnectionException
-     */
     public static function insertQueryFailed(
         \Throwable $previous,
         string $query,
-        ?QueryParameters $queryParameters = null
+        ?QueryParameters $queryParameters = null,
     ): self {
-        $context['query'] = $query;
-        $context['query_parameters'] = $queryParameters;
-
         return new self(
             message: "Error while executing the insert query : {$previous->getMessage()}",
             code: self::ERROR_CODE_DATABASE,
-            context: $context,
+            context: [
+                'query' => $query,
+                'query_parameters' => $queryParameters,
+            ],
             previous: $previous
         );
     }
 
-    /**
-     * @param string $message
-     *
-     * @return ConnectionException
-     */
     public static function batchInsertQueryBadUsage(string $message): self
     {
         return new self(
@@ -222,20 +166,14 @@ class ConnectionException extends DatabaseException
     }
 
     /**
-     * @param \Throwable $previous
-     * @param string $tableName
      * @param array<string> $columns
-     * @param BatchInsertParameters $batchInsertParameters
-     * @param string $query
-     *
-     * @return ConnectionException
      */
     public static function batchInsertQueryFailed(
         \Throwable $previous,
         string $tableName,
         array $columns,
         BatchInsertParameters $batchInsertParameters,
-        string $query = ''
+        string $query = '',
     ): self {
         return new self(
             message: "Error while executing the batch insert query : {$previous->getMessage()}",
@@ -250,11 +188,6 @@ class ConnectionException extends DatabaseException
         );
     }
 
-    /**
-     * @param string $query
-     *
-     * @return ConnectionException
-     */
     public static function updateQueryBadFormat(string $query): self
     {
         return new self(
@@ -264,34 +197,22 @@ class ConnectionException extends DatabaseException
         );
     }
 
-    /**
-     * @param \Throwable $previous
-     * @param string $query
-     * @param QueryParameters|null $queryParameters
-     *
-     * @return ConnectionException
-     */
     public static function updateQueryFailed(
         \Throwable $previous,
         string $query,
-        ?QueryParameters $queryParameters = null
+        ?QueryParameters $queryParameters = null,
     ): self {
-        $context['query'] = $query;
-        $context['query_parameters'] = $queryParameters;
-
         return new self(
             message: "Error while executing the update query : {$previous->getMessage()}",
             code: self::ERROR_CODE_DATABASE,
-            context: $context,
+            context: [
+                'query' => $query,
+                'query_parameters' => $queryParameters,
+            ],
             previous: $previous
         );
     }
 
-    /**
-     * @param string $query
-     *
-     * @return ConnectionException
-     */
     public static function deleteQueryBadFormat(string $query): self
     {
         return new self(
@@ -301,34 +222,22 @@ class ConnectionException extends DatabaseException
         );
     }
 
-    /**
-     * @param \Throwable $previous
-     * @param string $query
-     * @param QueryParameters|null $queryParameters
-     *
-     * @return ConnectionException
-     */
     public static function deleteQueryFailed(
         \Throwable $previous,
         string $query,
-        ?QueryParameters $queryParameters = null
+        ?QueryParameters $queryParameters = null,
     ): self {
-        $context['query'] = $query;
-        $context['query_parameters'] = $queryParameters;
-
         return new self(
             message: "Error while executing the delete query : {$previous->getMessage()}",
             code: self::ERROR_CODE_DATABASE,
-            context: $context,
+            context: [
+                'query' => $query,
+                'query_parameters' => $queryParameters,
+            ],
             previous: $previous
         );
     }
 
-    /**
-     * @param string $query
-     *
-     * @return ConnectionException
-     */
     public static function selectQueryBadFormat(string $query): self
     {
         return new self(
@@ -339,18 +248,13 @@ class ConnectionException extends DatabaseException
     }
 
     /**
-     * @param \Throwable $previous
-     * @param string $query
-     * @param QueryParameters|null $queryParameters
      * @param array<string,mixed> $context
-     *
-     * @return ConnectionException
      */
     public static function selectQueryFailed(
         \Throwable $previous,
         string $query,
         ?QueryParameters $queryParameters = null,
-        array $context = []
+        array $context = [],
     ): self {
         $context['query'] = $query;
         $context['query_parameters'] = $queryParameters;
@@ -363,265 +267,182 @@ class ConnectionException extends DatabaseException
         );
     }
 
-    /**
-     * @param \Throwable $previous
-     * @param string $query
-     * @param QueryParameters|null $queryParameters
-     *
-     * @return ConnectionException
-     */
     public static function fetchNumericQueryFailed(
         \Throwable $previous,
         string $query,
-        ?QueryParameters $queryParameters = null
+        ?QueryParameters $queryParameters = null,
     ): self {
-        $context['query'] = $query;
-        $context['query_parameters'] = $queryParameters;
-
         return new self(
             message: "Error while executing fetch numeric query : {$previous->getMessage()}",
             code: self::ERROR_CODE_DATABASE,
-            context: $context,
+            context: [
+                'query' => $query,
+                'query_parameters' => $queryParameters,
+            ],
             previous: $previous
         );
     }
 
-    /**
-     * @param \Throwable $previous
-     * @param string $query
-     * @param QueryParameters|null $queryParameters
-     *
-     * @return ConnectionException
-     */
     public static function fetchAssociativeQueryFailed(
         \Throwable $previous,
         string $query,
-        ?QueryParameters $queryParameters = null
+        ?QueryParameters $queryParameters = null,
     ): self {
-        $context['query'] = $query;
-        $context['query_parameters'] = $queryParameters;
-
         return new self(
             message: "Error while executing fetch associative query : {$previous->getMessage()}",
             code: self::ERROR_CODE_DATABASE,
-            context: $context,
+            context: [
+                'query' => $query,
+                'query_parameters' => $queryParameters,
+            ],
             previous: $previous
         );
     }
 
-    /**
-     * @param \Throwable $previous
-     * @param string $query
-     * @param QueryParameters|null $queryParameters
-     *
-     * @return ConnectionException
-     */
     public static function fetchOneQueryFailed(
         \Throwable $previous,
         string $query,
-        ?QueryParameters $queryParameters = null
+        ?QueryParameters $queryParameters = null,
     ): self {
-        $context['query'] = $query;
-        $context['query_parameters'] = $queryParameters;
-
         return new self(
             message: "Error while executing fetch one query : {$previous->getMessage()}",
             code: self::ERROR_CODE_DATABASE,
-            context: $context,
+            context: [
+                'query' => $query,
+                'query_parameters' => $queryParameters,
+            ],
             previous: $previous
         );
     }
 
-    /**
-     * @param \Throwable $previous
-     * @param string $query
-     * @param QueryParameters|null $queryParameters
-     *
-     * @return ConnectionException
-     */
     public static function fetchFirstColumnQueryFailed(
         \Throwable $previous,
         string $query,
         ?QueryParameters $queryParameters = null,
     ): self {
-        $context['query'] = $query;
-        $context['query_parameters'] = $queryParameters;
-
         return new self(
             message: "Error while executing fetch first column query : {$previous->getMessage()}",
             code: self::ERROR_CODE_DATABASE,
-            context: $context,
+            context: [
+                'query' => $query,
+                'query_parameters' => $queryParameters,
+            ],
             previous: $previous
         );
     }
 
-    /**
-     * @param \Throwable $previous
-     * @param string $query
-     * @param QueryParameters|null $queryParameters
-     *
-     * @return ConnectionException
-     */
     public static function fetchAllNumericQueryFailed(
         \Throwable $previous,
         string $query,
-        ?QueryParameters $queryParameters = null
+        ?QueryParameters $queryParameters = null,
     ): self {
-        $context['query'] = $query;
-        $context['query_parameters'] = $queryParameters;
-
         return new self(
             message: "Error while executing fetch all numeric query : {$previous->getMessage()}",
             code: self::ERROR_CODE_DATABASE,
-            context: $context,
+            context: [
+                'query' => $query,
+                'query_parameters' => $queryParameters,
+            ],
             previous: $previous
         );
     }
 
-    /**
-     * @param \Throwable $previous
-     * @param string $query
-     * @param QueryParameters|null $queryParameters
-     *
-     * @return ConnectionException
-     */
     public static function fetchAllAssociativeQueryFailed(
         \Throwable $previous,
         string $query,
-        ?QueryParameters $queryParameters = null
+        ?QueryParameters $queryParameters = null,
     ): self {
-        $context['query'] = $query;
-        $context['query_parameters'] = $queryParameters;
-
         return new self(
             message: "Error while executing fetch all associative query : {$previous->getMessage()}",
             code: self::ERROR_CODE_DATABASE,
-            context: $context,
+            context: [
+                'query' => $query,
+                'query_parameters' => $queryParameters,
+            ],
             previous: $previous
         );
     }
 
-    /**
-     * @param \Throwable $previous
-     * @param string $query
-     * @param QueryParameters|null $queryParameters
-     *
-     * @return ConnectionException
-     */
     public static function fetchAllKeyValueQueryFailed(
         \Throwable $previous,
         string $query,
-        ?QueryParameters $queryParameters = null
+        ?QueryParameters $queryParameters = null,
     ): self {
-        $context['query'] = $query;
-        $context['query_parameters'] = $queryParameters;
-
         return new self(
             message: "Error while executing fetch all key value query : {$previous->getMessage()}",
             code: self::ERROR_CODE_DATABASE,
-            context: $context,
+            context: [
+                'query' => $query,
+                'query_parameters' => $queryParameters,
+            ],
             previous: $previous
         );
     }
 
-    /**
-     * @param \Throwable $previous
-     * @param string $query
-     * @param QueryParameters|null $queryParameters
-     *
-     * @return ConnectionException
-     */
     public static function fetchAllAssociativeIndexedQueryFailed(
         \Throwable $previous,
         string $query,
-        ?QueryParameters $queryParameters = null
+        ?QueryParameters $queryParameters = null,
     ): self {
-        $context['query'] = $query;
-        $context['query_parameters'] = $queryParameters;
-
         return new self(
             message: "Error while executing fetch all associative indexed query : {$previous->getMessage()}",
             code: self::ERROR_CODE_DATABASE,
-            context: $context,
+            context: [
+                'query' => $query,
+                'query_parameters' => $queryParameters,
+            ],
             previous: $previous
         );
     }
 
-    /**
-     * @param \Throwable $previous
-     * @param string $query
-     * @param QueryParameters|null $queryParameters
-     *
-     * @return ConnectionException
-     */
     public static function iterateNumericQueryFailed(
         \Throwable $previous,
         string $query,
-        ?QueryParameters $queryParameters = null
+        ?QueryParameters $queryParameters = null,
     ): self {
-        $context['query'] = $query;
-        $context['query_parameters'] = $queryParameters;
-
         return new self(
             message: "Error while executing iterate numeric query : {$previous->getMessage()}",
             code: self::ERROR_CODE_DATABASE,
-            context: $context,
+            context: [
+                'query' => $query,
+                'query_parameters' => $queryParameters,
+            ],
             previous: $previous
         );
     }
 
-    /**
-     * @param \Throwable $previous
-     * @param string $query
-     * @param QueryParameters|null $queryParameters
-     *
-     * @return ConnectionException
-     */
     public static function iterateAssociativeQueryFailed(
         \Throwable $previous,
         string $query,
-        ?QueryParameters $queryParameters = null
+        ?QueryParameters $queryParameters = null,
     ): self {
-        $context['query'] = $query;
-        $context['query_parameters'] = $queryParameters;
-
         return new self(
             message: "Error while executing iterate associative query : {$previous->getMessage()}",
             code: self::ERROR_CODE_DATABASE,
-            context: $context,
+            context: [
+                'query' => $query,
+                'query_parameters' => $queryParameters,
+            ],
             previous: $previous
         );
     }
 
-    /**
-     * @param \Throwable $previous
-     * @param string $query
-     * @param QueryParameters|null $queryParameters
-     *
-     * @return ConnectionException
-     */
     public static function iterateColumnQueryFailed(
         \Throwable $previous,
         string $query,
-        ?QueryParameters $queryParameters = null
+        ?QueryParameters $queryParameters = null,
     ): self {
-        $context['query'] = $query;
-        $context['query_parameters'] = $queryParameters;
-
         return new self(
             message: "Error while executing iterate first column query : {$previous->getMessage()}",
             code: self::ERROR_CODE_DATABASE,
-            context: $context,
+            context: [
+                'query' => $query,
+                'query_parameters' => $queryParameters,
+            ],
             previous: $previous
         );
     }
 
-    /**
-     * @param string $query
-     * @param string $message
-     *
-     * @return self
-     */
     public static function iterateKeyValueQueryBadFormat(string $message, string $query): self
     {
         return new self(
@@ -631,63 +452,44 @@ class ConnectionException extends DatabaseException
         );
     }
 
-    /**
-     * @param \Throwable $previous
-     * @param string $query
-     * @param QueryParameters|null $queryParameters
-     *
-     * @return ConnectionException
-     */
     public static function iterateKeyValueQueryFailed(
         \Throwable $previous,
         string $query,
-        ?QueryParameters $queryParameters = null
+        ?QueryParameters $queryParameters = null,
     ): self {
-        $context['query'] = $query;
-        $context['query_parameters'] = $queryParameters;
-
         return new self(
             message: "Error while executing iterate key value query : {$previous->getMessage()}",
             code: self::ERROR_CODE_DATABASE,
-            context: $context,
+            context: [
+                'query' => $query,
+                'query_parameters' => $queryParameters,
+            ],
             previous: $previous
         );
     }
 
-    /**
-     * @param \Throwable $previous
-     * @param string $query
-     * @param QueryParameters|null $queryParameters
-     *
-     * @return ConnectionException
-     */
     public static function iterateAssociativeIndexedQueryFailed(
         \Throwable $previous,
         string $query,
-        ?QueryParameters $queryParameters = null
+        ?QueryParameters $queryParameters = null,
     ): self {
-        $context['query'] = $query;
-        $context['query_parameters'] = $queryParameters;
-
         return new self(
             message: "Error while executing iterate associative indexed query : {$previous->getMessage()}",
             code: self::ERROR_CODE_DATABASE,
-            context: $context,
+            context: [
+                'query' => $query,
+                'query_parameters' => $queryParameters,
+            ],
             previous: $previous
         );
     }
 
     // ----------------------------------------- TRANSACTIONS -----------------------------------------
 
-    /**
-     * @param \Throwable|null $exception
-     *
-     * @return self
-     */
     public static function setAutoCommitFailed(?\Throwable $exception = null): self
     {
         $message = 'Error while setting auto commit';
-        if (! is_null($exception) && ! empty($exception->getMessage())) {
+        if ($exception instanceof \Throwable && ! empty($exception->getMessage())) {
             $message .= " : {$exception->getMessage()}";
         }
 
@@ -698,11 +500,6 @@ class ConnectionException extends DatabaseException
         );
     }
 
-    /**
-     * @param \Throwable $previous
-     *
-     * @return ConnectionException
-     */
     public static function startTransactionFailed(\Throwable $previous): self
     {
         return new self(
@@ -712,15 +509,10 @@ class ConnectionException extends DatabaseException
         );
     }
 
-    /**
-     * @param \Throwable|null $previous
-     *
-     * @return ConnectionException
-     */
     public static function commitTransactionFailed(?\Throwable $previous = null): self
     {
         $message = 'Error during the transaction commit';
-        if (! is_null($previous) && ! empty($previous->getMessage())) {
+        if ($previous instanceof \Throwable && ! empty($previous->getMessage())) {
             $message .= " : {$previous->getMessage()}";
         }
 
@@ -731,15 +523,10 @@ class ConnectionException extends DatabaseException
         );
     }
 
-    /**
-     * @param \Throwable|null $previous
-     *
-     * @return ConnectionException
-     */
     public static function rollbackTransactionFailed(?\Throwable $previous = null): self
     {
         $message = 'Error during the transaction rollback';
-        if (! is_null($previous) && ! empty($previous->getMessage())) {
+        if ($previous instanceof \Throwable && ! empty($previous->getMessage())) {
             $message .= " : {$previous->getMessage()}";
         }
 
@@ -752,15 +539,9 @@ class ConnectionException extends DatabaseException
 
     // ------------------------------------- UNBUFFERED QUERIES -----------------------------------------
 
-    /**
-     * @param string $nativeConnectionClass
-     * @param string $currentDriverName
-     *
-     * @return ConnectionException
-     */
     public static function allowUnbufferedQueryFailed(
         string $nativeConnectionClass,
-        string $currentDriverName
+        string $currentDriverName,
     ): self {
         return new self(
             message: "Unbuffered queries not allowed for native connection class '{$nativeConnectionClass}' with this driver : {$currentDriverName}.",
@@ -769,9 +550,6 @@ class ConnectionException extends DatabaseException
         );
     }
 
-    /**
-     * @return ConnectionException
-     */
     public static function startUnbufferedQueryFailed(): self
     {
         return new self(
@@ -780,13 +558,8 @@ class ConnectionException extends DatabaseException
         );
     }
 
-    /**
-     * @param string $message
-     *
-     * @return ConnectionException
-     */
     public static function stopUnbufferedQueryFailed(
-        string $message
+        string $message,
     ): self {
         return new self(
             message: "Stopping unbuffered queries failed : {$message}",
@@ -796,12 +569,6 @@ class ConnectionException extends DatabaseException
 
     // ------------------------------------- BASE METHODS -----------------------------------------
 
-    /**
-     * @param \Throwable $previous
-     * @param string $query
-     *
-     * @return ConnectionException
-     */
     public static function closeQueryFailed(\Throwable $previous, string $query): self
     {
         return new self(
@@ -811,23 +578,4 @@ class ConnectionException extends DatabaseException
             previous: $previous
         );
     }
-
-    // --------------------------------------- DDL TOOLS -----------------------------------------------
-
-    public static function columnExistsFailed(
-        string $message,
-        string $tableName,
-        string $columnName,
-        ?\Exception $previous = null,
-    ): self {
-        return new self(
-            message: "Error while checking if column '{$columnName}' exists in table '{$tableName}' : {$message}",
-            code: self::ERROR_CODE_DATABASE,
-            context: [
-                'table_name' => $tableName,
-                'column_name' => $columnName,
-            ],
-            previous: $previous
-        );
-    }
 }
