@@ -1,13 +1,13 @@
 <?php
 
 /*
- * Copyright 2005 - 2020 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -24,11 +24,8 @@ declare(strict_types=1);
 namespace Centreon\Application\Controller\Administration;
 
 use Centreon\Application\Controller\AbstractController;
-use Centreon\Domain\Contact\Contact;
-use Centreon\Domain\Contact\Interfaces\ContactInterface;
 use Centreon\Domain\Option\Interfaces\OptionServiceInterface;
 use FOS\RestBundle\View\View;
-use Symfony\Component\HttpFoundation\Response;
 
 /**
  * Used to get global parameters
@@ -37,10 +34,10 @@ use Symfony\Component\HttpFoundation\Response;
  */
 class ParametersController extends AbstractController
 {
-
     private const DEFAULT_DOWNTIME_DURATION = 'monitoring_dwt_duration';
     private const DEFAULT_DOWNTIME_DURATION_SCALE = 'monitoring_dwt_duration_scale';
     private const DEFAULT_REFRESH_INTERVAL = 'AjaxTimeReloadMonitoring';
+    private const DEFAULT_STATISTICS_REFRESH_INTERVAL = 'AjaxTimeReloadStatistic';
     private const DEFAULT_ACKNOWLEDGEMENT_STICKY = 'monitoring_ack_sticky';
     private const DEFAULT_ACKNOWLEDGEMENT_PERSISTENT = 'monitoring_ack_persistent';
     private const DEFAULT_ACKNOWLEDGEMENT_NOTIFY = 'monitoring_ack_notify';
@@ -48,12 +45,14 @@ class ParametersController extends AbstractController
     private const DEFAULT_ACKNOWLEDGEMENT_FORCE_ACTIVE_CHECKS = 'monitoring_ack_active_checks';
     private const DEFAULT_DOWNTIME_FIXED = 'monitoring_dwt_fixed';
     private const DEFAULT_DOWNTIME_WITH_SERVICES = 'monitoring_dwt_svc';
+    private const RESOURCE_STATUS_SEARCH_MODE = 'resource_status_search_mode';
 
     /**
      * Needed to make response "more readable"
      */
     private const KEY_NAME_CONCORDANCE = [
         self::DEFAULT_REFRESH_INTERVAL => 'monitoring_default_refresh_interval',
+        self::DEFAULT_STATISTICS_REFRESH_INTERVAL => 'statistics_default_refresh_interval',
         self::DEFAULT_DOWNTIME_DURATION => 'monitoring_default_downtime_duration',
         self::DEFAULT_ACKNOWLEDGEMENT_STICKY => 'monitoring_default_acknowledgement_sticky',
         self::DEFAULT_ACKNOWLEDGEMENT_PERSISTENT => 'monitoring_default_acknowledgement_persistent',
@@ -61,12 +60,12 @@ class ParametersController extends AbstractController
         self::DEFAULT_ACKNOWLEDGEMENT_WITH_SERVICES => 'monitoring_default_acknowledgement_with_services',
         self::DEFAULT_ACKNOWLEDGEMENT_FORCE_ACTIVE_CHECKS => 'monitoring_default_acknowledgement_force_active_checks',
         self::DEFAULT_DOWNTIME_FIXED => 'monitoring_default_downtime_fixed',
-        self::DEFAULT_DOWNTIME_WITH_SERVICES => 'monitoring_default_downtime_with_services'
+        self::DEFAULT_DOWNTIME_WITH_SERVICES => 'monitoring_default_downtime_with_services',
+        self::RESOURCE_STATUS_SEARCH_MODE => 'is_resource_status_full_search_enabled',
     ];
 
     public function __construct(
-        private OptionServiceInterface $optionService,
-        private ContactInterface $user
+        private OptionServiceInterface $optionService
     ) {
     }
 
@@ -77,14 +76,11 @@ class ParametersController extends AbstractController
      */
     public function getParameters(): View
     {
-        if (! $this->user->hasTopologyRole(Contact::ROLE_ADMINISTRATION_PARAMETERS_MONITORING_RW)) {
-            return $this->view(null, Response::HTTP_FORBIDDEN);
-        }
-
         $parameters = [];
         $downtimeDuration = '';
         $downtimeScale = '';
         $refreshInterval = '';
+        $statisticsRefreshInterval = '';
         $isAcknowledgementPersistent = true;
         $isAcknowledgementSticky = true;
         $isAcknowledgementNotify = false;
@@ -92,9 +88,11 @@ class ParametersController extends AbstractController
         $isAcknowledgementForceActiveChecks = true;
         $isDowntimeFixed = true;
         $isDowntimeWithServices = true;
+        $isResourceStatusFullSearchEnabled = true;
 
         $options = $this->optionService->findSelectedOptions([
             self::DEFAULT_REFRESH_INTERVAL,
+            self::DEFAULT_STATISTICS_REFRESH_INTERVAL,
             self::DEFAULT_ACKNOWLEDGEMENT_STICKY,
             self::DEFAULT_ACKNOWLEDGEMENT_PERSISTENT,
             self::DEFAULT_ACKNOWLEDGEMENT_NOTIFY,
@@ -103,7 +101,8 @@ class ParametersController extends AbstractController
             self::DEFAULT_DOWNTIME_DURATION,
             self::DEFAULT_DOWNTIME_DURATION_SCALE,
             self::DEFAULT_DOWNTIME_FIXED,
-            self::DEFAULT_DOWNTIME_WITH_SERVICES
+            self::DEFAULT_DOWNTIME_WITH_SERVICES,
+            self::RESOURCE_STATUS_SEARCH_MODE,
         ]);
 
         foreach ($options as $option) {
@@ -117,6 +116,9 @@ class ParametersController extends AbstractController
                 case self::DEFAULT_REFRESH_INTERVAL:
                     $refreshInterval = $option->getValue();
                     break;
+                case self::DEFAULT_STATISTICS_REFRESH_INTERVAL:
+                    $statisticsRefreshInterval = $option->getValue();
+                    break;
                 case self::DEFAULT_ACKNOWLEDGEMENT_PERSISTENT:
                     $isAcknowledgementPersistent = (int) $option->getValue() === 1;
                     break;
@@ -138,26 +140,32 @@ class ParametersController extends AbstractController
                 case self::DEFAULT_DOWNTIME_FIXED:
                     $isDowntimeFixed = (int) $option->getValue() === 1;
                     break;
+                case self::RESOURCE_STATUS_SEARCH_MODE:
+                    $isResourceStatusFullSearchEnabled = (int) $option->getValue() === 1;
+                    break;
                 default:
                     break;
             }
         }
 
-        $parameters[self::KEY_NAME_CONCORDANCE[self::DEFAULT_DOWNTIME_DURATION]] =
-            $this->convertToSeconds((int) $downtimeDuration, $downtimeScale);
+        $parameters[self::KEY_NAME_CONCORDANCE[self::DEFAULT_DOWNTIME_DURATION]]
+            = $this->convertToSeconds((int) $downtimeDuration, $downtimeScale);
 
         $parameters[self::KEY_NAME_CONCORDANCE[self::DEFAULT_REFRESH_INTERVAL]] = (int) $refreshInterval;
+        $parameters[self::KEY_NAME_CONCORDANCE[self::DEFAULT_STATISTICS_REFRESH_INTERVAL]]
+            = (int) $statisticsRefreshInterval;
 
-        $parameters[self::KEY_NAME_CONCORDANCE[self::DEFAULT_ACKNOWLEDGEMENT_PERSISTENT]] =
-            $isAcknowledgementPersistent;
+        $parameters[self::KEY_NAME_CONCORDANCE[self::DEFAULT_ACKNOWLEDGEMENT_PERSISTENT]]
+            = $isAcknowledgementPersistent;
         $parameters[self::KEY_NAME_CONCORDANCE[self::DEFAULT_ACKNOWLEDGEMENT_STICKY]] = $isAcknowledgementSticky;
         $parameters[self::KEY_NAME_CONCORDANCE[self::DEFAULT_ACKNOWLEDGEMENT_NOTIFY]] = $isAcknowledgementNotify;
-        $parameters[self::KEY_NAME_CONCORDANCE[self::DEFAULT_ACKNOWLEDGEMENT_WITH_SERVICES]] =
-            $isAcknowledgementWithServices;
-        $parameters[self::KEY_NAME_CONCORDANCE[self::DEFAULT_ACKNOWLEDGEMENT_FORCE_ACTIVE_CHECKS]] =
-            $isAcknowledgementForceActiveChecks;
+        $parameters[self::KEY_NAME_CONCORDANCE[self::DEFAULT_ACKNOWLEDGEMENT_WITH_SERVICES]]
+            = $isAcknowledgementWithServices;
+        $parameters[self::KEY_NAME_CONCORDANCE[self::DEFAULT_ACKNOWLEDGEMENT_FORCE_ACTIVE_CHECKS]]
+            = $isAcknowledgementForceActiveChecks;
         $parameters[self::KEY_NAME_CONCORDANCE[self::DEFAULT_DOWNTIME_FIXED]] = $isDowntimeFixed;
         $parameters[self::KEY_NAME_CONCORDANCE[self::DEFAULT_DOWNTIME_WITH_SERVICES]] = $isDowntimeWithServices;
+        $parameters[self::KEY_NAME_CONCORDANCE[self::RESOURCE_STATUS_SEARCH_MODE]] = $isResourceStatusFullSearchEnabled;
 
         return $this->view($parameters);
     }
@@ -165,19 +173,19 @@ class ParametersController extends AbstractController
     /**
      * Converts the combination stored in DB into seconds
      *
-     * @param integer $duration
+     * @param int $duration
      * @param string $scale
-     * @return integer
+     * @return int
      */
     private function convertToSeconds(int $duration, string $scale): int
     {
         switch ($scale) {
             case 'm':
-                return ($duration * 60);
+                return $duration * 60;
             case 'h':
-                return ($duration * 3600);
+                return $duration * 3600;
             case 'd':
-                return ($duration * 86400);
+                return $duration * 86400;
             default:
                 return $duration;
         }
