@@ -1,13 +1,13 @@
 <?php
 
 /*
- * Copyright 2005 - 2020 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -18,23 +18,29 @@
  * For more information : contact@centreon.com
  *
  */
+
 declare(strict_types=1);
 
 namespace Centreon\Application\Controller\Monitoring;
 
-use FOS\RestBundle\View\View;
-use Centreon\Domain\Contact\Contact;
-use Symfony\Component\HttpFoundation\Request;
-use Symfony\Component\HttpFoundation\Response;
-use Centreon\Domain\Exception\EntityNotFoundException;
 use Centreon\Application\Controller\AbstractController;
-use Centreon\Domain\Monitoring\SubmitResult\SubmitResult;
+use Centreon\Domain\Contact\Contact;
+use Centreon\Domain\Exception\EntityNotFoundException;
 use Centreon\Domain\Monitoring\Resource as ResourceEntity;
 use Centreon\Domain\Monitoring\SubmitResult\Interfaces\SubmitResultServiceInterface;
+use Centreon\Domain\Monitoring\SubmitResult\SubmitResult;
 use Exception;
+use FOS\RestBundle\View\View;
+use Symfony\Component\HttpFoundation\Request;
+use Symfony\Component\HttpFoundation\Response;
 
 class SubmitResultController extends AbstractController
 {
+    private const SUBMIT_RESULT_RESOURCES_PAYLOAD_VALIDATION_FILE
+        = __DIR__ . '/../../../../../config/json_validator/latest/Centreon/SubmitResult/SubmitResultResources.json';
+    private const SUBMIT_SINGLE_RESULT_PAYLOAD_VALIDATION_FILE
+        = __DIR__ . '/../../../../../config/json_validator/latest/Centreon/SubmitResult/SubmitResult.json';
+
     /**
      * submitResult
      *
@@ -42,12 +48,6 @@ class SubmitResultController extends AbstractController
      */
     private $submitResultService;
 
-    private const SUBMIT_RESULT_RESOURCES_PAYLOAD_VALIDATION_FILE =
-        __DIR__ . '/../../../../../config/json_validator/latest/Centreon/SubmitResult/SubmitResultResources.json';
-
-    private const SUBMIT_SINGLE_RESULT_PAYLOAD_VALIDATION_FILE =
-        __DIR__ . '/../../../../../config/json_validator/latest/Centreon/SubmitResult/SubmitResult.json';
-
     /**
      * @param SubmitResultServiceInterface $submitResultService
      */
@@ -56,68 +56,32 @@ class SubmitResultController extends AbstractController
         $this->submitResultService = $submitResultService;
     }
 
-    /**
-     * Check if all resources provided can be submitted a result
-     * by the current user.
-     *
-     * @param Contact $contact
-     * @param array<string,mixed> $resources
-     * @return bool
-     */
-    private function hasSubmitResultRightsForResources(Contact $contact, array $resources): bool
-    {
-        if ($contact->isAdmin()) {
-            return true;
-        }
-
-        /**
-         * Retrieving the current submit result rights of the user.
-         */
-        $hasHostRights = $contact->hasRole(Contact::ROLE_HOST_SUBMIT_RESULT);
-        $hasServiceRights = $contact->hasRole(Contact::ROLE_SERVICE_SUBMIT_RESULT);
-
-        foreach ($resources as $resource) {
-            if (
-                ($resource['type'] === ResourceEntity::TYPE_HOST && $hasHostRights)
-                || ($resource['type'] === ResourceEntity::TYPE_SERVICE && $hasServiceRights)
-                || ($resource['type'] === ResourceEntity::TYPE_META && $hasServiceRights)
-            ) {
-                continue;
-            }
-            return false;
-        }
-
-        return true;
-    }
-
     /**
      * Entry point to submit result to multiple hosts.
      *
      * @param Request $request
-     * @return View
-     * @throws \Exception
+     * @throws Exception
      * @throws \InvalidArgumentException
+     * @return View
      */
     public function submitResultResources(
         Request $request
     ): View {
         $this->denyAccessUnlessGrantedForApiRealtime();
         /**
-        * @var Contact $contact
-        */
+         * @var Contact $contact
+         */
         $contact = $this->getUser();
         $this->submitResultService->filterByContact($contact);
 
-       /*
-        * Validate the content of the POST request against the JSON schema validator
-        */
+        // Validate the content of the POST request against the JSON schema validator
         $payload = $this->validateAndRetrieveDataSent($request, self::SUBMIT_RESULT_RESOURCES_PAYLOAD_VALIDATION_FILE);
 
         /**
          * If user has no rights to submit result for host and/or service
          * return view with unauthorized HTTP header response
          */
-        if (!$this->hasSubmitResultRightsForResources($contact, $payload['resources'])) {
+        if (! $this->hasSubmitResultRightsForResources($contact, $payload['resources'])) {
             return $this->view(null, Response::HTTP_UNAUTHORIZED);
         }
 
@@ -150,9 +114,9 @@ class SubmitResultController extends AbstractController
      *
      * @param Request $request
      * @param int $hostId ID of the host
-     * @return View
-     * @throws \Exception
+     * @throws Exception
      * @throws \InvalidArgumentException
+     * @return View
      */
     public function submitResultHost(
         Request $request,
@@ -164,13 +128,11 @@ class SubmitResultController extends AbstractController
          * @var Contact $contact
          */
         $contact = $this->getUser();
-        if (!$contact->isAdmin() && !$contact->hasRole(Contact::ROLE_HOST_SUBMIT_RESULT)) {
+        if (! $contact->isAdmin() && ! $contact->hasRole(Contact::ROLE_HOST_SUBMIT_RESULT)) {
             return $this->view(null, Response::HTTP_UNAUTHORIZED);
         }
 
-       /*
-        * Validate the content of the POST request against the JSON schema validator
-        */
+        // Validate the content of the POST request against the JSON schema validator
         $payload = $this->validateAndRetrieveDataSent($request, self::SUBMIT_SINGLE_RESULT_PAYLOAD_VALIDATION_FILE);
 
         if ($payload !== []) {
@@ -196,9 +158,9 @@ class SubmitResultController extends AbstractController
      * @param Request $request
      * @param int $hostId ID of service parent (host)
      * @param int $serviceId ID of the service
-     * @return View
-     * @throws \Exception
+     * @throws Exception
      * @throws \InvalidArgumentException
+     * @return View
      */
     public function submitResultService(
         Request $request,
@@ -211,13 +173,11 @@ class SubmitResultController extends AbstractController
          * @var Contact $contact
          */
         $contact = $this->getUser();
-        if (!$contact->isAdmin() && !$contact->hasRole(Contact::ROLE_SERVICE_SUBMIT_RESULT)) {
+        if (! $contact->isAdmin() && ! $contact->hasRole(Contact::ROLE_SERVICE_SUBMIT_RESULT)) {
             return $this->view(null, Response::HTTP_UNAUTHORIZED);
         }
 
-       /*
-        * Validate the content of the POST request against the JSON schema validator
-        */
+        // Validate the content of the POST request against the JSON schema validator
         $payload = $this->validateAndRetrieveDataSent($request, self::SUBMIT_SINGLE_RESULT_PAYLOAD_VALIDATION_FILE);
 
         if ($payload !== []) {
@@ -233,4 +193,39 @@ class SubmitResultController extends AbstractController
 
         return $this->view(null, Response::HTTP_NO_CONTENT);
     }
+
+    /**
+     * Check if all resources provided can be submitted a result
+     * by the current user.
+     *
+     * @param Contact $contact
+     * @param array<string,mixed> $resources
+     * @return bool
+     */
+    private function hasSubmitResultRightsForResources(Contact $contact, array $resources): bool
+    {
+        if ($contact->isAdmin()) {
+            return true;
+        }
+
+        /**
+         * Retrieving the current submit result rights of the user.
+         */
+        $hasHostRights = $contact->hasRole(Contact::ROLE_HOST_SUBMIT_RESULT);
+        $hasServiceRights = $contact->hasRole(Contact::ROLE_SERVICE_SUBMIT_RESULT);
+
+        foreach ($resources as $resource) {
+            if (
+                ($resource['type'] === ResourceEntity::TYPE_HOST && $hasHostRights)
+                || ($resource['type'] === ResourceEntity::TYPE_SERVICE && $hasServiceRights)
+                || ($resource['type'] === ResourceEntity::TYPE_META && $hasServiceRights)
+            ) {
+                continue;
+            }
+
+            return false;
+        }
+
+        return true;
+    }
 }
