@@ -128,4 +128,12 @@ interface MonitoringServerRepositoryInterface
      * @param int $monitoringServerId
      */
     public function deleteServer(int $monitoringServerId): void;
+
+    /**
+     * Find remote servers IPs.
+     *
+     * @throws MonitoringServerException
+     * @return string[]
+     */
+    public function findRemoteServersIps(): array;
 }
