@@ -1,66 +1,45 @@
 <?php
+
 /*
- * Copyright 2005-2019 Centreon
- * Centreon is developed by : Julien Mathis and Romain Le Merlus under
- * GPL Licence 2.0.
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
- * This program is free software; you can redistribute it and/or modify it under
- * the terms of the GNU General Public License as published by the Free Software
- * Foundation ; either version 2 of the License.
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
- * This program is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
- * PARTICULAR PURPOSE. See the GNU General Public License for more details.
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
- * You should have received a copy of the GNU General Public License along with
- * this program; if not, see <http://www.gnu.org/licenses>.
- *
- * Linking this program statically or dynamically with other modules is making a
- * combined work based on this program. Thus, the terms and conditions of the GNU
- * General Public License cover the whole combination.
- *
- * As a special exception, the copyright holders of this program give Centreon
- * permission to link this program with independent modules to produce an executable,
- * regardless of the license terms of these independent modules, and to copy and
- * distribute the resulting executable under terms of Centreon choice, provided that
- * Centreon also meet, for each linked independent module, the terms  and conditions
- * of the license of that module. An independent module is a module which is not
- * derived from this program. If you modify this program, you may extend this
- * exception to your version of the program, but you are not obliged to do so. If you
- * do not wish to do so, delete this exception statement from your version.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  *
  * For more information : contact@centreon.com
  *
  */
+
 namespace Centreon\Domain\Service;
 
 use CentreonLegacy\Core\Module\Information;
-use Symfony\Component\Finder\Finder;
 use Symfony\Component\Filesystem\Filesystem;
+use Symfony\Component\Finder\Finder;
 
 /**
  * Class to manage translation of centreon and its extensions
  */
 class I18nService
 {
-    /**
-     * @var Information
-     */
+    /** @var Information */
     private $modulesInformation;
 
-    /**
-     * @var String
-     */
+    /** @var string */
     private $lang;
 
-    /**
-     * @var Finder
-     */
+    /** @var Finder */
     private $finder;
 
-    /**
-     * @var Filesystem
-     */
+    /** @var Filesystem */
     private $filesystem;
 
     /**
@@ -76,20 +55,6 @@ class I18nService
         $this->filesystem = $filesystem;
     }
 
-    /**
-     * Initialize lang object to bind language
-     *
-     * @return void
-     */
-    private function initLang(): void
-    {
-        $this->lang = getenv('LANG');
-
-        if (!str_contains($this->lang, '.UTF-8')) {
-            $this->lang .= '.UTF-8';
-        }
-    }
-
     /**
      * Get translation from centreon and its extensions
      *
@@ -104,7 +69,34 @@ class I18nService
     }
 
     /**
-     * Get translation from centreon
+     * Get all translations fron Centreon and its modules
+     *
+     * @return array
+     */
+    public function getAllTranslations(): array
+    {
+        $centreonTranslation = $this->getAllCentreonTranslation();
+        $modulesTranslation = $this->getAllModulesTranslation();
+
+        return array_replace_recursive($centreonTranslation, $modulesTranslation);
+    }
+
+    /**
+     * Initialize lang object to bind language
+     *
+     * @return void
+     */
+    private function initLang(): void
+    {
+        $this->lang = getenv('LANG');
+
+        if (! str_contains($this->lang, '.UTF-8')) {
+            $this->lang .= '.UTF-8';
+        }
+    }
+
+    /**
+     * Get all translations from centreon
      *
      * @return array
      */
@@ -113,9 +105,9 @@ class I18nService
         $data = [];
 
         $translationPath = __DIR__ . "/../../../../www/locale/{$this->lang}/LC_MESSAGES";
-        $translationFile = "messages.ser";
+        $translationFile = 'messages.ser';
 
-        if ($this->filesystem->exists($translationPath . "/" . $translationFile)) {
+        if ($this->filesystem->exists($translationPath . '/' . $translationFile)) {
             $files = $this->finder
                 ->name($translationFile)
                 ->in($translationPath);
@@ -128,6 +120,35 @@ class I18nService
         return $data;
     }
 
+    /**
+     * Get translation from centreon
+     *
+     * @return array
+     */
+    private function getAllCentreonTranslation(): array
+    {
+        $data = [];
+
+        $languages = ['fr_FR.UTF-8', 'de_DE.UTF-8', 'es_ES.UTF-8', 'pt-PT.UTF-8', 'pt_BR.UTF-8'];
+
+        foreach ($languages as $language) {
+            $translationPath = __DIR__ . "/../../../../www/locale/{$language}/LC_MESSAGES";
+            $translationFile = 'messages.ser';
+
+            if ($this->filesystem->exists($translationPath . '/' . $translationFile)) {
+                $files = $this->finder
+                    ->name($translationFile)
+                    ->in($translationPath);
+
+                foreach ($files as $file) {
+                    $data += unserialize($file->getContents());
+                }
+            }
+        }
+
+        return $data;
+    }
+
     /**
      * Get translation from each installed module
      *
@@ -140,9 +161,9 @@ class I18nService
         // loop over each installed modules to get translation
         foreach (array_keys($this->modulesInformation->getInstalledList()) as $module) {
             $translationPath = __DIR__ . "/../../../../www/modules/{$module}/locale/{$this->lang}/LC_MESSAGES";
-            $translationFile = "messages.ser";
+            $translationFile = 'messages.ser';
 
-            if ($this->filesystem->exists($translationPath . "/" . $translationFile)) {
+            if ($this->filesystem->exists($translationPath . '/' . $translationFile)) {
                 $files = $this->finder
                     ->name($translationFile)
                     ->in($translationPath);
@@ -158,4 +179,39 @@ class I18nService
 
         return $data;
     }
+
+    /**
+     * Get all translation from each installed module
+     *
+     * @return array
+     */
+    private function getAllModulesTranslation(): array
+    {
+        $data = [];
+
+        $languages = ['fr_FR.UTF-8', 'de_DE.UTF-8', 'es_ES.UTF-8', 'pt-PT.UTF-8', 'pt_BR.UTF-8'];
+
+        foreach ($languages as $language) {
+            // loop over each installed modules to get translation
+            foreach (array_keys($this->modulesInformation->getInstalledList()) as $module) {
+                $translationPath = __DIR__ . "/../../../../www/modules/{$module}/locale/{$language}/LC_MESSAGES";
+                $translationFile = 'messages.ser';
+
+                if ($this->filesystem->exists($translationPath . '/' . $translationFile)) {
+                    $files = $this->finder
+                        ->name($translationFile)
+                        ->in($translationPath);
+
+                    foreach ($files as $file) {
+                        $data += array_replace_recursive(
+                            $data,
+                            unserialize($file->getContents())
+                        );
+                    }
+                }
+            }
+        }
+
+        return $data;
+    }
 }
