@@ -75,7 +75,7 @@ final class AcknowledgementRepositoryRDB extends AbstractRepositoryDRB implement
      */
     public function __construct(
         DatabaseConnection $db,
-        SqlRequestParametersTranslator $sqlRequestTranslator,
+        SqlRequestParametersTranslator $sqlRequestTranslator
     ) {
         $this->db = $db;
         $this->sqlRequestTranslator = $sqlRequestTranslator;
@@ -379,7 +379,8 @@ final class AcknowledgementRepositoryRDB extends AbstractRepositoryDRB implement
             ? ' '
             : ' INNER JOIN `:dbstg`.`centreon_acl` acl
                   ON acl.host_id = ack.host_id'
-                . (($type === Acknowledgement::TYPE_SERVICE_ACKNOWLEDGEMENT)
+                . (
+                    ($type === Acknowledgement::TYPE_SERVICE_ACKNOWLEDGEMENT)
                     ? ' AND acl.service_id = ack.service_id '
                     : ''
                 )
