@@ -1,13 +1,13 @@
 <?php
 
 /*
- * Copyright 2005 - 2021 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -18,17 +18,16 @@
  * For more information : contact@centreon.com
  *
  */
+
 declare(strict_types=1);
 
 namespace Centreon\Infrastructure\Contact;
 
-use Assert\AssertionFailedException;
 use Centreon\Domain\Contact\Contact;
 use Centreon\Domain\Contact\Interfaces\ContactRepositoryInterface;
 use Centreon\Domain\Menu\Model\Page;
 use Centreon\Infrastructure\DatabaseConnection;
 use Core\Common\Infrastructure\Repository\SqlMultipleBindTrait;
-use Core\Security\AccessGroup\Domain\Model\AccessGroup;
 
 /**
  * Database repository for the contacts.
@@ -39,9 +38,7 @@ final class ContactRepositoryRDB implements ContactRepositoryInterface
 {
     use SqlMultipleBindTrait;
 
-    /**
-     * @var DatabaseConnection
-     */
+    /** @var DatabaseConnection */
     private $db;
 
     /**
@@ -186,7 +183,6 @@ final class ContactRepositoryRDB implements ContactRepositoryInterface
         return $contact;
     }
 
-
     /**
      * @inheritDoc
      *
@@ -230,6 +226,23 @@ final class ContactRepositoryRDB implements ContactRepositoryInterface
         return $contact;
     }
 
+    /**
+     * Replace all instances of :dbstg and :db by the real db names.
+     * The table names of the database are defined in the services.yaml
+     * configuration file.
+     *
+     * @param string $request Request to translate
+     * @return string Request translated
+     */
+    protected function translateDbName(string $request): string
+    {
+        return str_replace(
+            [':dbstg', ':db'],
+            [$this->db->getConnectionConfig()->getDatabaseNameRealTime(), $this->db->getConnectionConfig()->getDatabaseNameConfiguration()],
+            $request
+        );
+    }
+
     /**
      * Find and add all topology rules defined by all menus access defined for this contact.
      * The purpose is to limit access to the API based on menus access.
@@ -238,8 +251,8 @@ final class ContactRepositoryRDB implements ContactRepositoryInterface
      */
     private function addTopologyRules(Contact $contact): void
     {
-        $topologySubquery =
-            $contact->isAdmin()
+        $topologySubquery
+            = $contact->isAdmin()
             ? 'SELECT topology.topology_id, 1 AS access_right
                 FROM `:db`.topology'
             : 'SELECT topology.topology_id, acltr.access_right
@@ -259,8 +272,8 @@ final class ContactRepositoryRDB implements ContactRepositoryInterface
                     ON topology.topology_id = acltr.topology_topology_id
                 WHERE contact.contact_id = :contact_id';
 
-        $request =
-            'SELECT topology.topology_name, topology.topology_page,
+        $request
+            = 'SELECT topology.topology_name, topology.topology_page,
                     topology.topology_parent, access.access_right
             FROM `:db`.topology
             LEFT JOIN (' . $topologySubquery . ') AS access
@@ -281,7 +294,7 @@ final class ContactRepositoryRDB implements ContactRepositoryInterface
         while ($row = $prepare->fetch(\PDO::FETCH_ASSOC)) {
             $topologies[$row['topology_page']] = [
                 'name' => $row['topology_name'],
-                'right' => (int) $row['access_right']
+                'right' => (int) $row['access_right'],
             ];
             if ($row['access_right'] !== null) {
                 $rightsCounter++;
@@ -351,8 +364,8 @@ final class ContactRepositoryRDB implements ContactRepositoryInterface
      */
     private function addActionRules(Contact $contact): void
     {
-        $request =
-            'SELECT DISTINCT rules.acl_action_name
+        $request
+            = 'SELECT DISTINCT rules.acl_action_name
             FROM `:db`.contact contact
             LEFT JOIN `:db`.contactgroup_contact_relation cgcr
                 ON cgcr.contact_contact_id = contact.contact_id
@@ -432,11 +445,11 @@ final class ContactRepositoryRDB implements ContactRepositoryInterface
      */
     private function createContact(array $contact): Contact
     {
-        $contactTimezoneName = !empty($contact['timezone_name'])
+        $contactTimezoneName = ! empty($contact['timezone_name'])
             ? $contact['timezone_name']
             : $this->getDefaultTimezone();
 
-        $contactLocale = !empty($contact['contact_lang'])
+        $contactLocale = ! empty($contact['contact_lang'])
             ? $this->parseLocaleFromContactLang($contact['contact_lang'])
             : null;
 
@@ -448,7 +461,7 @@ final class ContactRepositoryRDB implements ContactRepositoryInterface
                 (int) $contact['default_page'],
                 (bool) $contact['is_react']
             );
-            if (!empty($contact['topology_url_opt'])) {
+            if (! empty($contact['topology_url_opt'])) {
                 $page->setUrlOptions($contact['topology_url_opt']);
             }
         }
@@ -471,6 +484,7 @@ final class ContactRepositoryRDB implements ContactRepositoryInterface
             ->setLocale($contactLocale)
             ->setDefaultPage($page)
             ->setUseDeprecatedPages($contact['show_deprecated_pages'] === '1')
+            ->setUseDeprecatedCustomViews($contact['show_deprecated_custom_views'] === '1')
             ->setTheme($contact['contact_theme'])
             ->setUserInterfaceDensity($contact['user_interface_density']);
 
@@ -549,29 +563,19 @@ final class ContactRepositoryRDB implements ContactRepositoryInterface
                 break;
             case 'manage_tokens':
                 $contact->addRole(Contact::ROLE_MANAGE_TOKENS);
+                // no break
             case 'create_edit_poller_cfg':
                 $contact->addRole(Contact::ROLE_CREATE_EDIT_POLLER_CFG);
                 break;
             case 'delete_poller_cfg':
                 $contact->addRole(Contact::ROLE_DELETE_POLLER_CFG);
                 break;
+            case 'top_counter':
+                $contact->addRole(Contact::ROLE_DISPLAY_TOP_COUNTER);
+                break;
+            case 'poller_stats':
+                $contact->addRole(Contact::ROLE_DISPLAY_TOP_COUNTER_POLLERS_STATISTICS);
+                break;
         }
     }
-
-    /**
-     * Replace all instances of :dbstg and :db by the real db names.
-     * The table names of the database are defined in the services.yaml
-     * configuration file.
-     *
-     * @param string $request Request to translate
-     * @return string Request translated
-     */
-    protected function translateDbName(string $request): string
-    {
-        return str_replace(
-            [':dbstg', ':db'],
-            [$this->db->getStorageDbName(), $this->db->getCentreonDbName()],
-            $request
-        );
-    }
 }
