@@ -1,13 +1,13 @@
 <?php
 
 /*
- * Copyright 2005 - 2019 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -18,6 +18,7 @@
  * For more information : contact@centreon.com
  *
  */
+
 declare(strict_types=1);
 
 namespace Centreon\Infrastructure\Downtime;
@@ -25,10 +26,10 @@ namespace Centreon\Infrastructure\Downtime;
 use Centreon\Domain\Downtime\Downtime;
 use Centreon\Domain\Downtime\Interfaces\DowntimeRepositoryInterface;
 use Centreon\Domain\Entity\EntityCreator;
-use Core\Security\AccessGroup\Domain\Model\AccessGroup;
 use Centreon\Infrastructure\DatabaseConnection;
 use Centreon\Infrastructure\Repository\AbstractRepositoryDRB;
 use Centreon\Infrastructure\RequestParameters\SqlRequestParametersTranslator;
+use Core\Security\AccessGroup\Domain\Model\AccessGroup;
 
 /**
  * Downtime repository for MySQL
@@ -37,18 +38,13 @@ use Centreon\Infrastructure\RequestParameters\SqlRequestParametersTranslator;
  */
 class DowntimeRepositoryRDB extends AbstractRepositoryDRB implements DowntimeRepositoryInterface
 {
-    /**
-     * @var SqlRequestParametersTranslator
-     */
+    /** @var SqlRequestParametersTranslator */
     private $sqlRequestTranslator;
 
-    /**
-     * @var AccessGroup[] List of access group used to filter the requests
-     */
+    /** @var AccessGroup[] List of access group used to filter the requests */
     private $accessGroups;
-    /**
-     * @var array<string, string>
-     */
+
+    /** @var array<string, string> */
     private $downtimeConcordanceArray = [
         // Relation for downtime
         'id' => 'dwt.downtime_id',
@@ -88,6 +84,7 @@ class DowntimeRepositoryRDB extends AbstractRepositoryDRB implements DowntimeRep
     public function forAccessGroups(array $accessGroups): DowntimeRepositoryInterface
     {
         $this->accessGroups = $accessGroups;
+
         return $this;
     }
 
@@ -114,50 +111,6 @@ class DowntimeRepositoryRDB extends AbstractRepositoryDRB implements DowntimeRep
         return $this->findHostDowntimes(true);
     }
 
-    /**
-     * @return bool Return TRUE if the contact is an admin or has at least one access group.
-     */
-    private function hasNotEnoughRightsToContinue(): bool
-    {
-        return count($this->accessGroups) == 0;
-    }
-
-    /**
-     * @param bool $isAdmin Indicates whether user is an admin
-     * @return Downtime[]
-     * @throws \Exception
-     */
-    private function findHostDowntimes(bool $isAdmin = false): array
-    {
-        $this->sqlRequestTranslator->setConcordanceArray($this->downtimeConcordanceArray);
-
-        $aclRequest = '';
-
-        if ($isAdmin === false) {
-            $aclRequest =
-                ' INNER JOIN `:dbstg`.`centreon_acl` acl
-                  ON acl.host_id = dwt.host_id
-                  AND acl.service_id IS NULL
-                INNER JOIN `:db`.`acl_groups` acg
-                  ON acg.acl_group_id = acl.group_id
-                  AND acg.acl_group_activate = \'1\'
-                  AND acg.acl_group_id IN ('
-                    . $this->accessGroupIdToString($this->accessGroups) . ')';
-        }
-
-        $request =
-            'SELECT SQL_CALC_FOUND_ROWS DISTINCT dwt.*, contact.contact_id AS author_id
-            FROM `:dbstg`.downtimes dwt
-            INNER JOIN `:dbstg`.hosts
-                ON hosts.host_id = dwt.host_id
-                AND dwt.service_id = 0
-            LEFT JOIN `:db`.`contact`
-                ON contact.contact_alias = dwt.author'
-            . $aclRequest;
-
-        return $this->processRequest($request);
-    }
-
     /**
      * @inheritDoc
      */
@@ -180,54 +133,6 @@ class DowntimeRepositoryRDB extends AbstractRepositoryDRB implements DowntimeRep
         return $this->findOneDowntime($downtimeId, false);
     }
 
-    /**
-     * Find one downtime linked to a host tacking into account or not the ACLs of host.
-     *
-     * @param int $downtimeId Downtime id
-     * @param bool $isAdmin Indicates whether user is an admin
-     * @return Downtime|null Return NULL if the downtime has not been found
-     * @throws \Exception
-     */
-    private function findOneDowntime(int $downtimeId, bool $isAdmin = false): ?Downtime
-    {
-        $aclRequest = '';
-
-        if ($isAdmin === false) {
-            $aclRequest =
-                ' INNER JOIN `:dbstg`.`centreon_acl` acl
-                  ON acl.host_id = dwt.host_id
-                  AND (acl.service_id = dwt.service_id OR acl.service_id IS NULL)
-                INNER JOIN `:db`.`acl_groups` acg
-                  ON acg.acl_group_id = acl.group_id
-                  AND acg.acl_group_activate = \'1\'
-                  AND acg.acl_group_id IN ('
-                . $this->accessGroupIdToString($this->accessGroups) . ')';
-        }
-
-        $request =
-            'SELECT SQL_CALC_FOUND_ROWS DISTINCT dwt.*, contact.contact_id AS author_id
-            FROM `:dbstg`.downtimes dwt
-            LEFT JOIN `:db`.`contact`
-                ON contact.contact_alias = dwt.author'
-            . $aclRequest
-            . ' WHERE dwt.downtime_id = :downtime_id';
-
-        $request = $this->translateDbName($request);
-
-        $prepare = $this->db->prepare($request);
-        $prepare->bindValue(':downtime_id', $downtimeId, \PDO::PARAM_INT);
-        $prepare->execute();
-
-        if (false !== ($row = $prepare->fetch(\PDO::FETCH_ASSOC))) {
-            return EntityCreator::createEntityByArray(
-                Downtime::class,
-                $row
-            );
-        } else {
-            return null;
-        }
-    }
-
     /**
      * @inheritDoc
      */
@@ -250,69 +155,6 @@ class DowntimeRepositoryRDB extends AbstractRepositoryDRB implements DowntimeRep
         return $this->findDowntimes(false);
     }
 
-    /**
-     * Find all downtimes.
-     *
-     * @param bool $isAdmin Indicates whether user is an admin
-     * @return Downtime[]
-     * @throws \Exception
-     */
-    private function findDowntimes(bool $isAdmin): array
-    {
-        $serviceConcordanceArray = [
-            // Relation for service
-            'service.id' => 'srv.service_id',
-            'service.display_name' => 'srv.display_name'
-        ];
-
-        /*
-         * If the search parameters contain at least one key corresponding to the services, we must:
-         *  1. taking into account the search for service
-         *  2. add the join to the services table
-         */
-        $downtimeConcordanceArray = $this->downtimeConcordanceArray;
-        $searchParameters = $this->sqlRequestTranslator->getRequestParameters()->extractSearchNames();
-        $shouldJoinService = false;
-        if (array_intersect($searchParameters, array_keys($serviceConcordanceArray)) !== []) {
-            $shouldJoinService = true;
-            $downtimeConcordanceArray = array_merge($downtimeConcordanceArray, $serviceConcordanceArray);
-        }
-
-        $this->sqlRequestTranslator->setConcordanceArray($downtimeConcordanceArray);
-
-        $aclRequest = '';
-
-        if ($isAdmin === false) {
-            $aclRequest =
-                ' INNER JOIN `:dbstg`.`centreon_acl` acl
-                  ON acl.host_id = dwt.host_id
-                  AND (acl.service_id = dwt.service_id OR acl.service_id IS NULL)
-                INNER JOIN `:db`.`acl_groups` acg
-                  ON acg.acl_group_id = acl.group_id
-                  AND acg.acl_group_activate = \'1\'
-                  AND acg.acl_group_id IN ('
-                . $this->accessGroupIdToString($this->accessGroups) . ') ';
-        }
-
-        $serviceRequest = ($shouldJoinService)
-            ? ' INNER JOIN `:dbstg`.services srv
-                 ON srv.service_id = dwt.service_id
-                 AND srv.host_id = hosts.host_id '
-            : '';
-
-        $request =
-            'SELECT SQL_CALC_FOUND_ROWS DISTINCT dwt.*, contact.contact_id AS author_id
-            FROM `:dbstg`.downtimes dwt
-            LEFT JOIN `:db`.`contact`
-              ON contact.contact_alias = dwt.author
-            INNER JOIN `:dbstg`.hosts
-              ON hosts.host_id = dwt.host_id'
-            . $serviceRequest
-            . $aclRequest;
-
-        return $this->processRequest($request);
-    }
-
     /**
      * @inheritDoc
      */
@@ -335,68 +177,6 @@ class DowntimeRepositoryRDB extends AbstractRepositoryDRB implements DowntimeRep
         return $this->findDowntimesByHost($hostId, $withServices, false);
     }
 
-    /**
-     * Find all downtimes for a host.
-     *
-     * @param int $hostId Host id for which we want to find downtimes.
-     * @param bool $withServices
-     * @param bool $isAdmin Indicates whether user is an admin
-     * @return Downtime[]
-     * @throws \Exception
-     */
-    private function findDowntimesByHost(int $hostId, bool $withServices, bool $isAdmin = false): array
-    {
-        $concordanceArray = [
-            // Relation for downtime
-            'id' => 'dwt.downtime_id',
-            'entry_time' => 'dwt.entry_time',
-            'is_cancelled' => 'dwt.cancelled',
-            'comment' => 'dwt.comment_data',
-            'deletion_time' => 'dwt.deletion_time',
-            'duration' => 'dwt.duration',
-            'end_time' => 'dwt.end_time',
-            'is_fixed' => 'dwt.fixed',
-            'start_time' => 'dwt.start_time',
-            // Relation for contact
-            'contact.id' => 'contact.contact_id',
-            'contact.name' => 'contact.contact_name',
-        ];
-
-        $this->sqlRequestTranslator->setConcordanceArray($concordanceArray);
-
-        $aclRequest = '';
-
-        if ($isAdmin === false) {
-            $aclRequest =
-                ' INNER JOIN `:dbstg`.`centreon_acl` acl
-                  ON acl.host_id = dwt.host_id'
-                . ($withServices ? '' : ' AND acl.service_id IS NULL')
-                . ' INNER JOIN `:db`.`acl_groups` acg
-                  ON acg.acl_group_id = acl.group_id
-                  AND acg.acl_group_activate = \'1\'
-                  AND acg.acl_group_id IN ('
-                . $this->accessGroupIdToString($this->accessGroups) . ')';
-        }
-
-        $request =
-            'SELECT SQL_CALC_FOUND_ROWS DISTINCT dwt.*, contact.contact_id AS author_id
-            FROM `:dbstg`.downtimes dwt
-            LEFT JOIN `:db`.`contact`
-                ON contact.contact_alias = dwt.author
-            INNER JOIN `:dbstg`.hosts
-              ON hosts.host_id = dwt.host_id
-              AND dwt.host_id = :host_id'
-                . ($withServices ? '' : ' AND dwt.service_id = 0')
-            . $aclRequest;
-
-        $this->sqlRequestTranslator->addSearchValue(
-            ':host_id',
-            [\PDO::PARAM_INT => $hostId]
-        );
-
-        return $this->processRequest($request);
-    }
-
     /**
      * @inheritDoc
      */
@@ -419,46 +199,6 @@ class DowntimeRepositoryRDB extends AbstractRepositoryDRB implements DowntimeRep
         return $this->findServicesDowntimes(true);
     }
 
-    /**
-     * Find all downtimes of all services.
-     *
-     * @param bool $isAdmin $isAdmin Indicates whether user is an admin
-     * @return Downtime[]
-     * @throws \Exception
-     */
-    private function findServicesDowntimes(bool $isAdmin): array
-    {
-        $this->sqlRequestTranslator->setConcordanceArray($this->downtimeConcordanceArray);
-
-        $aclRequest = '';
-
-        if ($isAdmin === false) {
-            $aclRequest =
-                ' INNER JOIN `:dbstg`.`centreon_acl` acl
-                  ON acl.host_id = dwt.host_id
-                  AND acl.service_id = dwt.service_id
-                INNER JOIN `:db`.`acl_groups` acg
-                  ON acg.acl_group_id = acl.group_id
-                  AND acg.acl_group_activate = \'1\'
-                  AND acg.acl_group_id IN ('
-                . $this->accessGroupIdToString($this->accessGroups) . ')';
-        }
-
-        $request =
-            'SELECT SQL_CALC_FOUND_ROWS DISTINCT dwt.*, contact.contact_id AS author_id
-            FROM `:dbstg`.downtimes dwt
-            INNER JOIN `:dbstg`.hosts
-                ON hosts.host_id = dwt.host_id
-            INNER JOIN `:dbstg`.services srv
-                ON srv.service_id = dwt.service_id
-                AND srv.host_id = hosts.host_id
-            LEFT JOIN `:db`.`contact`
-                ON contact.contact_alias = dwt.author'
-            . $aclRequest;
-
-        return $this->processRequest($request);
-    }
-
     /**
      * @inheritDoc
      */
@@ -481,14 +221,271 @@ class DowntimeRepositoryRDB extends AbstractRepositoryDRB implements DowntimeRep
         return $this->findDowntimesByService($hostId, $serviceId, true);
     }
 
+    /**
+     * @return bool return TRUE if the contact is an admin or has at least one access group
+     */
+    private function hasNotEnoughRightsToContinue(): bool
+    {
+        return count($this->accessGroups) == 0;
+    }
+
+    /**
+     * @param bool $isAdmin Indicates whether user is an admin
+     * @throws \Exception
+     * @return Downtime[]
+     */
+    private function findHostDowntimes(bool $isAdmin = false): array
+    {
+        $this->sqlRequestTranslator->setConcordanceArray($this->downtimeConcordanceArray);
+
+        $aclRequest = '';
+
+        if ($isAdmin === false) {
+            $aclRequest
+                = ' INNER JOIN `:dbstg`.`centreon_acl` acl
+                  ON acl.host_id = dwt.host_id
+                  AND acl.service_id IS NULL
+                INNER JOIN `:db`.`acl_groups` acg
+                  ON acg.acl_group_id = acl.group_id
+                  AND acg.acl_group_activate = \'1\'
+                  AND acg.acl_group_id IN ('
+                    . $this->accessGroupIdToString($this->accessGroups) . ')';
+        }
+
+        $request
+            = 'SELECT SQL_CALC_FOUND_ROWS DISTINCT dwt.*, contact.contact_id AS author_id
+            FROM `:dbstg`.downtimes dwt
+            INNER JOIN `:dbstg`.hosts
+                ON hosts.host_id = dwt.host_id
+                AND dwt.service_id = 0
+            LEFT JOIN `:db`.`contact`
+                ON contact.contact_alias = dwt.author'
+            . $aclRequest;
+
+        return $this->processRequest($request);
+    }
+
+    /**
+     * Find one downtime linked to a host tacking into account or not the ACLs of host.
+     *
+     * @param int $downtimeId Downtime id
+     * @param bool $isAdmin Indicates whether user is an admin
+     * @throws \Exception
+     * @return Downtime|null Return NULL if the downtime has not been found
+     */
+    private function findOneDowntime(int $downtimeId, bool $isAdmin = false): ?Downtime
+    {
+        $aclRequest = '';
+
+        if ($isAdmin === false) {
+            $aclRequest
+                = ' INNER JOIN `:dbstg`.`centreon_acl` acl
+                  ON acl.host_id = dwt.host_id
+                  AND (acl.service_id = dwt.service_id OR acl.service_id IS NULL)
+                INNER JOIN `:db`.`acl_groups` acg
+                  ON acg.acl_group_id = acl.group_id
+                  AND acg.acl_group_activate = \'1\'
+                  AND acg.acl_group_id IN ('
+                . $this->accessGroupIdToString($this->accessGroups) . ')';
+        }
+
+        $request
+            = 'SELECT SQL_CALC_FOUND_ROWS DISTINCT dwt.*, contact.contact_id AS author_id
+            FROM `:dbstg`.downtimes dwt
+            LEFT JOIN `:db`.`contact`
+                ON contact.contact_alias = dwt.author'
+            . $aclRequest
+            . ' WHERE dwt.downtime_id = :downtime_id';
+
+        $request = $this->translateDbName($request);
+
+        $prepare = $this->db->prepare($request);
+        $prepare->bindValue(':downtime_id', $downtimeId, \PDO::PARAM_INT);
+        $prepare->execute();
+
+        if (false !== ($row = $prepare->fetch(\PDO::FETCH_ASSOC))) {
+            return EntityCreator::createEntityByArray(
+                Downtime::class,
+                $row
+            );
+        }
+
+        return null;
+    }
+
+    /**
+     * Find all downtimes.
+     *
+     * @param bool $isAdmin Indicates whether user is an admin
+     * @throws \Exception
+     * @return Downtime[]
+     */
+    private function findDowntimes(bool $isAdmin): array
+    {
+        $serviceConcordanceArray = [
+            // Relation for service
+            'service.id' => 'srv.service_id',
+            'service.display_name' => 'srv.display_name',
+        ];
+
+        /*
+         * If the search parameters contain at least one key corresponding to the services, we must:
+         *  1. taking into account the search for service
+         *  2. add the join to the services table
+         */
+        $downtimeConcordanceArray = $this->downtimeConcordanceArray;
+        $searchParameters = $this->sqlRequestTranslator->getRequestParameters()->extractSearchNames();
+        $shouldJoinService = false;
+        if (array_intersect($searchParameters, array_keys($serviceConcordanceArray)) !== []) {
+            $shouldJoinService = true;
+            $downtimeConcordanceArray = array_merge($downtimeConcordanceArray, $serviceConcordanceArray);
+        }
+
+        $this->sqlRequestTranslator->setConcordanceArray($downtimeConcordanceArray);
+
+        $aclRequest = '';
+
+        if ($isAdmin === false) {
+            $aclRequest
+                = ' INNER JOIN `:dbstg`.`centreon_acl` acl
+                  ON acl.host_id = dwt.host_id
+                  AND (acl.service_id = dwt.service_id OR acl.service_id IS NULL)
+                INNER JOIN `:db`.`acl_groups` acg
+                  ON acg.acl_group_id = acl.group_id
+                  AND acg.acl_group_activate = \'1\'
+                  AND acg.acl_group_id IN ('
+                . $this->accessGroupIdToString($this->accessGroups) . ') ';
+        }
+
+        $serviceRequest = ($shouldJoinService)
+            ? ' INNER JOIN `:dbstg`.services srv
+                 ON srv.service_id = dwt.service_id
+                 AND srv.host_id = hosts.host_id '
+            : '';
+
+        $request
+            = 'SELECT SQL_CALC_FOUND_ROWS DISTINCT dwt.*, contact.contact_id AS author_id
+            FROM `:dbstg`.downtimes dwt
+            LEFT JOIN `:db`.`contact`
+              ON contact.contact_alias = dwt.author
+            INNER JOIN `:dbstg`.hosts
+              ON hosts.host_id = dwt.host_id'
+            . $serviceRequest
+            . $aclRequest;
+
+        return $this->processRequest($request);
+    }
+
+    /**
+     * Find all downtimes for a host.
+     *
+     * @param int $hostId host id for which we want to find downtimes
+     * @param bool $withServices
+     * @param bool $isAdmin Indicates whether user is an admin
+     * @throws \Exception
+     * @return Downtime[]
+     */
+    private function findDowntimesByHost(int $hostId, bool $withServices, bool $isAdmin = false): array
+    {
+        $concordanceArray = [
+            // Relation for downtime
+            'id' => 'dwt.downtime_id',
+            'entry_time' => 'dwt.entry_time',
+            'is_cancelled' => 'dwt.cancelled',
+            'comment' => 'dwt.comment_data',
+            'deletion_time' => 'dwt.deletion_time',
+            'duration' => 'dwt.duration',
+            'end_time' => 'dwt.end_time',
+            'is_fixed' => 'dwt.fixed',
+            'start_time' => 'dwt.start_time',
+            // Relation for contact
+            'contact.id' => 'contact.contact_id',
+            'contact.name' => 'contact.contact_name',
+        ];
+
+        $this->sqlRequestTranslator->setConcordanceArray($concordanceArray);
+
+        $aclRequest = '';
+
+        if ($isAdmin === false) {
+            $aclRequest
+                = ' INNER JOIN `:dbstg`.`centreon_acl` acl
+                  ON acl.host_id = dwt.host_id'
+                . ($withServices ? '' : ' AND acl.service_id IS NULL')
+                . ' INNER JOIN `:db`.`acl_groups` acg
+                  ON acg.acl_group_id = acl.group_id
+                  AND acg.acl_group_activate = \'1\'
+                  AND acg.acl_group_id IN ('
+                . $this->accessGroupIdToString($this->accessGroups) . ')';
+        }
+
+        $request
+            = 'SELECT SQL_CALC_FOUND_ROWS DISTINCT dwt.*, contact.contact_id AS author_id
+            FROM `:dbstg`.downtimes dwt
+            LEFT JOIN `:db`.`contact`
+                ON contact.contact_alias = dwt.author
+            INNER JOIN `:dbstg`.hosts
+              ON hosts.host_id = dwt.host_id
+              AND dwt.host_id = :host_id'
+                . ($withServices ? '' : ' AND dwt.service_id = 0')
+            . $aclRequest;
+
+        $this->sqlRequestTranslator->addSearchValue(
+            ':host_id',
+            [\PDO::PARAM_INT => $hostId]
+        );
+
+        return $this->processRequest($request);
+    }
+
+    /**
+     * Find all downtimes of all services.
+     *
+     * @param bool $isAdmin $isAdmin Indicates whether user is an admin
+     * @throws \Exception
+     * @return Downtime[]
+     */
+    private function findServicesDowntimes(bool $isAdmin): array
+    {
+        $this->sqlRequestTranslator->setConcordanceArray($this->downtimeConcordanceArray);
+
+        $aclRequest = '';
+
+        if ($isAdmin === false) {
+            $aclRequest
+                = ' INNER JOIN `:dbstg`.`centreon_acl` acl
+                  ON acl.host_id = dwt.host_id
+                  AND acl.service_id = dwt.service_id
+                INNER JOIN `:db`.`acl_groups` acg
+                  ON acg.acl_group_id = acl.group_id
+                  AND acg.acl_group_activate = \'1\'
+                  AND acg.acl_group_id IN ('
+                . $this->accessGroupIdToString($this->accessGroups) . ')';
+        }
+
+        $request
+            = 'SELECT SQL_CALC_FOUND_ROWS DISTINCT dwt.*, contact.contact_id AS author_id
+            FROM `:dbstg`.downtimes dwt
+            INNER JOIN `:dbstg`.hosts
+                ON hosts.host_id = dwt.host_id
+            INNER JOIN `:dbstg`.services srv
+                ON srv.service_id = dwt.service_id
+                AND srv.host_id = hosts.host_id
+            LEFT JOIN `:db`.`contact`
+                ON contact.contact_alias = dwt.author'
+            . $aclRequest;
+
+        return $this->processRequest($request);
+    }
+
     /**
      *  Find all downtimes for a service (linked to a host).
      *
      * @param int $hostId Host id linked to this service
      * @param int $serviceId Service id for which we want to find downtimes
      * @param bool $isAdmin Indicates whether user is an admin
-     * @return Downtime[]
      * @throws \Exception
+     * @return Downtime[]
      */
     private function findDowntimesByService(int $hostId, int $serviceId, bool $isAdmin): array
     {
@@ -510,8 +507,8 @@ class DowntimeRepositoryRDB extends AbstractRepositoryDRB implements DowntimeRep
         $aclRequest = '';
 
         if ($isAdmin === false) {
-            $aclRequest =
-                ' INNER JOIN `:dbstg`.`centreon_acl` acl
+            $aclRequest
+                = ' INNER JOIN `:dbstg`.`centreon_acl` acl
                   ON acl.host_id = dwt.host_id
                   AND acl.service_id = dwt.service_id
                 INNER JOIN `:db`.`acl_groups` acg
@@ -521,8 +518,8 @@ class DowntimeRepositoryRDB extends AbstractRepositoryDRB implements DowntimeRep
                 . $this->accessGroupIdToString($this->accessGroups) . ')';
         }
 
-        $request =
-            'SELECT SQL_CALC_FOUND_ROWS DISTINCT dwt.*, contact.contact_id AS author_id
+        $request
+            = 'SELECT SQL_CALC_FOUND_ROWS DISTINCT dwt.*, contact.contact_id AS author_id
             FROM `:dbstg`.downtimes dwt
             INNER JOIN `:dbstg`.hosts
                 ON hosts.host_id = dwt.host_id
@@ -537,6 +534,7 @@ class DowntimeRepositoryRDB extends AbstractRepositoryDRB implements DowntimeRep
 
         $this->sqlRequestTranslator->addSearchValue(':host_id', [\PDO::PARAM_INT => $hostId]);
         $this->sqlRequestTranslator->addSearchValue(':service_id', [\PDO::PARAM_INT => $serviceId]);
+
         return $this->processRequest($request);
     }
 
@@ -544,8 +542,8 @@ class DowntimeRepositoryRDB extends AbstractRepositoryDRB implements DowntimeRep
      * Execute the request and retrieve the downtimes list
      *
      * @param string $request Request to execute
-     * @return Downtime[]
      * @throws \Exception
+     * @return Downtime[]
      */
     private function processRequest(string $request): array
     {
@@ -553,11 +551,11 @@ class DowntimeRepositoryRDB extends AbstractRepositoryDRB implements DowntimeRep
 
         // Search
         $searchRequest = $this->sqlRequestTranslator->translateSearchParameterToSql();
-        $request .= !is_null($searchRequest) ? $searchRequest : '';
+        $request .= ! is_null($searchRequest) ? $searchRequest : '';
 
         // Sort
         $sortRequest = $this->sqlRequestTranslator->translateSortParameterToSql();
-        $request .= !is_null($sortRequest) ? $sortRequest : ' ORDER BY dwt.downtime_id DESC';
+        $request .= ! is_null($sortRequest) ? $sortRequest : ' ORDER BY dwt.downtime_id DESC';
 
         // Pagination
         $request .= $this->sqlRequestTranslator->translatePaginationToSql();
