@@ -337,6 +337,21 @@ class MonitoringServerRepositoryRDB extends AbstractRepositoryDRB implements Mon
         $statement->execute();
     }
 
+    /**
+     * @inheritDoc
+     */
+    public function findRemoteServersIps(): array
+    {
+        $request = $this->translateDbName('SELECT ip FROM remote_servers');
+        $statement = $this->db->query($request);
+        $statement->execute();
+        if ($statement !== false) {
+            return $statement->fetchAll(\PDO::FETCH_COLUMN);
+        }
+
+        return [];
+    }
+
     /**
      * Find servers.
      *
@@ -353,7 +368,7 @@ class MonitoringServerRepositoryRDB extends AbstractRepositoryDRB implements Mon
         ?string $searchRequest,
         ?string $sortRequest,
         ?string $paginationRequest,
-        array $accessGroups = [],
+        array $accessGroups = []
     ): array {
         $aclMonitoringServersRequest = '';
         $searchRequest ??= '';
