@@ -1,13 +1,13 @@
 <?php
 
 /*
- * Copyright 2005 - 2020 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -18,10 +18,12 @@
  * For more information : contact@centreon.com
  *
  */
+
 declare(strict_types=1);
 
 namespace Centreon\Infrastructure\RequestParameters;
 
+use Adaptation\Database\QueryBuilder\QueryBuilderInterface;
 use Centreon\Domain\RequestParameters\Interfaces\RequestParametersInterface;
 use Centreon\Domain\RequestParameters\RequestParameters;
 use Centreon\Infrastructure\DatabaseConnection;
@@ -33,33 +35,25 @@ use Utility\SqlConcatenator;
  */
 class SqlRequestParametersTranslator
 {
-    /**
-     * @var string[]
-     */
+    /** @var string[] */
     private $aggregateOperators = [
         RequestParameters::AGGREGATE_OPERATOR_OR,
-        RequestParameters::AGGREGATE_OPERATOR_AND
+        RequestParameters::AGGREGATE_OPERATOR_AND,
     ];
 
     /**
-     * @var array<string, string> $concordanceArray Concordance table between the search column
-     * and the real column name in the database. ['id' => 'my_table_id', ...]
+     * @var array<string, string> Concordance table between the search column
+     *                            and the real column name in the database. ['id' => 'my_table_id', ...]
      */
     private $concordanceArray = [];
 
-    /**
-     * @var array<string, mixed>
-     */
+    /** @var array<string, mixed> */
     private $searchValues = [];
 
-    /**
-     * @var array<string, NormalizerInterface>
-     */
+    /** @var array<string, NormalizerInterface> */
     private $normalizers = [];
 
-    /**
-     * @var RequestParametersInterface
-     */
+    /** @var RequestParametersInterface */
     private $requestParameters;
 
     /**
@@ -71,60 +65,6 @@ class SqlRequestParametersTranslator
         $this->requestParameters = $requestParameters;
     }
 
-    /**
-     * Create the database query based on the search parameters.
-     *
-     * @param array<mixed, mixed> $search Array containing search parameters
-     * @param string|null $aggregateOperator Aggregate operator
-     * @return string Return the processed database query
-     * @throws RequestParametersTranslatorException
-     */
-    private function createDatabaseQuery(array $search, string $aggregateOperator = null): string
-    {
-        $databaseQuery = '';
-        $databaseSubQuery = '';
-        foreach ($search as $key => $searchRequests) {
-            if ($this->isAggregateOperator($key)) {
-                if (is_object($searchRequests) || is_array($searchRequests)) {
-                    if (is_object($searchRequests)) {
-                        $searchRequests = (array) $searchRequests;
-                    }
-                    // Recursive call until to read key/value data
-                    $databaseSubQuery = $this->createDatabaseQuery($searchRequests, $key);
-                }
-            } elseif (is_int($key) && (is_object($searchRequests) || is_array($searchRequests))) {
-                // It's a list of object to process
-                $searchRequests = (array) $searchRequests;
-                if ($searchRequests !== []) {
-                    // Recursive call until to read key/value data
-                    $databaseSubQuery = $this->createDatabaseQuery($searchRequests, $aggregateOperator);
-                }
-            } elseif (!is_int($key)) {
-                // It's a pair on key/value to translate into a database query
-                if (is_object($searchRequests)) {
-                    $searchRequests = (array) $searchRequests;
-                }
-                $databaseSubQuery = $this->createQueryOnKeyValue($key, $searchRequests);
-            }
-            if (!empty($databaseQuery)) {
-                if (is_null($aggregateOperator)) {
-                    $aggregateOperator = RequestParameters::AGGREGATE_OPERATOR_AND;
-                }
-                if (!empty($databaseSubQuery)) {
-                    $databaseQuery .= ' '
-                        . $this->translateAggregateOperator($aggregateOperator)
-                        . ' '
-                        . $databaseSubQuery;
-                }
-            } else {
-                $databaseQuery .= $databaseSubQuery;
-            }
-        }
-        return count($search) > 1 && !empty($databaseQuery)
-            ? '(' . $databaseQuery . ')'
-            : $databaseQuery;
-    }
-
     /**
      * @return RequestParametersInterface
      */
@@ -155,17 +95,26 @@ class SqlRequestParametersTranslator
      *      list($whereQuery, $bindValues) = $pagination->createQuery([...]);
      * </code>
      *
-     * @return string|null SQL request according to the search parameters
      * @throws RequestParametersTranslatorException
+     * @return string|null SQL request according to the search parameters
      */
     public function translateSearchParameterToSql(): ?string
     {
         $whereQuery = '';
         $search = $this->requestParameters->getSearch();
-        if (!empty($search) && is_array($search)) {
+        if (! empty($search) && is_array($search)) {
             $whereQuery .= $this->createDatabaseQuery($search);
         }
-        return !empty($whereQuery) ? ' WHERE ' . $whereQuery : null;
+
+        return ! empty($whereQuery) ? ' WHERE ' . $whereQuery : null;
+    }
+
+    public function appendQueryBuilderWithSearchParameter(QueryBuilderInterface $queryBuilder): void
+    {
+        $search = $this->requestParameters->getSearch();
+        if (! empty($search)) {
+            $queryBuilder->where($this->createDatabaseQuery($search));
+        }
     }
 
     /**
@@ -178,7 +127,7 @@ class SqlRequestParametersTranslator
         $orderQuery = '';
         foreach ($this->requestParameters->getSort() as $name => $order) {
             if (array_key_exists($name, $this->concordanceArray)) {
-                if (!empty($orderQuery)) {
+                if (! empty($orderQuery)) {
                     $orderQuery .= ', ';
                 }
                 $orderQuery .= sprintf(
@@ -189,7 +138,35 @@ class SqlRequestParametersTranslator
                 );
             }
         }
-        return !empty($orderQuery) ? ' ORDER BY ' . $orderQuery : null;
+
+        return ! empty($orderQuery) ? ' ORDER BY ' . $orderQuery : null;
+    }
+
+    public function appendQueryBuilderWithSortParameter(QueryBuilderInterface $queryBuilder): void
+    {
+        foreach ($this->requestParameters->getSort() as $name => $order) {
+            if (array_key_exists($name, $this->concordanceArray)) {
+                $queryBuilder->addOrderBy(
+                    sprintf(
+                        '%s IS NULL, %s',
+                        $this->concordanceArray[$name],
+                        $this->concordanceArray[$name],
+                    ),
+                    $order
+                );
+            }
+        }
+    }
+
+    public function appendQueryBuilderWithPagination(QueryBuilderInterface $queryBuilder): void
+    {
+        $page = $this->requestParameters->getPage();
+        $limit = $this->requestParameters->getLimit();
+        $offset = ($page - 1) * $limit;
+
+        $queryBuilder
+            ->limit($limit)
+            ->offset($offset);
     }
 
     /**
@@ -214,176 +191,6 @@ class SqlRequestParametersTranslator
         }
     }
 
-    /**
-     *
-     * @param string $key Key representing the entity to search
-     * @param mixed $valueOrArray Mixed value or array representing the value to search.
-     * @return string Part of the database query.
-     * @throws RequestParametersTranslatorException
-     */
-    private function createQueryOnKeyValue(string $key, $valueOrArray): string
-    {
-        if (
-            $this->requestParameters->getConcordanceStrictMode() === RequestParameters::CONCORDANCE_MODE_STRICT
-            && ! array_key_exists($key, $this->concordanceArray)
-        ) {
-            if (
-                $this->requestParameters
-                    ->getConcordanceErrorMode() === RequestParameters::CONCORDANCE_ERRMODE_EXCEPTION
-            ) {
-                throw new RequestParametersTranslatorException(
-                    sprintf(_('The parameter %s is not allowed'), $key)
-                );
-            }
-
-            return '';
-        }
-        if (is_array($valueOrArray)) {
-            $searchOperator = (string) key($valueOrArray);
-            $mixedValue = $valueOrArray[$searchOperator];
-        } else {
-            $searchOperator = RequestParameters::DEFAULT_SEARCH_OPERATOR;
-            $mixedValue = $valueOrArray;
-        }
-
-        if ($mixedValue === null) {
-            $mixedValue = $this->normalizeValue($key, $mixedValue);
-        }
-
-        if ($mixedValue === null) {
-            if ($searchOperator === RequestParameters::OPERATOR_EQUAL) {
-                $bindKey = 'NULL';
-            } elseif ($searchOperator === RequestParameters::OPERATOR_NOT_EQUAL) {
-                $bindKey = 'NOT NULL';
-            } else {
-                throw new RequestParametersTranslatorException(
-                    'The value "null" is only supported by the operators '
-                    . RequestParameters::OPERATOR_EQUAL
-                    . ' and '
-                    . RequestParameters::OPERATOR_NOT_EQUAL
-                );
-            }
-        } elseif (
-            $searchOperator === RequestParameters::OPERATOR_IN
-            || $searchOperator === RequestParameters::OPERATOR_NOT_IN
-        ) {
-            if (is_array($mixedValue)) {
-                $bindKey = '(';
-                foreach ($mixedValue as $index => $newValue) {
-                    $newValue = $this->normalizeValue($key, $newValue);
-                    $currentBindKey = ':value_' . (count($this->searchValues) + 1);
-                    $this->searchValues[$currentBindKey] = [$this->toPdoType($newValue) => $newValue];
-                    if ($index > 0) {
-                        $bindKey .= ',';
-                    }
-                    $bindKey .= $currentBindKey;
-                }
-                $bindKey .= ')';
-            } else {
-                $mixedValue = $this->normalizeValue($key, $mixedValue);
-                $bindKey = ':value_' . (count($this->searchValues) + 1);
-                $this->searchValues[$bindKey] = [$this->toPdoType($mixedValue) => $mixedValue];
-                $bindKey = '(' . $bindKey . ')';
-            }
-        } elseif (
-            $searchOperator === RequestParameters::OPERATOR_LIKE
-            || $searchOperator === RequestParameters::OPERATOR_NOT_LIKE
-            || $searchOperator === RequestParameters::OPERATOR_REGEXP
-        ) {
-            // We check the regex
-            if ($searchOperator === RequestParameters::OPERATOR_REGEXP) {
-                // For MySQL compatibility
-                if ($mixedValue === '') {
-                    $mixedValue = '.*';
-                }
-                preg_match('/' . $mixedValue . '/', '');
-                if (preg_last_error() !== PREG_NO_ERROR) {
-                    throw new RequestParametersTranslatorException('Bad regex format \'' . $mixedValue . '\'', 0);
-                }
-            }
-            $bindKey = ':value_' . (count($this->searchValues) + 1);
-            $this->searchValues[$bindKey] = [\PDO::PARAM_STR => $mixedValue];
-        } else {
-            $mixedValue = $this->normalizeValue($key, $mixedValue);
-            $bindKey = ':value_' . (count($this->searchValues) + 1);
-            $this->searchValues[$bindKey] = [$this->toPdoType($mixedValue) => $mixedValue];
-        }
-
-        return sprintf(
-            '%s %s %s',
-            (array_key_exists($key, $this->concordanceArray)
-                ? $this->concordanceArray[$key]
-                : $key),
-            ($mixedValue !== null) ? $this->translateSearchOperator($searchOperator) : 'IS',
-            $bindKey
-        );
-    }
-
-    /**
-     * Detect the correct PDO type from a php type.
-     *
-     * @param mixed $value
-     *
-     * @return int
-     */
-    private function toPdoType(mixed $value): int
-    {
-        return match (true) {
-            is_int($value) => \PDO::PARAM_INT,
-            is_bool($value) => \PDO::PARAM_BOOL,
-            default => \PDO::PARAM_STR,
-        };
-    }
-
-    /**
-     * Indicates if the key is an aggregate operator
-     *
-     * @param mixed $key Key to test
-     * @return bool Return TRUE if the key is an aggregate operator otherwise FALSE
-     */
-    private function isAggregateOperator($key): bool
-    {
-        return is_string($key) && in_array($key, $this->aggregateOperators);
-    }
-
-    /**
-     * @param string $aggregateOperator
-     * @return string
-     * @throws RequestParametersTranslatorException
-     */
-    private function translateAggregateOperator(string $aggregateOperator): string
-    {
-        return match ($aggregateOperator) {
-            RequestParameters::AGGREGATE_OPERATOR_AND => 'AND',
-            RequestParameters::AGGREGATE_OPERATOR_OR => 'OR',
-            default => throw new RequestParametersTranslatorException(_('Bad search operator'))
-        };
-    }
-
-    /**
-     * Translates the search operators (RequestParameters::OPERATOR_LIKE, ...)
-     * in their SQL equivalent (LIKE, ...).
-     *
-     * @param string $operator Operator to translate
-     * @return string Operator translated in his SQL equivalent
-     */
-    private function translateSearchOperator(string $operator): string
-    {
-        return match ($operator) {
-            RequestParameters::OPERATOR_LIKE => 'LIKE',
-            RequestParameters::OPERATOR_NOT_LIKE => 'NOT LIKE',
-            RequestParameters::OPERATOR_REGEXP => 'REGEXP',
-            RequestParameters::OPERATOR_LESS_THAN => '<',
-            RequestParameters::OPERATOR_LESS_THAN_OR_EQUAL => '<=',
-            RequestParameters::OPERATOR_GREATER_THAN => '>',
-            RequestParameters::OPERATOR_GREATER_THAN_OR_EQUAL => '>=',
-            RequestParameters::OPERATOR_NOT_EQUAL => '!=',
-            RequestParameters::OPERATOR_IN => 'IN',
-            RequestParameters::OPERATOR_NOT_IN => 'NOT IN',
-            default => '=',
-        };
-    }
-
     /**
      * @return array<string, string>
      */
@@ -460,6 +267,14 @@ class SqlRequestParametersTranslator
         return $nbRows;
     }
 
+    /**
+     * @param int $numberOfRows
+     */
+    public function setNumberOfRows(int $numberOfRows): void
+    {
+        $this->requestParameters->setTotal($numberOfRows);
+    }
+
     /**
      * Add a normalizer for a property name to be declared in the search parameters.
      * <code>
@@ -490,6 +305,239 @@ class SqlRequestParametersTranslator
         $this->normalizers[$propertyName] = $normalizer;
     }
 
+    /**
+     * Create the database query based on the search parameters.
+     *
+     * @param array<mixed, mixed> $search Array containing search parameters
+     * @param string|null $aggregateOperator Aggregate operator
+     * @throws RequestParametersTranslatorException
+     * @return string Return the processed database query
+     */
+    private function createDatabaseQuery(array $search, ?string $aggregateOperator = null): string
+    {
+        $databaseQuery = '';
+        $databaseSubQuery = '';
+        foreach ($search as $key => $searchRequests) {
+            if ($this->isAggregateOperator($key)) {
+                if (is_object($searchRequests) || is_array($searchRequests)) {
+                    if (is_object($searchRequests)) {
+                        $searchRequests = (array) $searchRequests;
+                    }
+                    // Recursive call until to read key/value data
+                    $databaseSubQuery = $this->createDatabaseQuery($searchRequests, $key);
+                }
+            } elseif (is_int($key) && (is_object($searchRequests) || is_array($searchRequests))) {
+                // It's a list of object to process
+                $searchRequests = (array) $searchRequests;
+                if ($searchRequests !== []) {
+                    // Recursive call until to read key/value data
+                    $databaseSubQuery = $this->createDatabaseQuery($searchRequests, $aggregateOperator);
+                }
+            } elseif (! is_int($key)) {
+                // It's a pair on key/value to translate into a database query
+                if (is_object($searchRequests)) {
+                    $searchRequests = (array) $searchRequests;
+                }
+                $databaseSubQuery = $this->createQueryOnKeyValue($key, $searchRequests);
+            }
+            if (! empty($databaseQuery)) {
+                if (is_null($aggregateOperator)) {
+                    $aggregateOperator = RequestParameters::AGGREGATE_OPERATOR_AND;
+                }
+                if (! empty($databaseSubQuery)) {
+                    $databaseQuery .= ' '
+                        . $this->translateAggregateOperator($aggregateOperator)
+                        . ' '
+                        . $databaseSubQuery;
+                }
+            } else {
+                $databaseQuery .= $databaseSubQuery;
+            }
+        }
+
+        return count($search) > 1 && ! empty($databaseQuery)
+            ? '(' . $databaseQuery . ')'
+            : $databaseQuery;
+    }
+
+    /**
+     * @param string $key Key representing the entity to search
+     * @param mixed $valueOrArray mixed value or array representing the value to search
+     * @throws RequestParametersTranslatorException
+     * @return string part of the database query
+     */
+    private function createQueryOnKeyValue(string $key, $valueOrArray): string
+    {
+        if (
+            $this->requestParameters->getConcordanceStrictMode() === RequestParameters::CONCORDANCE_MODE_STRICT
+            && ! array_key_exists($key, $this->concordanceArray)
+        ) {
+            if (
+                $this->requestParameters
+                    ->getConcordanceErrorMode() === RequestParameters::CONCORDANCE_ERRMODE_EXCEPTION
+            ) {
+                throw new RequestParametersTranslatorException(
+                    sprintf(_('The parameter %s is not allowed'), $key)
+                );
+            }
+
+            return '';
+        }
+        if (is_array($valueOrArray)) {
+            $searchOperator = (string) key($valueOrArray);
+            $mixedValue = $valueOrArray[$searchOperator];
+        } else {
+            $searchOperator = RequestParameters::DEFAULT_SEARCH_OPERATOR;
+            $mixedValue = $valueOrArray;
+        }
+
+        if ($mixedValue === null) {
+            $mixedValue = $this->normalizeValue($key, $mixedValue);
+        }
+
+        if ($mixedValue === null) {
+            if ($searchOperator === RequestParameters::OPERATOR_EQUAL) {
+                $bindKey = 'NULL';
+            } elseif ($searchOperator === RequestParameters::OPERATOR_NOT_EQUAL) {
+                $bindKey = 'NOT NULL';
+            } else {
+                throw new RequestParametersTranslatorException(
+                    'The value "null" is only supported by the operators '
+                    . RequestParameters::OPERATOR_EQUAL
+                    . ' and '
+                    . RequestParameters::OPERATOR_NOT_EQUAL
+                );
+            }
+        } elseif (
+            $searchOperator === RequestParameters::OPERATOR_IN
+            || $searchOperator === RequestParameters::OPERATOR_NOT_IN
+        ) {
+            if (is_array($mixedValue)) {
+                $bindKey = '(';
+                foreach ($mixedValue as $index => $newValue) {
+                    $newValue = $this->normalizeValue($key, $newValue);
+                    $currentBindKey = ':value_' . (count($this->searchValues) + 1);
+                    $this->searchValues[$currentBindKey] = [$this->toPdoType($newValue) => $newValue];
+                    if ($index > 0) {
+                        $bindKey .= ',';
+                    }
+                    $bindKey .= $currentBindKey;
+                }
+                $bindKey .= ')';
+            } else {
+                $mixedValue = $this->normalizeValue($key, $mixedValue);
+                $bindKey = ':value_' . (count($this->searchValues) + 1);
+                $this->searchValues[$bindKey] = [$this->toPdoType($mixedValue) => $mixedValue];
+                $bindKey = '(' . $bindKey . ')';
+            }
+        } elseif (
+            $searchOperator === RequestParameters::OPERATOR_LIKE
+            || $searchOperator === RequestParameters::OPERATOR_NOT_LIKE
+            || $searchOperator === RequestParameters::OPERATOR_REGEXP
+        ) {
+            // We check the regex
+            if ($searchOperator === RequestParameters::OPERATOR_REGEXP) {
+                // For MySQL compatibility
+                if ($mixedValue === '') {
+                    $mixedValue = '.*';
+                }
+                try {
+                    $mixedValue = str_replace('/', '\/', $mixedValue);
+                    preg_match('/' . $mixedValue . '/', '');
+                    if (preg_last_error() !== PREG_NO_ERROR) {
+                        throw new RequestParametersTranslatorException('Bad regex format \'' . $mixedValue . '\'', 0);
+                    }
+                } catch (\ErrorException $exception) {
+                    throw new RequestParametersTranslatorException(
+                        message: 'Error while preg_match() the value : \'' . $mixedValue . '\'',
+                        code: 0,
+                        previous: $exception
+                    );
+                }
+            }
+            $bindKey = ':value_' . (count($this->searchValues) + 1);
+            $this->searchValues[$bindKey] = [\PDO::PARAM_STR => $mixedValue];
+        } else {
+            $mixedValue = $this->normalizeValue($key, $mixedValue);
+            $bindKey = ':value_' . (count($this->searchValues) + 1);
+            $this->searchValues[$bindKey] = [$this->toPdoType($mixedValue) => $mixedValue];
+        }
+
+        return sprintf(
+            '%s %s %s',
+            (array_key_exists($key, $this->concordanceArray)
+                ? $this->concordanceArray[$key]
+                : $key),
+            ($mixedValue !== null) ? $this->translateSearchOperator($searchOperator) : 'IS',
+            $bindKey
+        );
+    }
+
+    /**
+     * Detect the correct PDO type from a php type.
+     *
+     * @param mixed $value
+     *
+     * @return int
+     */
+    private function toPdoType(mixed $value): int
+    {
+        return match (true) {
+            is_int($value) => \PDO::PARAM_INT,
+            is_bool($value) => \PDO::PARAM_BOOL,
+            default => \PDO::PARAM_STR,
+        };
+    }
+
+    /**
+     * Indicates if the key is an aggregate operator
+     *
+     * @param mixed $key Key to test
+     * @return bool Return TRUE if the key is an aggregate operator otherwise FALSE
+     */
+    private function isAggregateOperator($key): bool
+    {
+        return is_string($key) && in_array($key, $this->aggregateOperators, true);
+    }
+
+    /**
+     * @param string $aggregateOperator
+     * @throws RequestParametersTranslatorException
+     * @return string
+     */
+    private function translateAggregateOperator(string $aggregateOperator): string
+    {
+        return match ($aggregateOperator) {
+            RequestParameters::AGGREGATE_OPERATOR_AND => 'AND',
+            RequestParameters::AGGREGATE_OPERATOR_OR => 'OR',
+            default => throw new RequestParametersTranslatorException(_('Bad search operator'))
+        };
+    }
+
+    /**
+     * Translates the search operators (RequestParameters::OPERATOR_LIKE, ...)
+     * in their SQL equivalent (LIKE, ...).
+     *
+     * @param string $operator Operator to translate
+     * @return string Operator translated in his SQL equivalent
+     */
+    private function translateSearchOperator(string $operator): string
+    {
+        return match ($operator) {
+            RequestParameters::OPERATOR_LIKE => 'LIKE',
+            RequestParameters::OPERATOR_NOT_LIKE => 'NOT LIKE',
+            RequestParameters::OPERATOR_REGEXP => 'REGEXP',
+            RequestParameters::OPERATOR_LESS_THAN => '<',
+            RequestParameters::OPERATOR_LESS_THAN_OR_EQUAL => '<=',
+            RequestParameters::OPERATOR_GREATER_THAN => '>',
+            RequestParameters::OPERATOR_GREATER_THAN_OR_EQUAL => '>=',
+            RequestParameters::OPERATOR_NOT_EQUAL => '!=',
+            RequestParameters::OPERATOR_IN => 'IN',
+            RequestParameters::OPERATOR_NOT_IN => 'NOT IN',
+            default => '=',
+        };
+    }
+
     /**
      * Normalize a value.
      *
@@ -502,6 +550,7 @@ class SqlRequestParametersTranslator
         if (array_key_exists($propertyName, $this->normalizers)) {
             return $this->normalizers[$propertyName]->normalize($valueToNormalize);
         }
+
         return $valueToNormalize;
     }
 }
