@@ -21,7 +21,9 @@
 
 namespace CentreonLegacy\Core\Utils;
 
+use Psr\Container\ContainerExceptionInterface;
 use Psr\Container\ContainerInterface;
+use Psr\Container\NotFoundExceptionInterface;
 
 class Utils
 {
@@ -68,6 +70,8 @@ class Utils
      * @param array $customMacros
      * @param mixed $monitoring
      *
+     * @throws ContainerExceptionInterface
+     * @throws NotFoundExceptionInterface
      * @throws \Exception
      */
     public function executeSqlFile($fileName, $customMacros = [], $monitoring = false): void
@@ -82,21 +86,13 @@ class Utils
 
         $file = fopen($fileName, 'r');
         $str = '';
-        $delimiter = ';';
         while (! feof($file)) {
             $line = fgets($file);
             if (! preg_match('/^(--|#)/', $line)) {
-                if (preg_match('/DELIMITER\s+(\S+)/i', $line, $matches)) {
-                    $delimiter = $matches[1];
-                    continue;
-                }
-                $pos = strrpos($line, $delimiter);
+                $pos = strrpos($line, ';');
                 $str .= $line;
                 if ($pos !== false) {
                     $str = rtrim($this->replaceMacros($str, $customMacros));
-                    if ($delimiter !== ';') {
-                        $str = preg_replace('/' . preg_quote($delimiter, '/') . '$/', '', $str);
-                    }
                     $this->services->get($dbName)->query($str);
                     $str = '';
                 }
