@@ -1,13 +1,13 @@
 <?php
 
 /*
- * Copyright 2005 - 2024 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -18,19 +18,26 @@
  * For more information : contact@centreon.com
  *
  */
+
 declare(strict_types=1);
 
 namespace Core\ActionLog\Application\Repository;
 
 use Core\ActionLog\Domain\Model\ActionLog;
+use Core\Common\Domain\Exception\RepositoryException;
 
+/**
+ * Interface
+ *
+ * @class WriteActionLogRepositoryInterface
+ * @package Core\ActionLog\Application\Repository
+ */
 interface WriteActionLogRepositoryInterface
 {
     /**
      * @param ActionLog $actionLog
      *
-     * @throws \Throwable
-     *
+     * @throws RepositoryException
      * @return int
      */
     public function addAction(ActionLog $actionLog): int;
@@ -39,7 +46,7 @@ interface WriteActionLogRepositoryInterface
      * @param ActionLog $actionLog
      * @param array<string, string|int|bool> $details
      *
-     * @throws \Throwable
+     * @throws RepositoryException
      */
     public function addActionDetails(ActionLog $actionLog, array $details): void;
 }
