@@ -56,7 +56,7 @@ class DbReadAgentConfigurationRepository extends AbstractRepositoryRDB implement
     use MonitoringServerRepositoryTrait;
 
     public function __construct(
-        DatabaseConnection $db,
+        DatabaseConnection $db
     ) {
         $this->db = $db;
     }
@@ -146,7 +146,10 @@ class DbReadAgentConfigurationRepository extends AbstractRepositoryRDB implement
             <<<'SQL'
                 SELECT
                     rel.`poller_id` as id,
-                    ng.`name`
+                    ng.`name`,
+                    (ng.`localhost` = '1' AND NOT EXISTS (
+                        SELECT 1 FROM `:db`.`remote_servers` rs WHERE rs.server_id = ng.id
+                    )) as is_central
                 FROM `:db`.`ac_poller_relation` rel
                 JOIN `:db`.`nagios_server` ng
                     ON rel.poller_id = ng.id
@@ -160,8 +163,8 @@ class DbReadAgentConfigurationRepository extends AbstractRepositoryRDB implement
         // Retrieve data
         $pollers = [];
         foreach ($statement as $result) {
-            /** @var array{id:int,name:string} $result */
-            $pollers[] = new Poller($result['id'], $result['name']);
+            /** @var array{id:int,name:string,is_central:int} $result */
+            $pollers[] = new Poller($result['id'], $result['name'], $result['is_central'] === 1);
         }
 
         return $pollers;
@@ -255,7 +258,7 @@ class DbReadAgentConfigurationRepository extends AbstractRepositoryRDB implement
      */
     public function findAllByRequestParametersAndAccessGroups(
         RequestParametersInterface $requestParameters,
-        array $accessGroups,
+        array $accessGroups
     ): array {
         if ($accessGroups === []) {
             return [];
