@@ -49,7 +49,7 @@ class DbWriteAgentConfigurationRepository extends DatabaseRepository implements
     public function add(NewAgentConfiguration $agentConfiguration): int
     {
         try {
-            $query = $this->connection->createQueryBuilder()->insert('`:db`.`agent_configuration`')
+            $query = $this->queryBuilder->insert('`:db`.`agent_configuration`')
                 ->values(
                     [
                         'type' => ':type',
@@ -95,12 +95,11 @@ class DbWriteAgentConfigurationRepository extends DatabaseRepository implements
     public function update(AgentConfiguration $agentConfiguration): void
     {
         try {
-            $queryBuilder = $this->connection->createQueryBuilder();
-            $query = $queryBuilder->update('`:db`.`agent_configuration`')
+            $query = $this->queryBuilder->update('`:db`.`agent_configuration`')
                 ->set('name', ':name')
                 ->set('configuration', ':configuration')
                 ->set('connection_mode', ':connection_mode')
-                ->where($queryBuilder->expr()->equal('id', ':id'))
+                ->where($this->queryBuilder->expr()->equal('id', ':id'))
                 ->getQuery();
 
             $this->connection->update(
@@ -137,9 +136,8 @@ class DbWriteAgentConfigurationRepository extends DatabaseRepository implements
     public function delete(int $id): void
     {
         try {
-            $queryBuilder = $this->connection->createQueryBuilder();
-            $query = $queryBuilder->delete('`:db`.`agent_configuration`')
-                ->where($queryBuilder->expr()->equal('id', ':id'))
+            $query = $this->queryBuilder->delete('`:db`.`agent_configuration`')
+                ->where($this->queryBuilder->expr()->equal('id', ':id'))
                 ->getQuery();
 
             $this->connection->delete(
@@ -161,7 +159,7 @@ class DbWriteAgentConfigurationRepository extends DatabaseRepository implements
     public function linkToPollers(int $agentConfigurationId, array $pollerIds): void
     {
         try {
-            $query = $this->connection->createQueryBuilder()->insert('`:db`.`ac_poller_relation`')
+            $query = $this->queryBuilder->insert('`:db`.`ac_poller_relation`')
                 ->values(
                     [
                         'ac_id' => ':ac_id',
@@ -194,9 +192,8 @@ class DbWriteAgentConfigurationRepository extends DatabaseRepository implements
     public function removePollers(int $agentConfigurationId): void
     {
         try {
-            $queryBuilder = $this->connection->createQueryBuilder();
-            $query = $queryBuilder->delete('`:db`.`ac_poller_relation`')
-                ->where($queryBuilder->expr()->equal('ac_id', ':ac_id'))
+            $query = $this->queryBuilder->delete('`:db`.`ac_poller_relation`')
+                ->where($this->queryBuilder->expr()->equal('ac_id', ':ac_id'))
                 ->getQuery();
 
             $this->connection->delete(
@@ -218,10 +215,9 @@ class DbWriteAgentConfigurationRepository extends DatabaseRepository implements
     public function removePoller(int $agentConfigurationId, int $pollerId): void
     {
         try {
-            $queryBuilder = $this->connection->createQueryBuilder();
-            $query = $queryBuilder->delete('`:db`.`ac_poller_relation`')
-                ->where($queryBuilder->expr()->equal('ac_id', ':ac_id'))
-                ->andWhere($queryBuilder->expr()->equal('poller_id', ':poller_id'))
+            $query = $this->queryBuilder->delete('`:db`.`ac_poller_relation`')
+                ->where($this->queryBuilder->expr()->equal('ac_id', ':ac_id'))
+                ->andWhere($this->queryBuilder->expr()->equal('poller_id', ':poller_id'))
                 ->getQuery();
 
             $this->connection->delete(
@@ -246,7 +242,7 @@ class DbWriteAgentConfigurationRepository extends DatabaseRepository implements
     public function addBrokerDirective(string $module, array $pollerIds): void
     {
         try {
-            $query = $this->connection->createQueryBuilder()->insert('`:db`.`cfg_nagios_broker_module`')
+            $query = $this->queryBuilder->insert('`:db`.`cfg_nagios_broker_module`')
                 ->values(
                     [
                         'bk_mod_id' => ':bk_mod_id',
