@@ -1,7 +1,7 @@
 <?php
 
 /*
- * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -66,18 +66,18 @@ final class FindNotificationPolicyResponse
                 'alias' => $notifiedContact->getAlias(),
                 'email' => $notifiedContact->getEmail(),
                 'notifications' => [
-                    'host' => [
+                    'host' => $notifiedContact->getHostNotification() ? [
                         'events' => $notifiedContact->getHostNotification()->getEvents(),
                         'time_period' => self::timePeriodToArray(
                             $notifiedContact->getHostNotification()->getTimePeriod(),
                         ),
-                    ],
-                    'service' => [
+                    ] : null,
+                    'service' => $notifiedContact->getServiceNotification() ? [
                         'events' => $notifiedContact->getServiceNotification()->getEvents(),
                         'time_period' => self::timePeriodToArray(
                             $notifiedContact->getServiceNotification()->getTimePeriod(),
                         ),
-                    ],
+                    ] : null,
                 ],
             ],
             $notifiedContacts
