@@ -37,23 +37,12 @@ interface ReadContactRepositoryInterface
      *
      * @param int ...$ids
      *
-     * @throws \Throwable
+     * @throws RepositoryException
      *
      * @return array<int, array{id: int, name: string}>
      */
     public function findNamesByIds(int ...$ids): array;
 
-    /**
-     * Find contact alias by IDs.
-     *
-     * @param int ...$ids
-     *
-     * @throws RepositoryException
-     *
-     * @return array<int, array{id: int, alias: string}>
-     */
-    public function findAliasesByIds(int ...$ids): array;
-
     /**
      * Check user existence by its id.
      *
@@ -171,6 +160,6 @@ interface ReadContactRepositoryInterface
     public function findByAccessGroupsAndUserAndRequestParameters(
         array $accessGroups,
         ContactInterface $user,
-        ?RequestParametersInterface $requestParameters = null,
+        ?RequestParametersInterface $requestParameters = null
     ): array;
 }
