@@ -37,7 +37,7 @@ enum DashboardSharingRole
      */
     public function hasMorePermissionsThan(?self $role): bool
     {
-        if ($role === null) {
+        if (null === $role) {
             return true;
         }
 
@@ -54,7 +54,7 @@ enum DashboardSharingRole
      */
     public function getTheMostPermissiveOfBoth(?self $role): self
     {
-        if ($role === null) {
+        if (null === $role) {
             return $this;
         }
 
