@@ -1,7 +1,7 @@
 <?php
 
 /*
- * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -98,7 +98,8 @@ final class AddDashboardPresenter extends DefaultPresenter implements AddDashboa
      *
      * @return array{type: string, interval: null|int}
      */
-    private function formatRefresh(array $refresh): array {
+    private function formatRefresh(array $refresh): array
+    {
         return [
             'type' => RefreshTypeConverter::toString($refresh['type']),
             'interval' => $refresh['interval'],
