@@ -1,7 +1,7 @@
 <?php
 
 /*
- * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -447,12 +447,14 @@ class DbReadDashboardRepository extends AbstractRepositoryRDB implements ReadDas
             'created_by' => 'c.contact_name',
         ]);
 
-        $concatenator->appendJoins(
-            <<<'SQL'
-                LEFT JOIN contact c
-                ON d.created_by = c.contact_id
-                SQL
-        );
+        if (array_key_exists('created_by', $requestParameters?->getSort() ?? [])) {
+            $concatenator->appendJoins(
+                <<<'SQL'
+                    LEFT JOIN contact c
+                    ON d.created_by = c.contact_id
+                    SQL
+            );
+        }
 
         // Update the SQL string builder with the RequestParameters through SqlRequestParametersTranslator
         $sqlTranslator?->translateForConcatenator($concatenator);
