@@ -44,12 +44,11 @@ final class HostMacroFactory
     public static function create(
         array $data,
         int $hostId,
-        array $inheritedMacros,
+        array $inheritedMacros
     ): Macro {
         $macroName = mb_strtoupper($data['name']);
         $macroValue = $data['value'] ?? '';
         $passwordHasNotChanged = ($data['value'] === null) && $data['is_password'];
-        // Note: do not handle vault storage at the moment
         if ($passwordHasNotChanged) {
             $macroValue = match (true) {
                 // retrieve actual password value
