@@ -1,7 +1,7 @@
 <?php
 
 /*
- * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -23,7 +23,6 @@ declare(strict_types=1);
 
 namespace Core\Host\Application\UseCase\PartialUpdateHost;
 
-use Centreon\Domain\Common\Assertion\Assertion;
 use Centreon\Domain\Contact\Interfaces\ContactInterface;
 use Centreon\Domain\Log\LoggerTrait;
 use Core\Command\Application\Repository\ReadCommandRepositoryInterface;
@@ -37,7 +36,6 @@ use Core\HostGroup\Application\Repository\ReadHostGroupRepositoryInterface;
 use Core\HostSeverity\Application\Repository\ReadHostSeverityRepositoryInterface;
 use Core\HostTemplate\Application\Repository\ReadHostTemplateRepositoryInterface;
 use Core\MonitoringServer\Application\Repository\ReadMonitoringServerRepositoryInterface;
-use Core\MonitoringServer\Model\MonitoringServer;
 use Core\Security\AccessGroup\Domain\Model\AccessGroup;
 use Core\TimePeriod\Application\Repository\ReadTimePeriodRepositoryInterface;
 use Core\Timezone\Application\Repository\ReadTimezoneRepositoryInterface;
@@ -89,18 +87,11 @@ class PartialUpdateHostValidation
      */
     public function assertIsValidName(string $name, Host $host): void
     {
-        Assertion::unauthorizedCharacters(
-            $name,
-            MonitoringServer::ILLEGAL_CHARACTERS,
-            'Host::name'
-        );
-
         if ($host->isNameIdentical($name)) {
 
             return;
         }
         $formattedName = Host::formatName($name);
-
         if ($this->readHostRepository->existsByName($formattedName)) {
             $this->error('Host name already exists', compact('name', 'formattedName'));
 
@@ -160,7 +151,7 @@ class PartialUpdateHostValidation
      */
     public function assertIsValidTimePeriod(?int $timePeriodId, ?string $propertyName = null): void
     {
-        if ($timePeriodId !== null && false === $this->readTimePeriodRepository->exists($timePeriodId) ) {
+        if ($timePeriodId !== null && false === $this->readTimePeriodRepository->exists($timePeriodId)) {
             $this->error('Time period does not exist', ['time_period_id' => $timePeriodId]);
 
             throw HostException::idDoesNotExist($propertyName ?? 'timePeriodId', $timePeriodId);
@@ -198,7 +189,7 @@ class PartialUpdateHostValidation
      */
     public function assertIsValidTimezone(?int $timezoneId): void
     {
-        if ($timezoneId !== null && false === $this->readTimezoneRepository->exists($timezoneId) ) {
+        if ($timezoneId !== null && false === $this->readTimezoneRepository->exists($timezoneId)) {
             $this->error('Timezone does not exist', ['timezone_id' => $timezoneId]);
 
             throw HostException::idDoesNotExist('timezoneId', $timezoneId);
@@ -291,7 +282,7 @@ class PartialUpdateHostValidation
      */
     public function assertAreValidTemplates(array $templateIds, int $hostId): void
     {
-         if ($templateIds === []) {
+        if ($templateIds === []) {
 
             return;
         }
@@ -305,7 +296,7 @@ class PartialUpdateHostValidation
         if (
             in_array($hostId, $templateIds, true)
             || false === $this->inheritanceManager->isValidInheritanceTree($hostId, $templateIds)
-            ) {
+        ) {
             throw HostException::circularTemplateInheritance();
         }
     }
