@@ -1,7 +1,7 @@
 <?php
 
 /*
- * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -32,20 +32,12 @@ class NewHostGroup
     public const MAX_NAME_LENGTH = 200;
     public const MIN_NAME_LENGTH = 1;
     public const MAX_ALIAS_LENGTH = 200;
-    public const MAX_NOTES_LENGTH = 200;
-    public const MAX_NOTES_URL_LENGTH = 255;
-    public const MAX_ACTION_URL_LENGTH = 255;
     public const MAX_COMMENT_LENGTH = 65535;
 
     /**
      * @param string $name
      * @param string $alias
-     * @param string $notes
-     * @param string $notesUrl
-     * @param string $actionUrl
      * @param int|null $iconId FK
-     * @param int|null $iconMapId FK
-     * @param int|null $rrdRetention Days
      * @param GeoCoords|null $geoCoords
      * @param string $comment
      * @param bool $isActivated
@@ -55,12 +47,7 @@ class NewHostGroup
     public function __construct(
         protected string $name,
         protected string $alias = '',
-        protected string $notes = '',
-        protected string $notesUrl = '',
-        protected string $actionUrl = '',
         protected ?int $iconId = null,
-        protected ?int $iconMapId = null,
-        protected ?int $rrdRetention = null,
         protected null|GeoCoords $geoCoords = null,
         protected string $comment = '',
         protected bool $isActivated = true,
@@ -74,25 +61,12 @@ class NewHostGroup
         $this->alias = trim($this->alias);
         Assertion::maxLength($this->alias, self::MAX_ALIAS_LENGTH, "{$shortName}::alias");
 
-        $this->notes = trim($this->notes);
-        Assertion::maxLength($this->notes, self::MAX_NOTES_LENGTH, "{$shortName}::notes");
-
-        $this->notesUrl = trim($this->notesUrl);
-        Assertion::maxLength($this->notesUrl, self::MAX_NOTES_URL_LENGTH, "{$shortName}::notesUrl");
-
-        $this->actionUrl = trim($this->actionUrl);
-        Assertion::maxLength($this->actionUrl, self::MAX_ACTION_URL_LENGTH, "{$shortName}::actionUrl");
-
         $this->comment = trim($this->comment);
         Assertion::maxLength($this->comment, self::MAX_COMMENT_LENGTH, "{$shortName}::comment");
 
         if (null !== $iconId) {
             Assertion::positiveInt($iconId, "{$shortName}::iconId");
         }
-
-        if (null !== $iconMapId) {
-            Assertion::positiveInt($iconMapId, "{$shortName}::iconMapId");
-        }
     }
 
     public function getName(): string
@@ -105,36 +79,11 @@ class NewHostGroup
         return $this->alias;
     }
 
-    public function getNotes(): string
-    {
-        return $this->notes;
-    }
-
-    public function getNotesUrl(): string
-    {
-        return $this->notesUrl;
-    }
-
-    public function getActionUrl(): string
-    {
-        return $this->actionUrl;
-    }
-
     public function getIconId(): ?int
     {
         return $this->iconId;
     }
 
-    public function getIconMapId(): ?int
-    {
-        return $this->iconMapId;
-    }
-
-    public function getRrdRetention(): ?int
-    {
-        return $this->rrdRetention;
-    }
-
     public function getComment(): string
     {
         return $this->comment;
