@@ -27,6 +27,7 @@ use Centreon\Application\Controller\AbstractController;
 use Centreon\Domain\Log\LoggerTrait;
 use Core\Application\Common\UseCase\ErrorResponse;
 use Core\Application\Common\UseCase\InvalidArgumentResponse;
+use Core\Common\Application\Converter\YesNoDefaultConverter;
 use Core\HostTemplate\Application\Exception\HostTemplateException;
 use Core\HostTemplate\Application\UseCase\AddHostTemplate\AddHostTemplate;
 use Core\HostTemplate\Application\UseCase\AddHostTemplate\AddHostTemplateRequest;
@@ -75,7 +76,7 @@ final class AddHostTemplateController extends AbstractController
     private function executeUseCaseOnPrem(
         AddHostTemplate $useCase,
         AddHostTemplateOnPremPresenter $presenter,
-        Request $request,
+        Request $request
     ): Response {
         try {
             /**
@@ -153,7 +154,7 @@ final class AddHostTemplateController extends AbstractController
             $dto->flapDetectionEnabled = $data['flap_detection_enabled'] ?? 2;
             $dto->lowFlapThreshold = $data['low_flap_threshold'] ?? null;
             $dto->highFlapThreshold = $data['high_flap_threshold'] ?? null;
-            $dto->eventHandlerEnabled = $data['event_handler_enabled'] ?? 2;
+            $dto->eventHandlerEnabled = YesNoDefaultConverter::fromScalar($data['event_handler_enabled'] ?? 2);
             $dto->eventHandlerCommandId = $data['event_handler_command_id'] ?? null;
             $dto->eventHandlerCommandArgs = $data['event_handler_command_args'] ?? [];
             $dto->noteUrl = $data['note_url'] ?? '';
@@ -188,7 +189,7 @@ final class AddHostTemplateController extends AbstractController
     private function executeUseCaseSaas(
         AddHostTemplate $useCase,
         AddHostTemplateSaasPresenter $presenter,
-        Request $request,
+        Request $request
     ): Response {
         try {
             /**
@@ -199,6 +200,8 @@ final class AddHostTemplateController extends AbstractController
              *     snmp_community?: string,
              *     timezone_id?: null|int,
              *     severity_id?: null|int,
+             *     check_command_id?: null|int,
+             *     check_command_args?: string[],
              *     check_timeperiod_id?: null|int,
              *     max_check_attempts?: null|int,
              *     normal_check_interval?: null|int,
@@ -209,7 +212,9 @@ final class AddHostTemplateController extends AbstractController
              *     icon_id?: null|int,
              *     categories?: int[],
              *     templates?: int[],
-             *     macros?: array<array{name:string,value:null|string,is_password:bool,description:null|string}>
+             *     macros?: array<array{name:string,value:null|string,is_password:bool,description:null|string}>,
+             *     event_handler_enabled?: int,
+             *     event_handler_command_id?: null|int
              * } $data
              */
             $data = $this->validateAndRetrieveDataSent($request, __DIR__ . '/AddHostTemplateSaasSchema.json');
@@ -224,6 +229,8 @@ final class AddHostTemplateController extends AbstractController
             $dto->retryCheckInterval = $data['retry_check_interval'] ?? null;
             $dto->timezoneId = $data['timezone_id'] ?? null;
             $dto->severityId = $data['severity_id'] ?? null;
+            $dto->checkCommandId = $data['check_command_id'] ?? null;
+            $dto->checkCommandArgs = $data['check_command_args'] ?? [];
             $dto->checkTimeperiodId = $data['check_timeperiod_id'] ?? null;
             $dto->noteUrl = $data['note_url'] ?? '';
             $dto->note = $data['note'] ?? '';
@@ -232,6 +239,8 @@ final class AddHostTemplateController extends AbstractController
             $dto->templates = $data['templates'] ?? [];
             $dto->macros = $data['macros'] ?? [];
             $dto->iconId = $data['icon_id'] ?? null;
+            $dto->eventHandlerEnabled = YesNoDefaultConverter::fromScalar($data['event_handler_enabled'] ?? 2);
+            $dto->eventHandlerCommandId = $data['event_handler_command_id'] ?? null;
 
             $useCase($dto, $presenter);
         } catch (\InvalidArgumentException $ex) {
