@@ -56,7 +56,7 @@ class DbWriteHostTemplateActionLogRepository extends AbstractRepositoryRDB imple
         private readonly ContactInterface $contact,
         private readonly ReadHostTemplateRepositoryInterface $readHostTemplateRepository,
         private readonly WriteActionLogRepositoryInterface $writeActionLogRepository,
-        DatabaseConnection $db,
+        DatabaseConnection $db
     ) {
         $this->db = $db;
     }
@@ -136,6 +136,7 @@ class DbWriteHostTemplateActionLogRepository extends AbstractRepositoryRDB imple
             $currentHostTemplateDetails = $this->getHostTemplatePropertiesAsArray($currentHostTemplate);
             $updatedHostTemplateDetails = $this->getHostTemplatePropertiesAsArray($hostTemplate);
             $diff = array_diff_assoc($updatedHostTemplateDetails, $currentHostTemplateDetails);
+            // FIXME: $diff variable never used & do we want to always createActionLog even if nothing has changed ?
 
             $this->writeHostTemplateRepository->update($hostTemplate);
 
@@ -212,6 +213,7 @@ class DbWriteHostTemplateActionLogRepository extends AbstractRepositoryRDB imple
             $hostTemplatePropertiesArray[$property->getName()] = $value;
         }
 
+        /** @var array<string,int|bool|string> $hostTemplatePropertiesArray */
         return $hostTemplatePropertiesArray;
     }
 }
