@@ -1,7 +1,7 @@
 <?php
 
 /*
- * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -92,7 +92,7 @@ class FindHostPresenter extends AbstractPresenter implements FindHostPresenterIn
 
         $acknowledgement = null;
 
-        if (! empty($response->acknowledgement)) {
+        if ($response->acknowledgement !== []) {
             // Convert Acknowledgement dates into ISO 8601 format
             $acknowledgement = $response->acknowledgement;
             $acknowledgement['entry_time'] = $this->formatDateToIso8601($response->acknowledgement['entry_time']);
