@@ -24,7 +24,7 @@ declare(strict_types=1);
 namespace Core\Notification\Infrastructure\API\DeleteNotifications;
 
 use Centreon\Domain\Log\LoggerTrait;
-use Core\Application\Common\UseCase\{AbstractPresenter, MultiStatusResponse, ResponseStatusInterface};
+use Core\Application\Common\UseCase\{AbstractPresenter, ResponseStatusInterface};
 use Core\Infrastructure\Common\Api\Router;
 use Core\Infrastructure\Common\Presenter\PresenterFormatterInterface;
 use Core\Notification\Application\UseCase\DeleteNotifications\{
@@ -46,7 +46,7 @@ final class DeleteNotificationsPresenter extends AbstractPresenter implements De
      */
     public function __construct(
         protected PresenterFormatterInterface $presenterFormatter,
-        private readonly Router $router,
+        private readonly Router $router
     ) {
         parent::__construct($presenterFormatter);
     }
@@ -65,7 +65,7 @@ final class DeleteNotificationsPresenter extends AbstractPresenter implements De
                 ], $response->results),
             ];
 
-            $this->present(new MultiStatusResponse($multiStatusResponse));
+            $this->present($multiStatusResponse);
         } else {
             $this->setResponseStatus($response);
         }
@@ -81,7 +81,7 @@ final class DeleteNotificationsPresenter extends AbstractPresenter implements De
         return match ($code) {
             ResponseCode::OK => Response::HTTP_NO_CONTENT,
             ResponseCode::NotFound => Response::HTTP_NOT_FOUND,
-            ResponseCode::Error => Response::HTTP_INTERNAL_SERVER_ERROR,
+            ResponseCode::Error => Response::HTTP_INTERNAL_SERVER_ERROR
         };
     }
 
