@@ -30,6 +30,8 @@ use CentreonModule\ServiceProvider;
 use Core\Application\Common\UseCase\ErrorResponse;
 use Core\Application\Common\UseCase\ForbiddenResponse;
 use Core\Application\Common\UseCase\NoContentResponse;
+use Core\Engine\Application\Repository\EngineRepositoryInterface;
+use Core\Installation\Infrastructure\InstallationHelper;
 use Core\Platform\Application\Repository\ReadUpdateRepositoryInterface;
 use Core\Platform\Application\Repository\ReadVersionRepositoryInterface;
 use Core\Platform\Application\Repository\UpdateLockerRepositoryInterface;
@@ -61,6 +63,8 @@ final class UpdateVersions
         private readonly WriteUpdateRepositoryInterface $writeUpdateRepository,
         Container $dependencyInjector,
         private readonly ContactInterface $user,
+        private readonly InstallationHelper $installationHelper,
+        private readonly EngineRepositoryInterface $engineRepository,
     ) {
         /** @var CentreonModuleService $service */
         $service = $dependencyInjector[ServiceProvider::CENTREON_MODULE];
@@ -84,6 +88,7 @@ final class UpdateVersions
             $this->updateInstalledModules();
             $this->updateInstalledWidgets();
             $this->unlockUpdate();
+            $this->writeEngineContextConfiguration();
         } catch (\Throwable $exception) {
             $this->error(
                 $exception->getMessage(),
@@ -107,7 +112,7 @@ final class UpdateVersions
         $this->info('Starting centreon-web update process');
         $availableUpdates = $this->getAvailableUpdates($this->getCurrentVersion());
 
-        if ($availableUpdates !== []) {
+        if ([] !== $availableUpdates) {
             $this->info('Available updates found for centreon-web', ['updates' => $availableUpdates]);
             $this->runUpdates($availableUpdates);
         } else {
@@ -276,4 +281,15 @@ final class UpdateVersions
             throw UpdateVersionsException::errorWhenApplyingPostUpdate($exception);
         }
     }
+
+    private function writeEngineContextConfiguration(): void
+    {
+        try {
+            if ($this->engineRepository->engineSecretsHasContent() === false) {
+                $this->installationHelper->writeEngineContextFile();
+            }
+        } catch (\Throwable $exception) {
+            throw UpdateVersionsException::errorWhenWritingEngineContextConfiguration($exception);
+        }
+    }
 }
