@@ -52,7 +52,7 @@ class CountResourcesInputDenormalizer implements DenormalizerInterface, Denormal
         mixed $data,
         string $type,
         ?string $format = null,
-        array $context = [],
+        array $context = []
     ): CountResourcesInput {
         $context[self::ALREADY_CALL] = true;
 
@@ -97,4 +97,15 @@ class CountResourcesInputDenormalizer implements DenormalizerInterface, Denormal
 
         return $type === CountResourcesInput::class && is_array($data);
     }
+
+    /**
+     * @param ?string $format
+     * @return array<class-string|'*'|'object'|string, bool|null>
+     */
+    public function getSupportedTypes(?string $format): array
+    {
+        return [
+            CountResourcesInput::class => false,
+        ];
+    }
 }
