@@ -52,7 +52,7 @@ class ExportResourcesInputDenormalizer implements DenormalizerInterface, Denorma
         mixed $data,
         string $type,
         ?string $format = null,
-        array $context = [],
+        array $context = []
     ): ExportResourcesInput {
         $context[self::ALREADY_CALL] = true;
         if (isset($data['all_pages']) && $data['all_pages'] !== '') {
@@ -102,4 +102,15 @@ class ExportResourcesInputDenormalizer implements DenormalizerInterface, Denorma
 
         return $type === ExportResourcesInput::class && is_array($data);
     }
+
+    /**
+     * @param ?string $format
+     * @return array<class-string|'*'|'object'|string, bool|null>
+     */
+    public function getSupportedTypes(?string $format): array
+    {
+        return [
+            ExportResourcesInput::class => false,
+        ];
+    }
 }
