@@ -57,7 +57,7 @@ final class ExportResourcesPresenterCsv extends AbstractPresenter implements Exp
      */
     public function __construct(
         PresenterFormatterInterface $presenterFormatter,
-        private readonly ExceptionLogger $exceptionLogger,
+        private readonly ExceptionLogger $exceptionLogger
     ) {
         parent::__construct($presenterFormatter);
     }
@@ -137,7 +137,8 @@ final class ExportResourcesPresenterCsv extends AbstractPresenter implements Exp
                 _('Severity') => $resource->getSeverity()?->getLevel() ?? '',
                 _('Notes') => $this->getResourceNotes($resource),
                 _('Action') => $this->formatUrl(
-                    $resource->getLinks()->getExternals()->getActionUrl() ?? '', $resource
+                    $resource->getLinks()->getExternals()->getActionUrl() ?? '',
+                    $resource
                 ),
                 _('State') => _($this->getResourceState($resource)),
                 _('Alias') => $resource->getAlias() ?? '',
@@ -213,7 +214,7 @@ final class ExportResourcesPresenterCsv extends AbstractPresenter implements Exp
      */
     private function sortHeaderByFilteredColumns(
         StringCollection $csvHeader,
-        StringCollection $filteredColumns,
+        StringCollection $filteredColumns
     ): StringCollection {
         $csvHeader->sortByKeys(function ($keyA, $keyB) use ($filteredColumns) {
             // if the key is a resource or parent_resource, we keep all columns starting with this key
