@@ -1,7 +1,7 @@
 <?php
 
 /*
- * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -52,8 +52,7 @@ final class FindResourcesByParentController extends AbstractController
         FindResourcesByParent $useCase,
         FindResourcesByParentPresenter $presenter,
         Request $request
-    ): Response
-    {
+    ): Response {
         $this->denyAccessUnlessGrantedForApiRealtime();
 
         $filter = $this->validator->validateAndRetrieveRequestParameters($request->query->all());
