@@ -1,7 +1,7 @@
 <?php
 
 /*
- * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -172,7 +172,7 @@ class FindResourcesByParentPresenter extends AbstractPresenter implements FindRe
                 'downtime' => $endpoints['downtime'],
                 'check' => $endpoints['check'],
                 'forced_check' => $endpoints['forced_check'],
-                'metrics' => $endpoints['metrics'],
+                'metrics' => $endpoints['metrics'] ?? null,
             ],
             'uris' => $this->hypermediaCreator->createInternalUris($parameters),
             'externals' => [
@@ -206,6 +206,8 @@ class FindResourcesByParentPresenter extends AbstractPresenter implements FindRe
             ],
             'is_in_downtime' => $response->isInDowntime,
             'is_acknowledged' => $response->isAcknowledged,
+            'is_in_flapping' => $response->isInFlapping,
+            'percent_state_change' => $response->percentStateChange,
             'has_active_checks_enabled' => $response->withActiveChecks,
             'has_passive_checks_enabled' => $response->withPassiveChecks,
             'last_status_change' => $this->formatDateToIso8601($response->lastStatusChange),
