@@ -1,7 +1,7 @@
 <?php
 
 /*
- * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -136,6 +136,8 @@ class DbResourceFactory
             ->setStatus($status)
             ->setInDowntime((int) $record['in_downtime'] === 1)
             ->setAcknowledged((int) $record['acknowledged'] === 1)
+            ->setFlapping((int) $record['flapping'] === 1)
+            ->setPercentStateChange(self::getFloatOrNull($record['percent_state_change']))
             ->setStateType((int) $record['status_confirmed'])
             ->setName($name)
             ->setAlias($alias)
