@@ -1,7 +1,7 @@
 <?php
 
 /*
- * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -24,6 +24,8 @@ declare(strict_types=1);
 namespace Core\Security\AccessGroup\Application\Repository;
 
 use Centreon\Domain\Contact\Interfaces\ContactInterface;
+use Core\Common\Domain\Exception\RepositoryException;
+use Core\Security\AccessGroup\Domain\Collection\AccessGroupCollection;
 use Core\Security\AccessGroup\Domain\Model\AccessGroup;
 
 interface ReadAccessGroupRepositoryInterface
@@ -31,7 +33,7 @@ interface ReadAccessGroupRepositoryInterface
     /**
      * Find all access groups.
      *
-     * @throws \Throwable
+     * @throws RepositoryException
      *
      * @return AccessGroup[]
      */
@@ -42,18 +44,28 @@ interface ReadAccessGroupRepositoryInterface
      *
      * @param ContactInterface $contact contact for which we want to find the access groups
      *
-     * @throws \Throwable
+     * @throws RepositoryException
      *
      * @return AccessGroup[]
      */
     public function findByContact(ContactInterface $contact): array;
 
+    /**
+     * Find all access groups according to a contact.
+     *
+     * @param int $contactId
+     *
+     * @throws RepositoryException
+     * @return AccessGroupCollection
+     */
+    public function findByContactId(int $contactId): AccessGroupCollection;
+
     /**
      * Find all access groups according to a contact with filter.
      *
      * @param ContactInterface $contact
      *
-     * @throws \Throwable
+     * @throws RepositoryException
      *
      * @return AccessGroup[]
      */
@@ -62,7 +74,7 @@ interface ReadAccessGroupRepositoryInterface
     /**
      * @param int[] $accessGroupIds
      *
-     * @throws \Throwable
+     * @throws RepositoryException
      *
      * @return AccessGroup[]
      */
@@ -73,9 +85,19 @@ interface ReadAccessGroupRepositoryInterface
      *
      * @param int[] $accessGroupIds
      *
-     * @throws \Throwable
+     * @throws RepositoryException
      *
      * @return bool
      */
     public function hasAccessToResources(array $accessGroupIds): bool;
+
+    /**
+     * Finds ACL resources by a hostgroup ID.
+     *
+     * @param int $hostGroupId
+     *
+     * @throws RepositoryException
+     * @return int[] An array of distinct ACL resource IDs
+     */
+    public function findAclResourcesByHostGroupId(int $hostGroupId): array;
 }
