@@ -40,7 +40,7 @@ final class FindVaultConfiguration
      */
     public function __construct(
         private readonly ReadVaultConfigurationRepositoryInterface $readVaultConfigurationRepository,
-        private readonly ContactInterface $user,
+        private readonly ContactInterface $user
     ) {
     }
 
