@@ -47,6 +47,7 @@ class VaultConfiguration
     public const DATABASE_USERNAME_KEY = '_DBUSERNAME';
     public const DATABASE_PASSWORD_KEY = '_DBPASSWORD';
     public const KNOWLEDGE_BASE_KEY = '_KBPASSWORD';
+    public const GORGONE_PASSWORD = '_GORGONE_PASSWORD';
 
     /** Patterns Constants */
     public const VAULT_PATH_PATTERN = 'secret::';
@@ -76,7 +77,7 @@ class VaultConfiguration
         private string $rootPath,
         private string $encryptedRoleId,
         private string $encryptedSecretId,
-        private string $salt,
+        private string $salt
     ) {
         $this->setName($name);
         $this->setAddress($address);
