@@ -1,7 +1,7 @@
 <?php
 
 /*
- * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -55,12 +55,12 @@ use Utility\SqlConcatenator;
  */
 class DbReadServiceGroupRepository extends AbstractRepositoryDRB implements ReadServiceGroupRepositoryInterface
 {
-    use SqlMultipleBindTrait,
-        HostRepositoryTrait,
-        HostGroupRepositoryTrait,
-        ServiceCategoryRepositoryTrait,
-        HostCategoryRepositoryTrait,
-        ServiceGroupRepositoryTrait;
+    use SqlMultipleBindTrait;
+    use HostRepositoryTrait;
+    use HostGroupRepositoryTrait;
+    use ServiceCategoryRepositoryTrait;
+    use HostCategoryRepositoryTrait;
+    use ServiceGroupRepositoryTrait;
 
     /**
      * @param DatabaseConnection $db
