@@ -23,13 +23,12 @@ declare(strict_types=1);
 
 namespace Core\TimePeriod\Infrastructure\API\FindTimePeriod;
 
-use ArrayObject;
 use Core\TimePeriod\Domain\Model\TimePeriod;
 use Core\TimePeriod\Domain\Rules\TimePeriodRuleStrategyInterface;
 use DateTimeImmutable;
+use Symfony\Component\DependencyInjection\Attribute\Autowire;
 use Symfony\Component\Serializer\Exception\ExceptionInterface;
 use Symfony\Component\Serializer\Normalizer\NormalizerInterface;
-use Symfony\Component\Serializer\Normalizer\ObjectNormalizer;
 use Traversable;
 
 class TimePeriodNormalizer implements NormalizerInterface
@@ -38,11 +37,12 @@ class TimePeriodNormalizer implements NormalizerInterface
     private array $strategies;
 
     /**
-     * @param ObjectNormalizer $normalizer
      * @param Traversable<TimePeriodRuleStrategyInterface> $strategies
+     * @param NormalizerInterface $normalizer
      */
     public function __construct(
-        private readonly ObjectNormalizer $normalizer,
+        #[Autowire(service: 'serializer.normalizer.object')]
+        private readonly NormalizerInterface $normalizer,
         Traversable $strategies,
     ) {
         $this->strategies = iterator_to_array($strategies);
@@ -55,13 +55,13 @@ class TimePeriodNormalizer implements NormalizerInterface
      *
      * @throws ExceptionInterface
      *
-     * @return array<string, mixed>|ArrayObject<int, mixed>|bool|float|int|string|null
+     * @return array<string, mixed>
      */
     public function normalize(
         mixed $object,
         ?string $format = null,
-        array $context = [],
-    ): float|int|ArrayObject|bool|array|string|null {
+        array $context = []
+    ): array {
 
         /** @var array<string, bool|float|int|string> $data */
         $data = $this->normalizer->normalize($object, $format, $context);
@@ -70,8 +70,24 @@ class TimePeriodNormalizer implements NormalizerInterface
         return $data;
     }
 
-    public function supportsNormalization(mixed $data, ?string $format = null): bool
+    /**
+     * @param array<string, mixed> $context
+     * @param mixed $data
+     * @param ?string $format
+     */
+    public function supportsNormalization(mixed $data, ?string $format = null, array $context = []): bool
     {
         return $data instanceof TimePeriod;
     }
+
+    /**
+     * @param ?string $format
+     * @return array<class-string|'*'|'object'|string, bool|null>
+     */
+    public function getSupportedTypes(?string $format): array
+    {
+        return [
+            TimePeriod::class => true,
+        ];
+    }
 }
