@@ -25,8 +25,6 @@ namespace Security\Domain\Authentication;
 
 use Centreon\Domain\Authentication\Exception\AuthenticationException;
 use Centreon\Domain\Log\LoggerTrait;
-use Core\Common\Domain\Exception\RepositoryException;
-use Core\Common\Infrastructure\ExceptionLogger\ExceptionLogger;
 use Core\Security\Authentication\Application\Provider\ProviderAuthenticationFactoryInterface;
 use Core\Security\Authentication\Application\Repository\ReadTokenRepositoryInterface;
 use Core\Security\Authentication\Domain\Model\AuthenticationTokens;
@@ -52,7 +50,7 @@ class AuthenticationService implements AuthenticationServiceInterface
         private SessionRepositoryInterface $sessionRepository,
         private ReadConfigurationRepositoryInterface $readConfigurationFactory,
         private ProviderAuthenticationFactoryInterface $providerFactory,
-        private ReadTokenRepositoryInterface $readTokenRepository,
+        private ReadTokenRepositoryInterface $readTokenRepository
     ) {
     }
 
@@ -68,20 +66,14 @@ class AuthenticationService implements AuthenticationServiceInterface
             return false;
         }
 
-        try {
-            $configuration = $this->readConfigurationFactory->getConfigurationById(
-                $authenticationTokens->getConfigurationProviderId()
-            );
-        } catch (RepositoryException $e) {
-            ExceptionLogger::create()->log($e);
-
-            return false;
-        }
+        $configuration = $this->readConfigurationFactory->getConfigurationById(
+            $authenticationTokens->getConfigurationProviderId()
+        );
 
         try {
             $provider = $this->providerFactory->create($configuration->getType());
-        } catch (ProviderException $e) {
-            ExceptionLogger::create()->log($e);
+        } catch (ProviderException) {
+            $this->notice('[AUTHENTICATION SERVICE] Provider not found');
 
             return false;
         }
@@ -136,10 +128,10 @@ class AuthenticationService implements AuthenticationServiceInterface
     /**
      * @inheritDoc
      */
-    public function updateAuthenticationTokens(AuthenticationTokens $authenticationToken): void
+    public function updateAuthenticationTokens(AuthenticationTokens $authenticationTokens): void
     {
         try {
-            $this->authenticationRepository->updateAuthenticationTokens($authenticationToken);
+            $this->authenticationRepository->updateAuthenticationTokens($authenticationTokens);
         } catch (\Exception $ex) {
             throw AuthenticationException::updateAuthenticationTokens($ex);
         }
