@@ -1,7 +1,7 @@
 <?php
 
 /*
- * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -25,6 +25,9 @@ namespace Security;
 
 use Centreon\Domain\Contact\Interfaces\ContactRepositoryInterface;
 use Centreon\Domain\Exception\ContactDisabledException;
+use Centreon\Domain\Log\LoggerTrait;
+use Core\Security\Token\Application\Repository\ReadTokenRepositoryInterface;
+use Core\Security\Token\Domain\Model\ApiToken;
 use Security\Domain\Authentication\Interfaces\AuthenticationRepositoryInterface;
 use Security\Domain\Authentication\Model\LocalProvider;
 use Symfony\Component\HttpFoundation\JsonResponse;
@@ -47,14 +50,7 @@ use Symfony\Component\Security\Http\EntryPoint\AuthenticationEntryPointInterface
  */
 class TokenAPIAuthenticator extends AbstractAuthenticator implements AuthenticationEntryPointInterface
 {
-    /** @var AuthenticationRepositoryInterface */
-    private $authenticationRepository;
-
-    /** @var ContactRepositoryInterface */
-    private $contactRepository;
-
-    /** @var LocalProvider */
-    private $localProvider;
+    use LoggerTrait;
 
     /**
      * TokenAPIAuthenticator constructor.
@@ -62,15 +58,14 @@ class TokenAPIAuthenticator extends AbstractAuthenticator implements Authenticat
      * @param AuthenticationRepositoryInterface $authenticationRepository
      * @param ContactRepositoryInterface $contactRepository
      * @param LocalProvider $localProvider
+     * @param ReadTokenRepositoryInterface $readTokenRepository
      */
     public function __construct(
-        AuthenticationRepositoryInterface $authenticationRepository,
-        ContactRepositoryInterface $contactRepository,
-        LocalProvider $localProvider
+        private AuthenticationRepositoryInterface $authenticationRepository,
+        private ContactRepositoryInterface $contactRepository,
+        private LocalProvider $localProvider,
+        private ReadTokenRepositoryInterface $readTokenRepository,
     ) {
-        $this->authenticationRepository = $authenticationRepository;
-        $this->contactRepository = $contactRepository;
-        $this->localProvider = $localProvider;
     }
 
     /**
@@ -110,6 +105,8 @@ class TokenAPIAuthenticator extends AbstractAuthenticator implements Authenticat
      */
     public function onAuthenticationSuccess(Request $request, TokenInterface $token, string $providerKey): ?Response
     {
+        $this->logTokenUsage($request);
+
         return null;
     }
 
@@ -166,8 +163,36 @@ class TokenAPIAuthenticator extends AbstractAuthenticator implements Authenticat
             throw new ContactDisabledException();
         }
 
-        $this->authenticationRepository->updateProviderTokenExpirationDate($providerToken);
+        if ($this->readTokenRepository->isTokenTypeAuto($apiToken)) {
+            $this->authenticationRepository->updateProviderTokenExpirationDate($providerToken);
+        }
 
         return $contact;
     }
+
+    private function logTokenUsage(Request $request): void
+    {
+        try {
+            $tokenString = $request->headers->get('X-AUTH-TOKEN');
+            if ($tokenString && ! $this->readTokenRepository->isTokenTypeAuto($tokenString)) {
+                /** @var ApiToken|null $apiToken */
+                $apiToken = $this->readTokenRepository->find($tokenString);
+                if ($apiToken instanceof ApiToken) {
+                    $this->info(
+                        'Api token used',
+                        [
+                            'event' => 'Token usage',
+                            'datetime' => (new \DateTimeImmutable())->format('Y-m-d H:i:s'),
+                            'user_id' => $apiToken->getUserId(),
+                            'token_name' => $apiToken->getName(),
+                            'endpoint' => $request->getRequestUri(),
+                            'http_method' => $request->getMethod(),
+                        ]
+                    );
+                }
+            }
+        } catch (\Throwable $e) {
+            $this->error('Token usage log failure');
+        }
+    }
 }
