@@ -1,5 +1,4 @@
 import { Given, Then, When } from '@badeball/cypress-cucumber-preprocessor';
-import { PAGES } from 'e2e/fixtures/shared/constants/pages';
 
 beforeEach(() => {
   cy.startContainers();
@@ -23,7 +22,11 @@ Given('I am logged in as an Administrator', () => {
 });
 
 When('I navigate to "Administration" > "ACL" > "Actions Access"', () => {
-  cy.visit(PAGES.configuration.aclActionsAccessLegacy);
+  cy.navigateTo({
+    page: 'Actions Access',
+    rootItemNumber: 4,
+    subMenu: 'ACL'
+  });
   cy.wait('@getTimeZone');
 });
 
@@ -37,7 +40,11 @@ Then('I see {string} listed as an action', (actionName: string) => {
 });
 
 When('I navigate to "Administration" > "ACL" > "Menus Access"', () => {
-  cy.visit(PAGES.configuration.aclMenusAccessLegacy);
+  cy.navigateTo({
+    page: 'Menus Access',
+    rootItemNumber: 4,
+    subMenu: 'ACL'
+  });
   cy.wait('@getTimeZone');
 });
 
