@@ -1,6 +1,5 @@
 import { Given, Then, When } from '@badeball/cypress-cucumber-preprocessor';
 
-import { PAGES } from 'e2e/fixtures/shared/constants/pages';
 import { configureProviderAcls } from '../../../../commons';
 import {
   configureOpenIdConnect,
@@ -45,7 +44,10 @@ Given('an administrator is logged on the platform', () => {
 When(
   'the administrator sets valid settings in the OpenID Connect configuration form and saves the form',
   () => {
-    cy.visit(PAGES.configuration.authentication)
+    cy.navigateTo({
+      page: 'Authentication',
+      rootItemNumber: 4
+    })
       .get('div[role="tablist"] button:nth-child(2)')
       .click();
 
@@ -66,7 +68,10 @@ Then('the configuration is saved and secrets are not visible', () => {
 });
 
 When('the administrator configures the authentication mode', () => {
-  cy.visit(PAGES.configuration.authentication)
+  cy.navigateTo({
+    page: 'Authentication',
+    rootItemNumber: 4
+  })
     .get('div[role="tablist"] button:nth-child(2)')
     .click();
 });
@@ -96,7 +101,10 @@ Then(
 
 Given('an administrator is relogged on the platform', () => {
   cy.loginByTypeOfUser({ jsonName: 'admin', loginViaApi: true })
-    .visit(PAGES.configuration.authentication)
+    .navigateTo({
+      page: 'Authentication',
+      rootItemNumber: 4
+    })
     .get('div[role="tablist"] button:nth-child(2)')
     .click();
 
@@ -106,7 +114,10 @@ Given('an administrator is relogged on the platform', () => {
 When(
   'the administrator activates OpenID Connect authentication on the platform',
   () => {
-    cy.visit(PAGES.configuration.authentication)
+    cy.navigateTo({
+      page: 'Authentication',
+      rootItemNumber: 4
+    })
       .get('div[role="tablist"] button:nth-child(2)')
       .click();
 
