@@ -1,5 +1,4 @@
 import { Given, Then, When } from '@badeball/cypress-cucumber-preprocessor';
-import { PAGES } from 'e2e/fixtures/shared/constants/pages';
 
 before(() => {
   cy.startContainers();
@@ -28,7 +27,10 @@ Given('an administrator logged in the platform', () => {
 });
 
 When('the administrator first configures the authentication mode', () => {
-  cy.visit(PAGES.configuration.authentication)
+  cy.navigateTo({
+    page: 'Authentication',
+    rootItemNumber: 4
+  })
     .get('div[role="tablist"] button:nth-child(3)')
     .click();
   cy.wait('@getWebSSOProvider');
