@@ -1,10 +1,13 @@
 import { Given, Then, When } from '@badeball/cypress-cucumber-preprocessor';
 
-import { PAGES } from 'e2e/fixtures/shared/constants/pages';
 import contactTemplates from '../../../fixtures/users/contact.json';
 
 const checkFirstContactTemplateFromListing = () => {
-  cy.visit(PAGES.configuration.contactTemplatesLegacy);
+  cy.navigateTo({
+    page: 'Contact Templates',
+    rootItemNumber: 3,
+    subMenu: 'Users'
+  });
   cy.wait('@getTimeZone');
   cy.getIframeBody().find('div.md-checkbox.md-checkbox-inline').eq(1).click();
   cy.getIframeBody()
@@ -48,17 +51,29 @@ Given('an admin user is logged in a Centreon server', () => {
 });
 
 When('a contact template is configured', () => {
-  cy.visit(PAGES.configuration.contactTemplatesLegacy);
+  cy.navigateTo({
+    page: 'Contact Templates',
+    rootItemNumber: 3,
+    subMenu: 'Users'
+  });
   cy.wait('@getTimeZone');
   cy.getIframeBody().contains('a', 'Add').click();
-  cy.addOrUpdateContactTemplate(contactTemplates.defaultTemplate);
+  cy.addOrUpdateContactTemplate({
+    ...contactTemplates.defaultTemplate,
+    usedContactTemplate: contactTemplates.defaultTemplate.usedCTemplate,
+    notCommands: contactTemplates.defaultTemplate.NotCommands
+  });
 });
 
 When(
   'the user updates the properties of the configured contact template',
   () => {
     cy.getIframeBody().contains(contactTemplates.defaultTemplate.alias).click();
-    cy.addOrUpdateContactTemplate(contactTemplates.templateForUpdate);
+    cy.addOrUpdateContactTemplate({
+      ...contactTemplates.templateForUpdate,
+      usedContactTemplate: contactTemplates.templateForUpdate.usedCTemplate,
+      notCommands: contactTemplates.templateForUpdate.NotCommands
+    });
   }
 );
 
@@ -95,7 +110,7 @@ Then('the properties are updated', () => {
     .find('option:selected')
     .then(($selectedOptions) => {
       const selectedTexts = Array.from($selectedOptions).map(
-        (option) => option.textContent
+        (option) => (option as HTMLOptionElement).text
       );
       expect(selectedTexts).to.include.members([
         contactTemplates.defaultTemplate.NotCommands,
@@ -115,7 +130,7 @@ Then('the properties are updated', () => {
     .find('option:selected')
     .then(($selectedOptions) => {
       const selectedTexts = Array.from($selectedOptions).map(
-        (option) => option.textContent
+        (option) => (option as HTMLOptionElement).text
       );
       expect(selectedTexts).to.include.members([
         contactTemplates.defaultTemplate.NotCommands,
@@ -162,7 +177,7 @@ Then('a new contact template is created with identical properties', () => {
     .find('option:selected')
     .then(($selectedOptions) => {
       const selectedTexts = Array.from($selectedOptions).map(
-        (option) => option.textContent
+        (option) => (option as HTMLOptionElement).text
       );
       expect(selectedTexts).to.include.members([
         contactTemplates.defaultTemplate.NotCommands
@@ -177,7 +192,7 @@ Then('a new contact template is created with identical properties', () => {
     .find('option:selected')
     .then(($selectedOptions) => {
       const selectedTexts = Array.from($selectedOptions).map(
-        (option) => option.textContent
+        (option) => (option as HTMLOptionElement).text
       );
       expect(selectedTexts).to.include.members([
         contactTemplates.defaultTemplate.NotCommands
