@@ -1,4 +1,29 @@
-import { PAGES } from 'e2e/fixtures/shared/constants/pages';
+interface Contact {
+  alias: string;
+  name: string;
+  email: string;
+  pager: string;
+  template: string;
+  isNotificationsEnabled: string;
+}
+
+interface ContactGroup {
+  name: string;
+  alias: string;
+  linkedContact: string;
+  status: string;
+  comment: string;
+}
+
+interface ContactTemplate {
+  alias: string;
+  name: string;
+  usedContactTemplate: string;
+  defaultPage: string;
+  isNotEnabled: string;
+  timePeriod: string;
+  notCommands: string;
+}
 
 Cypress.Commands.add('addOrUpdateContact', (body: Contact) => {
   cy.wait('@getTimeZone');
@@ -9,6 +34,9 @@ Cypress.Commands.add('addOrUpdateContact', (body: Contact) => {
   cy.getIframeBody().find('input[id="contact_pager"]').clear().type(body.pager);
   cy.getIframeBody().find('#contact_template_id').select(body.template);
   cy.getIframeBody().contains('label', body.isNotificationsEnabled).click();
+  cy.getIframeBody().find('input.btc.bt_success[name^="submit"]').eq(0).click();
+  cy.wait('@getTimeZone');
+  cy.exportConfig();
 });
 
 Cypress.Commands.add('addOrUpdateContactGroup', (body: ContactGroup) => {
@@ -22,7 +50,7 @@ Cypress.Commands.add('addOrUpdateContactGroup', (body: ContactGroup) => {
   cy.getIframeBody().contains('div', body.linkedContact).click();
 
   cy.getIframeBody().find('input[class="select2-search__field"]').eq(1).click();
-  cy.wait('@getAclGroups');
+  cy.wait('@getACLGroups');
   cy.getIframeBody().contains('div', 'ALL').click();
 
   cy.getIframeBody().contains(body.status).click();
@@ -47,7 +75,7 @@ Cypress.Commands.add('addOrUpdateContactTemplate', (body: ContactTemplate) => {
   cy.getIframeBody().find('input[name="contact_name"]').clear().type(body.name);
   cy.getIframeBody()
     .find('select[name="contact_template_id"]')
-    .select(body.usedCTemplate);
+    .select(body.usedContactTemplate);
   cy.getIframeBody()
     .find('select[name="default_page"]')
     .select(body.defaultPage);
@@ -60,7 +88,7 @@ Cypress.Commands.add('addOrUpdateContactTemplate', (body: ContactTemplate) => {
   cy.getIframeBody().find(`div[title="${body.timePeriod}"]`).click();
   cy.getIframeBody().find('input[class="select2-search__field"]').eq(0).click();
   cy.wait('@getNotCommands');
-  cy.getIframeBody().find(`div[title="${body.NotCommands}"]`).click();
+  cy.getIframeBody().find(`div[title="${body.notCommands}"]`).click();
   cy.getIframeBody().find('label[for="sWarning"]').click();
   cy.getIframeBody()
     .find('span[id="select2-timeperiod_tp_id2-container"]')
@@ -69,7 +97,7 @@ Cypress.Commands.add('addOrUpdateContactTemplate', (body: ContactTemplate) => {
   cy.getIframeBody().find(`div[title="${body.timePeriod}"]`).click();
   cy.getIframeBody().find('input[class="select2-search__field"]').eq(1).click();
   cy.wait('@getNotCommands');
-  cy.getIframeBody().find(`div[title="${body.NotCommands}"]`).click();
+  cy.getIframeBody().find(`div[title="${body.notCommands}"]`).click();
   cy.getIframeBody().find('input.btc.bt_success[name^="submit"]').eq(1).click();
   cy.wait('@getTimeZone');
   cy.exportConfig();
@@ -100,40 +128,6 @@ Cypress.Commands.add(
   }
 );
 
-Cypress.Commands.add('visitContactsPage', () => {
-  cy.visit(PAGES.configuration.contactsUsersLegacy);
-  cy.wait('@getTimeZone');
-});
-
-interface Contact {
-  alias: string;
-  name: string;
-  email: string;
-  pager: string;
-  template: string;
-  isNotificationsEnabled: string;
-}
-
-interface ContactGroup {
-  name: string;
-  alias: string;
-  linkedContact: string;
-  status: string;
-  comment: string;
-}
-
-interface ContactTemplate {
-  alias: string;
-  name: string;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  usedCTemplate: string;
-  defaultPage: string;
-  isNotEnabled: string;
-  timePeriod: string;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  NotCommands: string;
-}
-
 declare global {
   // biome-ignore lint/style/noNamespace: <explanation>
   namespace Cypress {
@@ -145,7 +139,8 @@ declare global {
         jsonName: string,
         login: string
       ) => Cypress.Chainable;
-      visitContactsPage: () => Cypress.Chainable;
     }
   }
 }
+
+export {};
