@@ -1,16 +1,14 @@
-/* eslint-disable @typescript-eslint/no-unused-expressions */
-import { Given, When, Then } from '@badeball/cypress-cucumber-preprocessor';
+import { Given, Then, When } from '@badeball/cypress-cucumber-preprocessor';
 
 import {
   checkHostsAreMonitored,
   checkServicesAreMonitored
 } from '../../../commons';
-import dashboardAdministratorUser from '../../../fixtures/users/user-dashboard-administrator.json';
 import dashboards from '../../../fixtures/dashboards/creation/dashboards.json';
 import genericTextWidgets from '../../../fixtures/dashboards/creation/widgets/genericText.json';
 import statusGridWidget from '../../../fixtures/dashboards/creation/widgets/status-grid-widget.json';
-import twoStatusGridWidgets from '../../../fixtures/dashboards/creation/widgets/dashboardWithTwostatusGrid.json';
 import statusGridWidgetWithNewAddedHost from '../../../fixtures/dashboards/creation/widgets/statusGridWidgetWithNewAddedHost.json';
+import dashboardAdministratorUser from '../../../fixtures/users/user-dashboard-administrator.json';
 
 const services = {
   serviceCritical: {
@@ -161,11 +159,11 @@ beforeEach(() => {
   }).as('listAllDashboards');
   cy.intercept({
     method: 'POST',
-    url: `/centreon/api/latest/configuration/dashboards/*/access_rights/contacts`
+    url: '/centreon/api/latest/configuration/dashboards/*/access_rights/contacts'
   }).as('addContactToDashboardShareList');
   cy.intercept({
     method: 'PATCH',
-    url: `/centreon/api/latest/configuration/dashboards/*`
+    url: '/centreon/api/latest/configuration/dashboards/*'
   }).as('updateDashboard');
   cy.intercept({
     method: 'GET',
@@ -193,7 +191,13 @@ after(() => {
 });
 
 Given('a dashboard that includes a configured Status Grid widget', () => {
-  cy.insertDashboardWithWidget(dashboards.default, statusGridWidget);
+  cy.insertDashboardWithWidget(
+    dashboards.default,
+    statusGridWidget,
+    'centreon-widget-statusgrid',
+    '/widgets/statusgrid'
+  );
+
   cy.editDashboard(dashboards.default.name);
   cy.wait('@resourceRequest');
   cy.editWidget(1);
@@ -217,7 +221,12 @@ Then(
 );
 
 Given('a dashboard configuring Status Grid widget', () => {
-  cy.insertDashboardWithWidget(dashboards.default, statusGridWidget);
+  cy.insertDashboardWithWidget(
+    dashboards.default,
+    statusGridWidget,
+    'centreon-widget-statusgrid',
+    '/widgets/statusgrid'
+  );
   cy.editDashboard(dashboards.default.name);
   cy.wait('@resourceRequest');
   cy.editWidget(1);
@@ -251,17 +260,23 @@ Then(
 );
 
 Given('a dashboard featuring two Status Grid widgets', () => {
-  cy.insertDashboardWithWidget(dashboards.default, twoStatusGridWidgets);
+  cy.insertDashboardWithDoubleWidget(
+    dashboards.default,
+    statusGridWidget,
+    statusGridWidget,
+    'centreon-widget-statusgrid',
+    '/widgets/statusgrid'
+  );
+
   cy.editDashboard(dashboards.default.name);
   cy.wait('@resourceRequest');
   cy.getByTestId({ testId: 'More actions' }).eq(0).click();
 });
 
 When('the dashboard administrator user deletes one of the widgets', () => {
-  cy.getByTestId({ testId: 'DeleteIcon' }).click();
   cy.getByLabel({
-    label: 'Delete',
-    tag: 'button'
+    label: 'Delete widget',
+    tag: 'li'
   }).realClick();
 });
 
@@ -274,7 +289,6 @@ Then('only the contents of the other widget are displayed', () => {
     .click({ force: true });
   cy.get('[class*="resourceName"]').contains('Centreon-Server').should('exist');
   cy.get('[class*="resourceName"]').contains('host2').should('exist');
-  cy.get('[class*="resourceName"]').contains('host3').should('exist');
 });
 
 Given(
@@ -290,7 +304,7 @@ When(
   () => {
     cy.get('*[class^="react-grid-layout"]').children().should('have.length', 0);
     cy.getByTestId({ testId: 'edit_dashboard' }).click();
-    cy.getByTestId({ testId: 'AddIcon' }).should('have.length', 1).click();
+    cy.contains('div[class*="-addWidgetPanel"] h5', 'Add a widget').click();
   }
 );
 
@@ -346,7 +360,12 @@ Then("the Status Grid widget is added in the dashboard's layout", () => {
 });
 
 Given('a dashboard with a configured Status Grid widget', () => {
-  cy.insertDashboardWithWidget(dashboards.default, statusGridWidget);
+  cy.insertDashboardWithWidget(
+    dashboards.default,
+    statusGridWidget,
+    'centreon-widget-statusgrid',
+    '/widgets/statusgrid'
+  );
   cy.editDashboard(dashboards.default.name);
   cy.wait('@resourceRequest');
   cy.editWidget(1);
@@ -358,28 +377,27 @@ When(
     cy.getByLabel({
       label: 'tiles',
       tag: 'input'
-    }).clear();
+    })
+      .clear()
+      .type('2');
     cy.wait('@resourceRequest');
   }
 );
 
 Then('the Status Grid widget displays up to that number of tiles', () => {
-  cy.getByTestId({
-    testId: 'DvrIcon'
+  cy.getByLabel({
+    label: 'See more on the Resources Status page',
+    tag: 'a'
   }).should('be.visible');
-  cy.getByTestId({ tag: 'svg', testId: 'HostIcon' })
-    .eq(2)
-    .parent()
-    .parent()
-    .should(($a) => {
-      $a.attr('target', '_self');
-    })
-    .click({ force: true });
-  cy.get('[class*="resourceName"]').contains('Centreon-Server').should('exist');
 });
 
 Given('a dashboard having a configured Status Grid widget', () => {
-  cy.insertDashboardWithWidget(dashboards.default, statusGridWidget);
+  cy.insertDashboardWithWidget(
+    dashboards.default,
+    statusGridWidget,
+    'centreon-widget-statusgrid',
+    '/widgets/statusgrid'
+  );
   cy.editDashboard(dashboards.default.name);
   cy.wait('@resourceRequest');
 });
@@ -387,8 +405,8 @@ Given('a dashboard having a configured Status Grid widget', () => {
 When(
   'the dashboard administrator user duplicates the Status Grid widget',
   () => {
-    cy.getByTestId({ testId: 'MoreHorizIcon' }).click();
-    cy.getByTestId({ testId: 'ContentCopyIcon' }).click();
+    cy.getByTestId({ testId: 'More actions' }).click();
+    cy.getByTestId({ testId: 'Duplicate' }).click();
   }
 );
 
@@ -406,11 +424,15 @@ Then('the second widget has the same properties as the first widget', () => {
     .invoke('removeAttr', 'target')
     .click({ force: true });
   cy.get('[class*="resourceName"]').contains('host2').should('exist');
-  cy.get('[class*="resourceName"]').contains('host3').should('exist');
 });
 
 Given('a dashboard with a Status Grid widget', () => {
-  cy.insertDashboardWithWidget(dashboards.default, statusGridWidget);
+  cy.insertDashboardWithWidget(
+    dashboards.default,
+    statusGridWidget,
+    'centreon-widget-statusgrid',
+    '/widgets/statusgrid'
+  );
   cy.editDashboard(dashboards.default.name);
   cy.wait('@resourceRequest');
 });
@@ -450,7 +472,7 @@ Given('a new host is successfully added and configured', () => {
         .getByLabel({ label: 'Up status hosts', tag: 'a' })
         .invoke('text')
         .then((text) => {
-          if (text != '4') {
+          if (text !== '4') {
             cy.exportConfig();
           }
 
@@ -464,12 +486,128 @@ Given('a new host is successfully added and configured', () => {
 When('the dashboard administrator adds a status grid widget', () => {
   cy.insertDashboardWithWidget(
     dashboards.default,
-    statusGridWidgetWithNewAddedHost
+    statusGridWidgetWithNewAddedHost,
+    'centreon-widget-statusgrid',
+    '/widgets/statusgrid'
   );
+
   cy.editDashboard(dashboards.default.name);
   cy.wait('@resourceRequest');
 });
 
-Then('the newly added host should appear in the status grid widget', () => {
+Then('the newly added host is displayed in the status grid widget', () => {
   cy.getByTestId({ testId: 'link to service_test_ok' }).should('be.visible');
 });
+
+Then('searches for a specific resource type', () => {
+  cy.getByLabel({ label: 'Title' }).type(genericTextWidgets.default.title);
+  cy.getByLabel({ label: 'RichTextEditor' })
+    .eq(0)
+    .type(genericTextWidgets.default.description);
+  cy.getByTestId({ testId: 'Resource type' }).realClick();
+  cy.getByLabel({ label: 'Host' }).eq(1).click();
+  cy.getByTestId({ testId: 'Select resource' }).type('3');
+  cy.wait('@resourceRequest');
+});
+
+Then(
+  'only the resource that matches the search input is displayed in the results',
+  () => {
+    cy.waitUntil(
+      () =>
+        cy
+          .get('.MuiAutocomplete-listbox')
+          .invoke('text')
+          .then((listboxText) => {
+            return (
+              listboxText.includes('host3') &&
+              !listboxText.includes('Centreon-Server') &&
+              !listboxText.includes('host2')
+            );
+          }),
+      {
+        timeout: 10000,
+        interval: 500
+      }
+    );
+  }
+);
+
+When(
+  'the dashboard administrator selects a service by typing a single character',
+  () => {
+    cy.getByLabel({ label: 'Title' }).type(genericTextWidgets.default.title);
+    cy.getByLabel({ label: 'RichTextEditor' })
+      .eq(0)
+      .type(genericTextWidgets.default.description);
+    cy.getByTestId({ testId: 'Resource type' }).realClick();
+    cy.getByLabel({ label: 'Service' }).eq(1).click();
+    cy.getByLabel({ label: 'Select resource' }).type('Pin');
+    cy.getByLabel({ label: 'Select resource' }).click();
+  }
+);
+
+Then(
+  'only the services containing the typed character should be displayed in the list',
+  () => {
+    const clickAndCheckForServices = () => {
+      cy.getByTestId({ testId: 'Resource type' }).realClick();
+
+      return cy
+        .getByLabel({ label: 'Service' })
+        .eq(1)
+        .click()
+        .then(() => {
+          return cy.getByLabel({ label: 'Select resource' }).type('ser');
+        })
+        .then(() => {
+          cy.intercept(
+            'GET',
+            '**/centreon/api/latest/monitoring/services/names**'
+          ).as('getServices');
+          cy.wait('@getServices');
+          return cy.getByLabel({ label: 'Select resource' }).click();
+        });
+    };
+
+    cy.waitUntil(
+      () => {
+        return clickAndCheckForServices().then(() => {
+          return cy
+            .get('ul.MuiAutocomplete-listbox')
+            .find('li')
+            .then(($items) => {
+              const textArray = $items
+                .map((_index, el) => {
+                  return Cypress.$(el).find('p').text();
+                })
+                .get();
+
+              cy.log(textArray.join(', '));
+
+              // Check if all displayed services contain "ser"
+              const allServicesContainSer = textArray.every((service) =>
+                service.includes('ser')
+              );
+
+              // Ensure that there are no extra services that do not contain "ser"
+              const noExtraServices =
+                textArray.length ===
+                textArray.filter((service) => service.includes('ser')).length;
+
+              return Cypress.Promise.resolve(
+                allServicesContainSer && noExtraServices
+              );
+            });
+        });
+      },
+      { timeout: 30000, interval: 3000 }
+    ).then((found) => {
+      if (found) {
+        cy.log('Only services containing "ser" are displayed in the list.');
+      } else {
+        cy.log('The displayed services do not match the expected criteria.');
+      }
+    });
+  }
+);
