@@ -1,6 +1,5 @@
 import { Given, Then, When } from '@badeball/cypress-cucumber-preprocessor';
 
-import { PAGES } from 'e2e/fixtures/shared/constants/pages';
 import data from '../../../fixtures/hosts-dependency/host-dependency.json';
 
 const services = {
@@ -75,10 +74,33 @@ Given('some hosts and services are configured', () => {
 });
 
 Given('a host dependency is configured', () => {
-  cy.visit(PAGES.configuration.hostsDependenciesLegacy);
+  cy.navigateTo({
+    page: 'Hosts',
+    rootItemNumber: 3,
+    subMenu: 'Notifications'
+  });
   cy.getIframeBody().contains('a', 'Add').click();
   cy.wait('@getTimeZone');
-  cy.addHostDependency(data.default);
+  cy.addHostDependency({
+    name: data.default.name,
+    description: data.default.description,
+    parentRelationship: data.default.parent_relationship,
+    executionFailsOnOk: data.default.execution_fails_on_ok,
+    executionFailsOnDown: data.default.execution_fails_on_down,
+    executionFailsOnUnreachable: data.default.execution_fails_on_unreachable,
+    executionFailsOnPending: data.default.execution_fails_on_pending,
+    executionFailsOnNone: data.default.notification_fails_on_none,
+    notificationFailsOnNone: data.default.notification_fails_on_none,
+    notificationFailsOnOk: data.default.notification_fails_on_ok,
+    notificationFailsOnDown: data.default.notification_fails_on_down,
+    notificationFailsOnUnreachable:
+      data.default.notification_fails_on_unreachable,
+    notificationFailsOnPending: data.default.notification_fails_on_pending,
+    hostNames: data.default.hostNames,
+    dependentHostNames: data.default.dependentHostNames,
+    dependentServices: data.default.dependentServices,
+    comment: data.default.comment
+  });
 });
 
 When('the user changes the properties of a host dependency', () => {
@@ -89,7 +111,28 @@ When('the user changes the properties of a host dependency', () => {
   cy.getIframeBody().contains(data.default.name).click();
   cy.wait('@getTopCounter');
   cy.wait('@getTimeZone');
-  cy.updateHostDependency(data.HostDependency1);
+  cy.updateHostDependency({
+    name: data.HostDependency1.name,
+    description: data.HostDependency1.description,
+    parentRelationship: data.HostDependency1.parent_relationship,
+    executionFailsOnOk: data.HostDependency1.execution_fails_on_ok,
+    executionFailsOnDown: data.HostDependency1.execution_fails_on_down,
+    executionFailsOnUnreachable:
+      data.HostDependency1.execution_fails_on_unreachable,
+    executionFailsOnPending: data.HostDependency1.execution_fails_on_pending,
+    executionFailsOnNone: data.HostDependency1.execution_fails_on_none,
+    notificationFailsOnNone: data.HostDependency1.notification_fails_on_none,
+    notificationFailsOnOk: data.HostDependency1.notification_fails_on_ok,
+    notificationFailsOnDown: data.HostDependency1.notification_fails_on_down,
+    notificationFailsOnUnreachable:
+      data.HostDependency1.notification_fails_on_unreachable,
+    notificationFailsOnPending:
+      data.HostDependency1.notification_fails_on_pending,
+    hostNames: data.HostDependency1.hostNames,
+    dependentHostNames: data.HostDependency1.dependentHostNames,
+    dependentServices: data.HostDependency1.dependentServices,
+    comment: data.HostDependency1.comment
+  });
 });
 
 Then('the properties are updated', () => {
@@ -116,7 +159,7 @@ Then('the properties are updated', () => {
     .should('have.length', 2)
     .then((options) => {
       const selectedTexts = Array.from(options).map((option) =>
-        (option.textContent ?? '').trim()
+        (option.textContent || '').trim()
       );
       expect(selectedTexts).to.include.members([
         data.HostDependency1.hostNames[0],
