@@ -4,21 +4,21 @@ Cypress.Commands.add('addEscalation', (body: Escalation) => {
   cy.getIframeBody().find('input[name="esc_alias"]').type(body.alias);
   cy.getIframeBody()
     .find('input[name="first_notification"]')
-    .type(body.first_notification);
+    .type(body.firstNotification);
   cy.getIframeBody()
     .find('input[name="last_notification"]')
-    .type(body.last_notification);
+    .type(body.lastNotification);
   cy.getIframeBody()
     .find('input[name="notification_interval"]')
-    .type(body.notification_interval);
+    .type(body.notificationInterval);
   cy.getIframeBody()
     .find('span[id="select2-escalation_period-container"]')
     .click();
   cy.waitForElementInIframe(
     '#main-content',
-    `div[title=${body.escalation_period}]`
+    `div[title=${body.escalationPeriod}]`
   );
-  cy.getIframeBody().find(`div[title=${body.escalation_period}]`).click();
+  cy.getIframeBody().find(`div[title=${body.escalationPeriod}]`).click();
   cy.getIframeBody()
     .find('input[name="escalation_options1[d]"]')
     .click({ force: true });
@@ -26,7 +26,7 @@ Cypress.Commands.add('addEscalation', (body: Escalation) => {
     .find('input[name="escalation_options2[u]"]')
     .click({ force: true });
   cy.getIframeBody().find('input[class="select2-search__field"]').eq(0).click();
-  cy.getIframeBody().find(`div[title="${body.contactgroups}"]`).click();
+  cy.getIframeBody().find(`div[title="${body.contactGroups}"]`).click();
   cy.getIframeBody().find('textarea[name="esc_comment"]').type(body.comment);
 
   cy.getIframeBody().contains('a', 'Impacted Resources').click();
@@ -48,17 +48,17 @@ Cypress.Commands.add('addEscalation', (body: Escalation) => {
     .find('input[class="select2-search__field"]')
     .eq(3)
     .click({ force: true });
-  cy.getIframeBody().find(`div[title="${body.hostgroups}"]`).click();
+  cy.getIframeBody().find(`div[title="${body.hostGroups}"]`).click();
   cy.getIframeBody()
     .find('input[class="select2-search__field"]')
     .eq(4)
     .click({ force: true });
-  cy.getIframeBody().find(`div[title="${body.servicegroups}"]`).click();
+  cy.getIframeBody().find(`div[title="${body.serviceGroups}"]`).click();
   cy.getIframeBody()
     .find('input[class="select2-search__field"]')
     .eq(5)
     .click({ force: true });
-  cy.getIframeBody().find(`div[title="${body.metaservices}"]`).click();
+  cy.getIframeBody().find(`div[title="${body.metaServices}"]`).click();
 });
 
 Cypress.Commands.add('updateEscalation', (body: Escalation) => {
@@ -68,24 +68,24 @@ Cypress.Commands.add('updateEscalation', (body: Escalation) => {
   cy.getIframeBody()
     .find('input[name="first_notification"]')
     .clear()
-    .type(body.first_notification);
+    .type(body.firstNotification);
   cy.getIframeBody()
     .find('input[name="last_notification"]')
     .clear()
-    .type(body.last_notification);
+    .type(body.lastNotification);
   cy.getIframeBody()
     .find('input[name="notification_interval"]')
     .clear()
-    .type(body.notification_interval);
+    .type(body.notificationInterval);
   cy.getIframeBody().find('span[title="Clear field"]').eq(0).click();
   cy.getIframeBody()
     .find('span[id="select2-escalation_period-container"]')
     .click();
   cy.waitForElementInIframe(
     '#main-content',
-    `div[title=${body.escalation_period}]`
+    `div[title=${body.escalationPeriod}]`
   );
-  cy.getIframeBody().find(`div[title=${body.escalation_period}`).click();
+  cy.getIframeBody().find(`div[title=${body.escalationPeriod}]`).click();
   cy.getIframeBody()
     .find('input[name="escalation_options1[d]"]')
     .click({ force: true });
@@ -100,7 +100,7 @@ Cypress.Commands.add('updateEscalation', (body: Escalation) => {
     .click({ force: true });
   cy.getIframeBody().find('span[title="Clear field"]').eq(1).click();
   cy.getIframeBody().find('input[class="select2-search__field"]').eq(0).click();
-  cy.getIframeBody().find(`div[title="${body.contactgroups}"]`).click();
+  cy.getIframeBody().find(`div[title="${body.contactGroups}"]`).click();
   cy.getIframeBody()
     .find('textarea[name="esc_comment"]')
     .clear()
@@ -131,19 +131,19 @@ Cypress.Commands.add('updateEscalation', (body: Escalation) => {
     .find('input[class="select2-search__field"]')
     .eq(3)
     .click({ force: true });
-  cy.getIframeBody().find(`div[title="${body.hostgroups}"]`).click();
+  cy.getIframeBody().find(`div[title="${body.hostGroups}"]`).click();
   cy.getIframeBody().find('span[title="Clear field"]').eq(5).click();
   cy.getIframeBody()
     .find('input[class="select2-search__field"]')
     .eq(4)
     .click({ force: true });
-  cy.getIframeBody().find(`div[title="${body.servicegroups}"]`).click();
+  cy.getIframeBody().find(`div[title="${body.serviceGroups}"]`).click();
   cy.getIframeBody().find('span[title="Clear field"]').eq(6).click();
   cy.getIframeBody()
     .find('input[class="select2-search__field"]')
     .eq(5)
     .click({ force: true });
-  cy.getIframeBody().find(`div[title="${body.metaservices}"]`).click();
+  cy.getIframeBody().find(`div[title="${body.metaServices}"]`).click();
   cy.getIframeBody().find('input.btc.bt_success[name^="submit"]').eq(0).click();
   cy.wait('@getTimeZone');
   cy.exportConfig();
@@ -163,13 +163,13 @@ Cypress.Commands.add(
       .should('have.value', body.alias);
     cy.getIframeBody()
       .find('input[name="first_notification"]')
-      .should('have.value', body.first_notification);
+      .should('have.value', body.firstNotification);
     cy.getIframeBody()
       .find('input[name="last_notification"]')
-      .should('have.value', body.last_notification);
+      .should('have.value', body.lastNotification);
     cy.getIframeBody()
       .find('input[name="notification_interval"]')
-      .should('have.value', body.notification_interval);
+      .should('have.value', body.notificationInterval);
     cy.getIframeBody()
       .find('input[name="escalation_options1[r]"]')
       .should('be.checked');
@@ -180,12 +180,12 @@ Cypress.Commands.add(
       .find('#escalation_period')
       .find('option:selected')
       .should('have.length', 1)
-      .and('have.text', body.escalation_period);
+      .and('have.text', body.escalationPeriod);
     cy.getIframeBody()
       .find('#esc_cgs')
       .find('option:selected')
       .should('have.length', 1)
-      .and('have.text', body.contactgroups);
+      .and('have.text', body.contactGroups);
     cy.getIframeBody()
       .find('textarea[name="esc_comment"]')
       .should('have.value', body.comment);
@@ -212,42 +212,36 @@ Cypress.Commands.add(
       .find('#esc_hgs')
       .find('option:selected')
       .should('have.length', 1)
-      .and('have.text', body.hostgroups);
+      .and('have.text', body.hostGroups);
     cy.getIframeBody()
       .find('#esc_sgs')
       .find('option:selected')
       .should('have.length', 1)
-      .and('have.text', body.servicegroups);
+      .and('have.text', body.serviceGroups);
     cy.getIframeBody()
       .find('#esc_metas')
       .find('option:selected')
       .should('have.length', 1)
-      .and('have.text', body.metaservices);
+      .and('have.text', body.metaServices);
   }
 );
 
 interface Escalation {
   name: string;
   alias: string;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  first_notification: string;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  last_notification: string;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  notification_interval: string;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  escalation_period: string;
-  contactgroups: string;
+  firstNotification: string;
+  lastNotification: string;
+  notificationInterval: string;
+  escalationPeriod: string;
+  contactGroups: string;
   comment: string;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  host_inheritance_to_services: number;
   hosts: string;
+  hostInheritanceToServices: number;
+  hostGroups: string;
+  hostGroupInheritanceToServices: number;
   services: string;
-  // biome-ignore lint/style/useNamingConvention: <explanation>
-  hostgroup_inheritance_to_services: number;
-  hostgroups: string;
-  servicegroups: string;
-  metaservices: string;
+  serviceGroups: string;
+  metaServices: string;
 }
 
 declare global {
