@@ -7,6 +7,13 @@ import {
 } from '../common';
 
 beforeEach(() => {
+  // clear network cache to avoid chunk loading issues
+  cy.wrap(
+    Cypress.automation('remote:debugger:protocol', {
+      command: 'Network.clearBrowserCache'
+    })
+  );
+
   cy.getWebVersion().then(({ major_version }) => {
     cy.intercept({
       method: 'GET',
@@ -91,7 +98,7 @@ beforeEach(() => {
 
 Given(
   'a running platform in {string} version',
-  (version_from_expression: string) => {
+  (versionFromExpression: string) => {
     return cy.getWebVersion().then(({ major_version, minor_version }) => {
       if (minor_version === '0') {
         cy.log(
@@ -102,52 +109,52 @@ Given(
       }
 
       return getCentreonStableMinorVersions(major_version).then(
-        (stable_minor_versions) => {
-          if (stable_minor_versions.length === 0) {
-            cy.log(`centreon web is currently not available as stable`);
+        (stableMinorVersions) => {
+          if (stableMinorVersions.length === 0) {
+            cy.log('centreon web is currently not available as stable');
 
             return cy.stopContainer({ name: 'web' }).wrap('skipped');
           }
-          let minor_version_index = 0;
-          if (version_from_expression === 'first minor') {
-            minor_version_index = 0;
+          let minorVersionIndex = 0;
+          if (versionFromExpression === 'first minor') {
+            minorVersionIndex = 0;
           } else {
-            switch (version_from_expression) {
+            switch (versionFromExpression) {
               case 'last stable':
-                minor_version_index = stable_minor_versions.length - 1;
+                minorVersionIndex = stableMinorVersions.length - 1;
                 if (
-                  stable_minor_versions[minor_version_index] ===
+                  stableMinorVersions[minorVersionIndex] ===
                   Cypress.env('lastStableMinorVersion')
                 ) {
                   return cy.stopContainer({ name: 'web' }).wrap('skipped');
                 }
                 break;
               case 'penultimate stable':
-                minor_version_index = stable_minor_versions.length - 2;
+                minorVersionIndex = stableMinorVersions.length - 2;
                 break;
               case 'antepenultimate stable':
-                minor_version_index = stable_minor_versions.length - 3;
+                minorVersionIndex = stableMinorVersions.length - 3;
                 break;
               default:
-                throw new Error(`${version_from_expression} not managed.`);
+                throw new Error(`${versionFromExpression} not managed.`);
             }
-            if (minor_version_index <= 0) {
-              cy.log(`Not needed to test ${version_from_expression} version.`);
+            if (minorVersionIndex <= 0) {
+              cy.log(`Not needed to test ${versionFromExpression} version.`);
 
               return cy.stopContainer({ name: 'web' }).wrap('skipped');
             }
           }
 
           cy.log(
-            `${version_from_expression} version is ${stable_minor_versions[minor_version_index]}`
+            `${versionFromExpression} version is ${stableMinorVersions[minorVersionIndex]}`
           );
 
-          const installed_version = `${major_version}.${stable_minor_versions[minor_version_index]}`;
-          Cypress.env('installed_version', installed_version);
-          cy.log('installed_version', installed_version);
+          const installedVersion = `${major_version}.${stableMinorVersions[minorVersionIndex]}`;
+          Cypress.env('installed_version', installedVersion);
+          cy.log('installed_version', installedVersion);
 
-          return installCentreon(installed_version).then(() => {
-            return checkPlatformVersion(installed_version).then(() =>
+          return installCentreon(installedVersion).then(() => {
+            return checkPlatformVersion(installedVersion).then(() =>
               cy.visit('/')
             );
           });
@@ -158,5 +165,7 @@ Given(
 );
 
 afterEach(() => {
-  cy.visitEmptyPage().stopContainer({ name: 'web' });
+  cy.visitEmptyPage()
+    .copyWebContainerLogs({ name: 'web' })
+    .stopContainer({ name: 'web' });
 });
