@@ -1,6 +1,5 @@
 import { Given, Then, When } from '@badeball/cypress-cucumber-preprocessor';
 
-import { PAGES } from 'e2e/fixtures/shared/constants/pages';
 import data from '../../../fixtures/services/meta_service.json';
 
 beforeEach(() => {
@@ -31,19 +30,62 @@ Given('an admin user is logged in a Centreon server', () => {
 });
 
 Given('some meta services are configured', () => {
-  cy.visit(PAGES.configuration.metaServicesLegacy);
+  cy.navigateTo({
+    page: 'Meta Services',
+    rootItemNumber: 3,
+    subMenu: 'Services'
+  });
   cy.wait('@getTimeZone');
-  cy.addMetaService(data.metaService1);
-  cy.addMetaService(data.metaService2);
-  cy.addMetaService(data.metaService3);
+  cy.addMetaService({
+    ...data.metaService1,
+    maxCheckAttempts: data.metaService1.max_check_attempts
+  });
+  cy.addMetaService({
+    ...data.metaService2,
+    maxCheckAttempts: data.metaService2.max_check_attempts
+  });
+  cy.addMetaService({
+    ...data.metaService3,
+    maxCheckAttempts: data.metaService3.max_check_attempts
+  });
 });
 
 Given('a meta service dependency is configured', () => {
   cy.visit('/').url().should('include', '/monitoring/resources');
-  cy.visit(PAGES.configuration.metaServicesDependenciesLegacy);
+  cy.navigateTo({
+    page: 'Meta Services',
+    rootItemNumber: 3,
+    subMenu: 'Notifications'
+  });
   cy.getIframeBody().contains('a', 'Add').click();
   cy.wait('@getTimeZone');
-  cy.addMsDependency(data.defaultMetaServiceDep);
+  cy.addMetaserviceDependency({
+    ...data.defaultMetaServiceDep,
+    parentRelationship: data.defaultMetaServiceDep.parent_relationship,
+    executionFailsOnOk: data.defaultMetaServiceDep.execution_fails_on_ok,
+    executionFailsOnWarning:
+      data.defaultMetaServiceDep.execution_fails_on_warning,
+    executionFailsOnUnknown:
+      data.defaultMetaServiceDep.execution_fails_on_unknown,
+    executionFailsOnCritical:
+      data.defaultMetaServiceDep.execution_fails_on_critical,
+    executionFailsOnPending:
+      data.defaultMetaServiceDep.execution_fails_on_pending,
+    executionFailsOnNone: data.defaultMetaServiceDep.execution_fails_on_none,
+    notificationFailsOnNone:
+      data.defaultMetaServiceDep.notification_fails_on_none,
+    notificationFailsOnOk: data.defaultMetaServiceDep.notification_fails_on_ok,
+    notificationFailsOnWarning:
+      data.defaultMetaServiceDep.notification_fails_on_warning,
+    notificationFailsOnUnknown:
+      data.defaultMetaServiceDep.notification_fails_on_unknown,
+    notificationFailsOnCritical:
+      data.defaultMetaServiceDep.notification_fails_on_critical,
+    notificationFailsOnPending:
+      data.defaultMetaServiceDep.notification_fails_on_pending,
+    metaServicesNames: data.defaultMetaServiceDep.metaServicesNames,
+    dependentMetaServicesNames: data.defaultMetaServiceDep.dependentMSNames
+  });
 });
 
 When(
@@ -54,7 +96,29 @@ When(
       `a:contains("${data.defaultMetaServiceDep.name}")`
     );
     cy.getIframeBody().contains(data.defaultMetaServiceDep.name).click();
-    cy.updateMsDependency(data.MetaServiceDep1);
+    cy.updateMetaserviceDependency({
+      ...data.MetaServiceDep1,
+      parentRelationship: data.MetaServiceDep1.parent_relationship,
+      executionFailsOnOk: data.MetaServiceDep1.execution_fails_on_ok,
+      executionFailsOnWarning: data.MetaServiceDep1.execution_fails_on_warning,
+      executionFailsOnUnknown: data.MetaServiceDep1.execution_fails_on_unknown,
+      executionFailsOnCritical:
+        data.MetaServiceDep1.execution_fails_on_critical,
+      executionFailsOnPending: data.MetaServiceDep1.execution_fails_on_pending,
+      executionFailsOnNone: data.MetaServiceDep1.execution_fails_on_none,
+      notificationFailsOnNone: data.MetaServiceDep1.notification_fails_on_none,
+      notificationFailsOnOk: data.MetaServiceDep1.notification_fails_on_ok,
+      notificationFailsOnWarning:
+        data.MetaServiceDep1.notification_fails_on_warning,
+      notificationFailsOnUnknown:
+        data.MetaServiceDep1.notification_fails_on_unknown,
+      notificationFailsOnCritical:
+        data.MetaServiceDep1.notification_fails_on_critical,
+      notificationFailsOnPending:
+        data.MetaServiceDep1.notification_fails_on_pending,
+      metaServicesNames: data.MetaServiceDep1.metaServicesNames,
+      dependentMetaServicesNames: data.MetaServiceDep1.dependentMSNames
+    });
   }
 );
 
@@ -118,7 +182,7 @@ Then(
       .should('have.length', 2)
       .then((options) => {
         const selectedTexts = Array.from(options).map((option) =>
-          (option.textContent ?? '').trim()
+          (option.textContent || '').trim()
         );
         expect(selectedTexts).to.include.members([
           data.metaService1.name,
