@@ -47,7 +47,7 @@ $dbPassword = getEnvironmentVariable('MYSQL_PASSWORD');
 
 $dbConfigCentreon = null;
 
-if (! is_null($dbHost) && ! is_null($dbUser) && ! is_null($dbPassword)) {
+if ($dbHost !== null && $dbUser !== null && $dbPassword !== null) {
     $dbConfigCentreon = new ConnectionConfig(
         host: $dbHost,
         user: $dbUser,
@@ -76,14 +76,15 @@ function hasConnectionDb(ConnectionConfig $connectionConfig): bool
 
 // ************************************** With centreon database connection *******************************************
 
-if (! is_null($dbConfigCentreon) && hasConnectionDb($dbConfigCentreon)) {
+if ($dbConfigCentreon instanceof ConnectionConfig && hasConnectionDb($dbConfigCentreon)) {
     it(
         'DbalConnectionAdapter::createFromConfig factory with a good connection',
         function () use ($dbConfigCentreon): void {
             $db = DbalConnectionAdapter::createFromConfig(connectionConfig: $dbConfigCentreon);
+            /** @var \PDO $pdo */
             $pdo = $db->getNativeConnection();
             expect($db)->toBeInstanceOf(DbalConnectionAdapter::class);
-            $stmt = $db->getNativeConnection()->prepare('select database()');
+            $stmt = $pdo->prepare('select database()');
             $stmt->execute();
 
             $dbName = $stmt->fetchColumn();
@@ -154,12 +155,14 @@ if (! is_null($dbConfigCentreon) && hasConnectionDb($dbConfigCentreon)) {
 
     it('get native connection', function () use ($dbConfigCentreon): void {
         $db = DbalConnectionAdapter::createFromConfig(connectionConfig: $dbConfigCentreon);
+        /** @var \PDO $pdo */
         $pdo = $db->getNativeConnection();
         expect($pdo)->toBeInstanceOf(\PDO::class);
     });
 
     it('get last insert id', function () use ($dbConfigCentreon): void {
         $db = DbalConnectionAdapter::createFromConfig(connectionConfig: $dbConfigCentreon);
+        /** @var \PDO $pdo */
         $pdo = $db->getNativeConnection();
         $insert = $pdo->exec(
             "INSERT INTO contact(contact_id, contact_name, contact_alias) VALUES(110, 'foo_name', 'foo_alias')"
@@ -179,6 +182,7 @@ if (! is_null($dbConfigCentreon) && hasConnectionDb($dbConfigCentreon)) {
 
     it('quote string', function () use ($dbConfigCentreon): void {
         $db = DbalConnectionAdapter::createFromConfig(connectionConfig: $dbConfigCentreon);
+        /** @var \PDO $pdo */
         $pdo = $db->getNativeConnection();
         $quotedString = $pdo->quote('foo');
         expect($quotedString)->toBeString()->toBe("'foo'");
@@ -192,6 +196,7 @@ if (! is_null($dbConfigCentreon) && hasConnectionDb($dbConfigCentreon)) {
         'execute statement with a correct query without query parameters',
         function () use ($dbConfigCentreon): void {
             $db = DbalConnectionAdapter::createFromConfig(connectionConfig: $dbConfigCentreon);
+            /** @var \PDO $pdo */
             $pdo = $db->getNativeConnection();
             $inserted = $db->executeStatement(
                 "INSERT INTO contact(contact_id, contact_name, contact_alias) VALUES(110, 'foo_name', 'foo_alias')"
@@ -207,6 +212,7 @@ if (! is_null($dbConfigCentreon) && hasConnectionDb($dbConfigCentreon)) {
         'execute statement with a correct query with query parameters',
         function () use ($dbConfigCentreon): void {
             $db = DbalConnectionAdapter::createFromConfig(connectionConfig: $dbConfigCentreon);
+            /** @var \PDO $pdo */
             $pdo = $db->getNativeConnection();
             $queryParameters = QueryParameters::create(
                 [
@@ -230,6 +236,7 @@ if (! is_null($dbConfigCentreon) && hasConnectionDb($dbConfigCentreon)) {
         'execute statement with a correct query with query parameters with ":" before keys',
         function () use ($dbConfigCentreon): void {
             $db = DbalConnectionAdapter::createFromConfig(connectionConfig: $dbConfigCentreon);
+            /** @var \PDO $pdo */
             $pdo = $db->getNativeConnection();
             $queryParameters = QueryParameters::create(
                 [
@@ -290,6 +297,7 @@ if (! is_null($dbConfigCentreon) && hasConnectionDb($dbConfigCentreon)) {
         'insert with a correct query with query parameters',
         function () use ($dbConfigCentreon): void {
             $db = DbalConnectionAdapter::createFromConfig(connectionConfig: $dbConfigCentreon);
+            /** @var \PDO $pdo */
             $pdo = $db->getNativeConnection();
             $queryParameters = QueryParameters::create(
                 [
@@ -350,6 +358,7 @@ if (! is_null($dbConfigCentreon) && hasConnectionDb($dbConfigCentreon)) {
         'batch insert with a correct query with batch query parameters',
         function () use ($dbConfigCentreon): void {
             $db = DbalConnectionAdapter::createFromConfig(connectionConfig: $dbConfigCentreon);
+            /** @var \PDO $pdo */
             $pdo = $db->getNativeConnection();
             $batchQueryParameters = BatchInsertParameters::create([
                 QueryParameters::create([
@@ -424,6 +433,7 @@ if (! is_null($dbConfigCentreon) && hasConnectionDb($dbConfigCentreon)) {
         'update with a correct query with query parameters',
         function () use ($dbConfigCentreon): void {
             $db = DbalConnectionAdapter::createFromConfig(connectionConfig: $dbConfigCentreon);
+            /** @var \PDO $pdo */
             $pdo = $db->getNativeConnection();
             $inserted = $db->executeStatement(
                 "INSERT INTO contact(contact_id, contact_name, contact_alias) VALUES(110, 'foo_name', 'foo_alias')"
@@ -1542,7 +1552,7 @@ if (! is_null($dbConfigCentreon) && hasConnectionDb($dbConfigCentreon)) {
             $db->startUnbufferedQuery();
             expect($db->isUnbufferedQueryActive())->toBeTrue()
                 ->and($pdo->getAttribute(\PDO::MYSQL_ATTR_USE_BUFFERED_QUERY))->toBe(0);
-            $pdoStmt = $db->getNativeConnection()->prepare('SELECT * FROM contact WHERE contact_id = 1');
+            $pdoStmt = $pdo->prepare('SELECT * FROM contact WHERE contact_id = 1');
             $pdoStmt->execute();
 
             $contact = $pdoStmt->fetch(\PDO::FETCH_ASSOC);
@@ -1563,47 +1573,6 @@ if (! is_null($dbConfigCentreon) && hasConnectionDb($dbConfigCentreon)) {
         }
     )->throws(ConnectionException::class);
 
-    // --------------------------------------- DDL TOOLS -----------------------------------------------
-
-    it('check if a column exists with success', function () use ($dbConfigCentreon): void {
-        $db = DbalConnectionAdapter::createFromConfig(connectionConfig: $dbConfigCentreon);
-        $exists = $db->columnExists(
-            dbName: $dbConfigCentreon->getDatabaseNameConfiguration(),
-            tableName: 'contact',
-            columnName: 'contact_id'
-        );
-        expect($exists)->toBeTrue();
-    });
-
-    it('check if a non-existent column with success', function () use ($dbConfigCentreon): void {
-        $db = DbalConnectionAdapter::createFromConfig(connectionConfig: $dbConfigCentreon);
-        $exists = $db->columnExists(
-            dbName: $dbConfigCentreon->getDatabaseNameConfiguration(),
-            tableName: 'contact',
-            columnName: 'dummy_column'
-        );
-        expect($exists)->toBeFalse();
-    });
-
-    it('check if a column exists with errors must to throw an exception', function () use ($dbConfigCentreon): void {
-        $db = DbalConnectionAdapter::createFromConfig(connectionConfig: $dbConfigCentreon);
-        expect(fn (): bool => $db->columnExists(
-            dbName: '',
-            tableName: 'contact',
-            columnName: 'contact_id'
-        ))->toThrow(ConnectionException::class)
-            ->and(fn (): bool => $db->columnExists(
-                dbName: $dbConfigCentreon->getDatabaseNameConfiguration(),
-                tableName: 'contact',
-                columnName: ''
-            ))->toThrow(ConnectionException::class)
-            ->and(fn (): bool => $db->columnExists(
-                dbName: $dbConfigCentreon->getDatabaseNameConfiguration(),
-                tableName: '',
-                columnName: 'contact_id'
-            ))->toThrow(ConnectionException::class);
-    });
-
     // ----------------------------------- QUERY ON SEVERAL DATABASES -------------------------------------
 
     it(
