@@ -1,13 +1,13 @@
 <?php
 
 /*
- * Copyright 2005 - 2022 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -73,7 +73,7 @@ final class HostTest extends ResourceTestCase
             $this->mockRequest(self::DEFAULT_REQUEST_CONTENT),
             $this->mockEntityValidator(),
             $this->mockSerializer([]),
-            1
+            1,
         ];
     }
 
@@ -94,8 +94,9 @@ final class HostTest extends ResourceTestCase
         $sut = new CheckController($service, $readAccessGroupRepository);
         $sut->setContainer($container);
 
-        $methodUnderTest = static::METHOD_UNDER_TEST;
-        return $sut->$methodUnderTest(
+        $methodUnderTest = self::METHOD_UNDER_TEST;
+
+        return $sut->{$methodUnderTest}(
             $this->mockRequest(self::DEFAULT_REQUEST_CONTENT),
             $validator,
             $this->mockSerializer($check),
