@@ -1,13 +1,13 @@
 <?php
 
 /*
- * Copyright 2005 - 2021 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -18,6 +18,7 @@
  * For more information : contact@centreon.com
  *
  */
+
 declare(strict_types=1);
 
 namespace Tests\Centreon\Domain\PlatformInformation\Model;
@@ -28,14 +29,10 @@ use PHPUnit\Framework\TestCase;
 
 class InformationFactoryTest extends TestCase
 {
-    /**
-     * @var array<Information>
-     */
+    /** @var array<Information> */
     private $information;
 
-    /**
-     * @var array<string,mixed>
-     */
+    /** @var array<string,mixed> */
     private $informationRequest;
 
     protected function setUp(): void
@@ -49,7 +46,7 @@ class InformationFactoryTest extends TestCase
             'apiScheme' => 'http',
             'apiPort' => 80,
             'apiPath' => 'centreon',
-            'peerValidation' => false
+            'peerValidation' => false,
         ];
     }
 
