@@ -99,7 +99,8 @@ it('should present a FindConfigurationResponse when everything is ok', function
                 name: 'acOne',
                 type: Type::TELEGRAF,
                 connectionMode: ConnectionModeEnum::SECURE,
-                configuration: $configuration)
+                configuration: $configuration
+            )
         );
 
     $this->readRepository
