@@ -1,13 +1,13 @@
 <?php
 
 /*
- * Copyright 2005 - 2022 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -18,29 +18,33 @@
  * For more information : contact@centreon.com
  *
  */
+
 declare(strict_types=1);
 
 namespace Tests\Core\Application\Configuration\NotificationPolicy\UseCase;
 
+use Centreon\Domain\Contact\Interfaces\ContactInterface;
+use Centreon\Domain\Engine\EngineConfiguration;
+use Centreon\Domain\Engine\Interfaces\EngineConfigurationServiceInterface;
+use Centreon\Domain\HostConfiguration\Host;
+use Centreon\Domain\HostConfiguration\Interfaces\HostConfigurationRepositoryInterface;
+use Centreon\Domain\Option\OptionService;
+use Core\Application\Common\UseCase\NotFoundResponse;
+use Core\Application\Configuration\Notification\Repository\ReadHostNotificationRepositoryInterface;
 use Core\Application\Configuration\NotificationPolicy\UseCase\FindHostNotificationPolicy;
 use Core\Application\Configuration\NotificationPolicy\UseCase\FindNotificationPolicyPresenterInterface;
 use Core\Application\Configuration\NotificationPolicy\UseCase\FindNotificationPolicyResponse;
-use Core\Security\AccessGroup\Application\Repository\ReadAccessGroupRepositoryInterface;
-use Centreon\Domain\Engine\Interfaces\EngineConfigurationServiceInterface;
-use Centreon\Domain\HostConfiguration\Interfaces\HostConfigurationRepositoryInterface;
-use Core\Application\Configuration\Notification\Repository\ReadHostNotificationRepositoryInterface;
-use Centreon\Domain\Contact\Interfaces\ContactInterface;
 use Core\Application\RealTime\Repository\ReadHostRepositoryInterface as ReadRealTimeHostRepositoryInterface;
-use Centreon\Domain\Engine\EngineConfiguration;
-use Centreon\Domain\HostConfiguration\Host;
-use Core\Domain\RealTime\Model\Host as RealTimeHost;
-use Core\Domain\RealTime\Model\HostStatus;
-use Core\Application\Common\UseCase\NotFoundResponse;
+use Core\Domain\Configuration\Notification\Model\HostNotification;
 use Core\Domain\Configuration\Notification\Model\NotifiedContact;
 use Core\Domain\Configuration\Notification\Model\NotifiedContactGroup;
-use Core\Domain\Configuration\Notification\Model\HostNotification;
 use Core\Domain\Configuration\Notification\Model\ServiceNotification;
 use Core\Domain\Configuration\TimePeriod\Model\TimePeriod;
+use Core\Domain\RealTime\Model\Host as RealTimeHost;
+use Core\Domain\RealTime\Model\HostStatus;
+use Core\Host\Application\Repository\ReadHostRepositoryInterface;
+use Core\HostTemplate\Application\Repository\ReadHostTemplateRepositoryInterface;
+use Core\Security\AccessGroup\Application\Repository\ReadAccessGroupRepositoryInterface;
 
 beforeEach(function (): void {
     $this->readHostNotificationRepository = $this->createMock(ReadHostNotificationRepositoryInterface::class);
@@ -49,6 +53,9 @@ beforeEach(function (): void {
     $this->accessGroupRepository = $this->createMock(ReadAccessGroupRepositoryInterface::class);
     $this->contact = $this->createMock(ContactInterface::class);
     $this->readRealTimeHostRepository = $this->createMock(ReadRealTimeHostRepositoryInterface::class);
+    $this->optionsService = $this->createMock(OptionService::class);
+    $this->readHostTemplateRepository = $this->createMock(ReadHostTemplateRepositoryInterface::class);
+    $this->readHostRepository = $this->createMock(ReadHostRepositoryInterface::class);
 
     $this->host = new Host();
     $this->realTimeHost = new RealTimeHost(
@@ -59,10 +66,10 @@ beforeEach(function (): void {
         new HostStatus(HostStatus::STATUS_NAME_DOWN, HostStatus::STATUS_CODE_DOWN, 1)
     );
 
-    $hostNotification = new HostNotification(new Timeperiod(1, '24x7', '24/24 7/7'));
+    $hostNotification = new HostNotification(new TimePeriod(1, '24x7', '24/24 7/7'));
     $hostNotification->addEvent(HostNotification::EVENT_HOST_DOWN);
 
-    $serviceNotification = new ServiceNotification(new Timeperiod(1, '24x7', '24/24 7/7'));
+    $serviceNotification = new ServiceNotification(new TimePeriod(1, '24x7', '24/24 7/7'));
     $serviceNotification->addEvent(ServiceNotification::EVENT_SERVICE_CRITICAL);
 
     $this->notifiedContact = new NotifiedContact(
@@ -85,6 +92,9 @@ beforeEach(function (): void {
         $this->accessGroupRepository,
         $this->contact,
         $this->readRealTimeHostRepository,
+        $this->optionsService,
+        $this->readHostTemplateRepository,
+        $this->readHostRepository
     );
 });
 
@@ -147,13 +157,13 @@ it('returns users, user groups and notification status', function (): void {
 
     $this->readHostNotificationRepository
         ->expects($this->once())
-        ->method('findNotifiedContactsById')
+        ->method('findNotifiedContactsByIds')
         ->with(1)
         ->willReturn([$this->notifiedContact]);
 
     $this->readHostNotificationRepository
         ->expects($this->once())
-        ->method('findNotifiedContactGroupsById')
+        ->method('findNotifiedContactGroupsByIds')
         ->with(1)
         ->willReturn([$this->notifiedContactGroup]);
 
