@@ -94,9 +94,12 @@ it('test format business logic exception without previous with context', functio
 
 it('test format business logic exception with previous', function (): void {
     $exception = new RepositoryException(
-        'repository_exception_message', previous: new \LogicException(
-            'logic_exception_message', 99
-        ));
+        'repository_exception_message',
+        previous: new \LogicException(
+            'logic_exception_message',
+            99
+        )
+    );
     $format = ExceptionFormatter::format($exception);
     expect($format)->toBeArray()
         ->and($format)->toHaveKey('type')
@@ -106,7 +109,7 @@ it('test format business logic exception with previous', function (): void {
         ->and($format)->toHaveKey('file')
         ->and($format['file'])->toBe(__FILE__)
         ->and($format)->toHaveKey('line')
-        ->and($format['line'])->toBe(__LINE__ - 13)
+        ->and($format['line'])->toBe(__LINE__ - 16)
         ->and($format)->toHaveKey('code')
         ->and($format['code'])->toBe(1)
         ->and($format)->toHaveKey('class')
@@ -122,7 +125,7 @@ it('test format business logic exception with previous', function (): void {
         ->and($format['previous'])->toHaveKey('file')
         ->and($format['previous']['file'])->toBe(__FILE__)
         ->and($format['previous'])->toHaveKey('line')
-        ->and($format['previous']['line'])->toBe(__LINE__ - 28)
+        ->and($format['previous']['line'])->toBe(__LINE__ - 30)
         ->and($format['previous'])->toHaveKey('code')
         ->and($format['previous']['code'])->toBe(99)
         ->and($format['previous'])->toHaveKey('class')
