@@ -1,7 +1,7 @@
 <?php
 
 /*
- * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -81,27 +81,6 @@ it('throws an exception when name is invalid', function (): void {
     HostException::nameIsInvalid()->getMessage()
 );
 
-it('throws an exception when name contains invalid characters', function (): void {
-    $this->readHostRepository
-        ->expects($this->never())
-        ->method('existsByName');
-
-    $this->validation->assertIsValidName('hôst~3!');
-})->throws(
-    \InvalidArgumentException::class,
-    '[Host::name] The value contains unauthorized characters: ~!'
-);
-
-it('does not throw when name contains only valid characters', function (): void {
-    $this->readHostRepository
-        ->expects($this->once())
-        ->method('existsByName')
-        ->willReturn(false);
-
-    // Example with valid characters
-    $this->validation->assertIsValidName('valid_name123');
-});
-
 it('throws an exception when monitoring server ID does not exist', function (): void {
     $this->readMonitoringServerRepository
         ->expects($this->once())
