@@ -79,24 +79,24 @@ it(
         $id = 1;
         $name = ' fake_name ';
         $alias = ' fake_alias ';
-        $tp = new TimePeriod($id, $name, $alias);
-        expect($tp->getId())->toBe($id);
-        expect($tp->getName())->toBe(trim($name));
-        expect($tp->getAlias())->toBe(trim($alias));
+        $timePeriod = new TimePeriod($id, $name, $alias);
+        expect($timePeriod->getId())->toBe($id);
+        expect($timePeriod->getName())->toBe(trim($name));
+        expect($timePeriod->getAlias())->toBe(trim($alias));
 
         $timeRange = new TimeRange('00:00-01:00');
 
         $extra = [new ExtraTimePeriod(1, 'monday 1', $timeRange)];
-        $tp->setExtraTimePeriods($extra);
-        expect($tp->getExtraTimePeriods())->toBe($extra);
+        $timePeriod->setExtraTimePeriods($extra);
+        expect($timePeriod->getExtraTimePeriods())->toBe($extra);
 
         $templates = [new Template(1, 'fake_template')];
-        $tp->setTemplates($templates);
-        expect($tp->getTemplates())->toBe($templates);
+        $timePeriod->setTemplates($templates);
+        expect($timePeriod->getTemplates())->toBe($templates);
 
         $days = [new Day(1, $timeRange)];
-        $tp->setDays($days);
-        expect($tp->getDays())->toBe($days);
+        $timePeriod->setDays($days);
+        expect($timePeriod->getDays())->toBe($days);
     }
 );
 
@@ -118,8 +118,8 @@ it(
 it(
     'should throw an exception if the given extra periods are not of the right type',
     function (): void {
-        $tp = new TimePeriod(1, 'fake_name', 'fake_alias');
-        $tp->setExtraTimePeriods([
+        $timePeriod = new TimePeriod(1, 'fake_name', 'fake_alias');
+        $timePeriod->setExtraTimePeriods([
             new \stdClass(),
         ]);
     }
@@ -130,8 +130,8 @@ it(
 it(
     'should throw an exception if the given templates are not of the right type',
     function (): void {
-        $tp = new TimePeriod(1, 'fake_name', 'fake_alias');
-        $tp->setTemplates([
+        $timePeriod = new TimePeriod(1, 'fake_name', 'fake_alias');
+        $timePeriod->setTemplates([
             new \stdClass(),
         ]);
     }
@@ -142,8 +142,8 @@ it(
 it(
     'should throw an exception if the given days are not of the right type',
     function (): void {
-        $tp = new TimePeriod(1, 'fake_name', 'fake_alias');
-        $tp->setDays([
+        $timePeriod = new TimePeriod(1, 'fake_name', 'fake_alias');
+        $timePeriod->setDays([
             new \stdClass(),
         ]);
     }
