@@ -1,13 +1,13 @@
 <?php
 
 /*
- * Copyright 2005 - 2022 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -37,7 +37,7 @@ it(
     \InvalidArgumentException::class,
     AssertionException::minLength(
         $timeRange,
-        strlen($timeRange),
+        mb_strlen($timeRange),
         11,
         'TimeRange::timeRange'
     )->getMessage()
@@ -114,11 +114,16 @@ it(
 );
 
 it('should return a valid single array', function (): void {
-        $timeRange = new TimeRange('00:00-10:00');
-        expect($timeRange->getRanges())->toBeArray()->toHaveCount(1);
+    $timeRange = new TimeRange('00:00-10:00');
+    expect($timeRange->getRanges())->toBeArray()->toHaveCount(1);
 });
 
 it('should return a valid multiple array', function (): void {
     $timeRange = new TimeRange('00:00-10:00,11:00-18:00');
     expect($timeRange->getRanges())->toBeArray()->toHaveCount(2);
 });
+
+it('should not throw an exception for 00:00-00:00', function (): void {
+    $timeRange = new TimeRange('00:00-00:00');
+    expect($timeRange->getRanges())->toBeArray()->toHaveCount(1);
+});
