@@ -1,43 +1,28 @@
 <?php
 
 /*
- * Copyright 2005-2020 Centreon
- * Centreon is developed by : Julien Mathis and Romain Le Merlus under
- * GPL Licence 2.0.
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
- * This program is free software; you can redistribute it and/or modify it under
- * the terms of the GNU General Public License as published by the Free Software
- * Foundation ; either version 2 of the License.
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
- * This program is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
- * PARTICULAR PURPOSE. See the GNU General Public License for more details.
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
- * You should have received a copy of the GNU General Public License along with
- * this program; if not, see <http://www.gnu.org/licenses>.
- *
- * Linking this program statically or dynamically with other modules is making a
- * combined work based on this program. Thus, the terms and conditions of the GNU
- * General Public License cover the whole combination.
- *
- * As a special exception, the copyright holders of this program give Centreon
- * permission to link this program with independent modules to produce an executable,
- * regardless of the license terms of these independent modules, and to copy and
- * distribute the resulting executable under terms of Centreon choice, provided that
- * Centreon also meet, for each linked independent module, the terms  and conditions
- * of the license of that module. An independent module is a module which is not
- * derived from this program. If you modify this program, you may extend this
- * exception to your version of the program, but you are not obliged to do so. If you
- * do not wish to do so, delete this exception statement from your version.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  *
  * For more information : contact@centreon.com
  *
  */
 
-require_once _CENTREON_PATH_ . "/www/class/centreonDB.class.php";
-require_once _CENTREON_PATH_ . "/www/class/centreonHost.class.php";
-require_once _CENTREON_PATH_ . "/www/class/centreonHook.class.php";
-require_once __DIR__ . "/centreon_configuration_objects.class.php";
+require_once _CENTREON_PATH_ . '/www/class/centreonDB.class.php';
+require_once _CENTREON_PATH_ . '/www/class/centreonHost.class.php';
+require_once _CENTREON_PATH_ . '/www/class/centreonHook.class.php';
+require_once __DIR__ . '/centreon_configuration_objects.class.php';
 
 /**
  * Class
@@ -61,9 +46,9 @@ class CentreonConfigurationHost extends CentreonConfigurationObjects
     }
 
     /**
-     * @return array
      * @throws PDOException
      * @throws RestBadRequestException
+     * @return array
      */
     public function getList()
     {
@@ -79,29 +64,29 @@ class CentreonConfigurationHost extends CentreonConfigurationObjects
         $query = '';
 
         // Check for select2 'q' argument
-        $queryValues["hostName"] = false === isset($this->arguments['q']) ? '%%' : '%' . (string)$this->arguments['q'] . '%';
-        $query .= 'SELECT SQL_CALC_FOUND_ROWS DISTINCT host_name, host_id, host_activate ' .
-            'FROM ( ' .
-            '( SELECT DISTINCT h.host_name, h.host_id, h.host_activate ' .
-            'FROM host h ';
+        $queryValues['hostName'] = false === isset($this->arguments['q']) ? '%%' : '%' . (string) $this->arguments['q'] . '%';
+        $query .= 'SELECT SQL_CALC_FOUND_ROWS DISTINCT host_name, host_id, host_activate '
+            . 'FROM ( '
+            . '( SELECT DISTINCT h.host_name, h.host_id, h.host_activate '
+            . 'FROM host h ';
 
         if (isset($this->arguments['hostgroup'])) {
             $additionalTables .= ',hostgroup_relation hg ';
             $additionalCondition .= 'AND hg.host_host_id = h.host_id AND hg.hostgroup_hg_id IN (';
             foreach (explode(',', $this->arguments['hostgroup']) as $hgId => $hgValue) {
-                if (!is_numeric($hgValue)) {
-                    throw new \RestBadRequestException('Error, host group id must be numerical');
+                if (! is_numeric($hgValue)) {
+                    throw new RestBadRequestException('Error, host group id must be numerical');
                 }
                 $explodedValues .= ':hostgroup' . $hgId . ',';
-                $queryValues['hostgroup'][$hgId] = (int)$hgValue;
+                $queryValues['hostgroup'][$hgId] = (int) $hgValue;
             }
             $explodedValues = rtrim($explodedValues, ',');
             $additionalCondition .= $explodedValues . ') ';
         }
         $query .= $additionalTables . 'WHERE h.host_register = "1" ';
 
-        /* Get ACL if user is not admin */
-        if (!$isAdmin) {
+        // Get ACL if user is not admin
+        if (! $isAdmin) {
             $acl = new CentreonACL($userId, $isAdmin);
             $aclHosts .= 'AND h.host_id IN (' . $acl->getHostsString('ID', $this->pearDBMonitoring) . ') ';
         }
@@ -110,35 +95,35 @@ class CentreonConfigurationHost extends CentreonConfigurationObjects
 
         // Check for virtual hosts
         $virtualHostCondition = '';
-        if (!isset($this->arguments['hostgroup']) && isset($this->arguments['h']) && $this->arguments['h'] == 'all') {
+        if (! isset($this->arguments['hostgroup']) && isset($this->arguments['h']) && $this->arguments['h'] == 'all') {
             $allVirtualHosts = CentreonHook::execute('Host', 'getVirtualHosts');
             foreach ($allVirtualHosts as $virtualHosts) {
                 foreach ($virtualHosts as $vHostId => $vHostName) {
-                    $virtualHostCondition .= 'UNION ALL ' .
-                        "(SELECT :hostNameTable$vHostId as host_name, "
-                        . ":virtualHostId$vHostId as host_id, "
+                    $virtualHostCondition .= 'UNION ALL '
+                        . "(SELECT :hostNameTable{$vHostId} as host_name, "
+                        . ":virtualHostId{$vHostId} as host_id, "
                         . "'1' AS host_activate ) ";
-                    $queryValues['virtualHost'][$vHostId] = (string)$vHostName;
+                    $queryValues['virtualHost'][$vHostId] = (string) $vHostName;
                 }
             }
         }
-        $query .= $virtualHostCondition .
-            ') t_union ' .
-            'WHERE host_name LIKE :hostName ' .
-            'ORDER BY host_name ';
+        $query .= $virtualHostCondition
+            . ') t_union '
+            . 'WHERE host_name LIKE :hostName '
+            . 'ORDER BY host_name ';
 
-        if (isset($this->arguments['page_limit']) && isset($this->arguments['page'])) {
+        if (isset($this->arguments['page_limit'], $this->arguments['page'])) {
             if (
-                !is_numeric($this->arguments['page'])
-                || !is_numeric($this->arguments['page_limit'])
+                ! is_numeric($this->arguments['page'])
+                || ! is_numeric($this->arguments['page_limit'])
                 || $this->arguments['page_limit'] < 1
             ) {
-                throw new \RestBadRequestException('Error, limit must be an integer greater than zero');
+                throw new RestBadRequestException('Error, limit must be an integer greater than zero');
             }
             $offset = ($this->arguments['page'] - 1) * $this->arguments['page_limit'];
             $query .= 'LIMIT :offset, :limit';
-            $queryValues['offset'] = (int)$offset;
-            $queryValues['limit'] = (int)$this->arguments['page_limit'];
+            $queryValues['offset'] = (int) $offset;
+            $queryValues['limit'] = (int) $this->arguments['page_limit'];
         }
 
         $stmt = $this->pearDB->prepare($query);
@@ -156,8 +141,8 @@ class CentreonConfigurationHost extends CentreonConfigurationObjects
             }
         }
         if (isset($queryValues['offset'])) {
-            $stmt->bindParam(':offset', $queryValues["offset"], PDO::PARAM_INT);
-            $stmt->bindParam(':limit', $queryValues["limit"], PDO::PARAM_INT);
+            $stmt->bindParam(':offset', $queryValues['offset'], PDO::PARAM_INT);
+            $stmt->bindParam(':limit', $queryValues['limit'], PDO::PARAM_INT);
         }
         $stmt->execute();
         $hostList = [];
@@ -169,15 +154,15 @@ class CentreonConfigurationHost extends CentreonConfigurationObjects
     }
 
     /**
-     * @return array
      * @throws PDOException
      * @throws RestBadRequestException
+     * @return array
      */
     public function getServices()
     {
         // Check for id
         if (false === isset($this->arguments['id'])) {
-            throw new RestBadRequestException("Missing host id");
+            throw new RestBadRequestException('Missing host id');
         }
         $id = $this->arguments['id'];
 
