@@ -1,36 +1,21 @@
 <?php
 
 /*
- * Copyright 2005-2022 CENTREON
- * Centreon is developed by : Julien Mathis and Romain Le Merlus under
- * GPL Licence 2.0.
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
- * This program is free software; you can redistribute it and/or modify it under
- * the terms of the GNU General Public License as published by the Free Software
- * Foundation ; either version 2 of the License.
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
- * This program is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
- * PARTICULAR PURPOSE. See the GNU General Public License for more details.
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
- * You should have received a copy of the GNU General Public License along with
- * this program; if not, see <http://www.gnu.org/licenses>.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  *
- * Linking this program statically or dynamically with other modules is making a
- * combined work based on this program. Thus, the terms and conditions of the GNU
- * General Public License cover the whole combination.
- *
- * As a special exception, the copyright holders of this program give CENTREON
- * permission to link this program with independent modules to produce an executable,
- * regardless of the license terms of these independent modules, and to copy and
- * distribute the resulting executable under terms of CENTREON choice, provided that
- * CENTREON also meet, for each linked independent module, the terms  and conditions
- * of the license of that module. An independent module is a module which is not
- * derived from this program. If you modify this program, you may extend this
- * exception to your version of the program, but you are not obliged to do so. If you
- * do not wish to do so, delete this exception statement from your version.
- *
- * For more information : command@centreon.com
+ * For more information : contact@centreon.com
  *
  */
 
@@ -70,8 +55,8 @@ class CentreonConfigurationChange
      *
      * @param int[] $hostgroupIds
      * @param bool $shouldHostgroupBeEnabled (default true)
-     * @return int[]
      * @throws Exception
+     * @return int[]
      */
     public function findHostsForConfigChangeFlagFromHostGroupIds(
         array $hostgroupIds,
@@ -91,10 +76,10 @@ class CentreonConfigurationChange
                 FROM hostgroup_relation hgr
                 JOIN hostgroup ON hostgroup.hg_id = hgr.hostgroup_hg_id
                 WHERE hostgroup.hg_activate = '1'
-                AND hgr.hostgroup_hg_id IN (" . implode(', ', array_keys($bindedParams)) . ")";
+                AND hgr.hostgroup_hg_id IN (" . implode(', ', array_keys($bindedParams)) . ')';
         } else {
-            $query = "SELECT DISTINCT(hgr.host_host_id) FROM hostgroup_relation hgr
-                WHERE hgr.hostgroup_hg_id IN (" . implode(', ', array_keys($bindedParams)) . ")";
+            $query = 'SELECT DISTINCT(hgr.host_host_id) FROM hostgroup_relation hgr
+                WHERE hgr.hostgroup_hg_id IN (' . implode(', ', array_keys($bindedParams)) . ')';
         }
 
         $stmt = $this->db->prepare($query);
@@ -112,8 +97,8 @@ class CentreonConfigurationChange
      * @param int[] $serviceIds
      * @param bool $shoudlServiceBeEnabled
      *
-     * @return int[]
      * @throws PDOException
+     * @return int[]
      */
     public function findHostsForConfigChangeFlagFromServiceIds(
         array $serviceIds,
@@ -133,11 +118,11 @@ class CentreonConfigurationChange
                 FROM host_service_relation hsr
                 JOIN service ON service.service_id = hsr.service_service_id
                 WHERE service.service_activate = '1' AND hsr.service_service_id IN ("
-                . implode(', ', array_keys($bindedParams)) . ")";
+                . implode(', ', array_keys($bindedParams)) . ')';
         } else {
-            $query = "SELECT DISTINCT(hsr.host_host_id)
+            $query = 'SELECT DISTINCT(hsr.host_host_id)
                 FROM host_service_relation hsr
-                WHERE hsr.service_service_id IN (" . implode(', ', array_keys($bindedParams)) . ")";
+                WHERE hsr.service_service_id IN (' . implode(', ', array_keys($bindedParams)) . ')';
         }
 
         $stmt = $this->db->prepare($query);
@@ -149,56 +134,13 @@ class CentreonConfigurationChange
         return $stmt->fetchAll(PDO::FETCH_COLUMN);
     }
 
-    /**
-     * Return ids of services linked to templates recursively
-     *
-     * @param int[] $serviceTemplateIds
-     * @return int[]
-     * @throws Exception
-     */
-    private function findServicesForConfigChangeFlagFromServiceTemplateIds(array $serviceTemplateIds): array
-    {
-        if ($serviceTemplateIds === []) {
-            return [];
-        }
-
-        $bindedParams = [];
-        foreach ($serviceTemplateIds as $key => $serviceTemplateId) {
-            $bindedParams[':servicetemplate_id_' . $key] = $serviceTemplateId;
-        }
-
-        $query = "SELECT service_id, service_register FROM service
-            WHERE service.service_activate = '1'
-            AND service_template_model_stm_id IN (" . implode(', ', array_keys($bindedParams)) . ")";
-
-        $stmt = $this->db->prepare($query);
-        foreach ($bindedParams as $bindedParam => $bindedValue) {
-            $stmt->bindValue($bindedParam, $bindedValue, PDO::PARAM_INT);
-        }
-        $stmt->execute();
-
-        $serviceIds = [];
-        $serviceTemplateIds2 = [];
-        foreach ($stmt->fetchAll(PDO::FETCH_ASSOC) as $value) {
-            if ($value['service_register'] === '0') {
-                $serviceTemplateIds2[] = $value['service_id'];
-            } else {
-                $serviceIds[] = $value['service_id'];
-            }
-        }
-        return array_merge(
-            $serviceIds,
-            $this->findServicesForConfigChangeFlagFromServiceTemplateIds($serviceTemplateIds2)
-        );
-    }
-
     /**
      * Return ids of hosts linked to service
      *
      * @param int $servicegroupId
      * @param bool $shouldServicegroupBeEnabled (default true)
-     * @return int[]
      * @throws Exception
+     * @return int[]
      */
     public function findHostsForConfigChangeFlagFromServiceGroupId(
         int $servicegroupId,
@@ -209,7 +151,7 @@ class CentreonConfigurationChange
             JOIN servicegroup ON servicegroup.sg_id = sgr.servicegroup_sg_id
             JOIN service ON service.service_id = sgr.service_service_id
             WHERE service.service_activate = '1' AND sgr.servicegroup_sg_id = :servicegroup_id"
-            . ($shouldServicegroupBeEnabled ? " AND servicegroup.sg_activate = '1'" : "");
+            . ($shouldServicegroupBeEnabled ? " AND servicegroup.sg_activate = '1'" : '');
 
         $stmt = $this->db->prepare($query);
         $stmt->bindValue(':servicegroup_id', $servicegroupId, PDO::PARAM_INT);
@@ -242,8 +184,8 @@ class CentreonConfigurationChange
      *
      * @param int[] $hostIds
      * @param bool $shouldHostBeEnabled (default true)
-     * @return int[]
      * @throws Exception
+     * @return int[]
      */
     public function findPollersForConfigChangeFlagFromHostIds(array $hostIds, bool $shouldHostBeEnabled = true): array
     {
@@ -260,10 +202,10 @@ class CentreonConfigurationChange
             $query = "SELECT DISTINCT(phr.nagios_server_id)
             FROM ns_host_relation phr
             JOIN host ON host.host_id = phr.host_host_id
-            WHERE host.host_activate = '1' AND phr.host_host_id IN (" . implode(', ', array_keys($bindedParams)) . ")";
+            WHERE host.host_activate = '1' AND phr.host_host_id IN (" . implode(', ', array_keys($bindedParams)) . ')';
         } else {
-            $query = "SELECT DISTINCT(phr.nagios_server_id) FROM ns_host_relation phr
-            WHERE phr.host_host_id IN (" . implode(', ', array_keys($bindedParams)) . ")";
+            $query = 'SELECT DISTINCT(phr.nagios_server_id) FROM ns_host_relation phr
+            WHERE phr.host_host_id IN (' . implode(', ', array_keys($bindedParams)) . ')';
         }
 
         $stmt = $this->db->prepare($query);
@@ -275,31 +217,6 @@ class CentreonConfigurationChange
         return $stmt->fetchAll(PDO::FETCH_COLUMN);
     }
 
-    /**
-     * Set 'updated' flag to '1' for all listed poller ids
-     *
-     * @param int[] $pollerIds
-     * @throws Exception
-     */
-    private function definePollersToUpdated(array $pollerIds): void
-    {
-        if ($pollerIds === []) {
-            return;
-        }
-
-        $bindedParams = [];
-        foreach ($pollerIds as $key => $pollerId) {
-            $bindedParams[':poller_id_' . $key] = $pollerId;
-        }
-        $query = "UPDATE nagios_server SET updated = '1' WHERE id IN ("
-            . implode(', ', array_keys($bindedParams)) . ")";
-        $stmt = $this->db->prepare($query);
-        foreach ($bindedParams as $bindedParam => $bindedValue) {
-            $stmt->bindValue($bindedParam, $bindedValue, PDO::PARAM_INT);
-        }
-        $stmt->execute();
-    }
-
     /**
      * Set relevent pollers as updated
      *
@@ -339,8 +256,8 @@ class CentreonConfigurationChange
                 );
                 break;
             default:
-                throw new CentreonClapiException(self::UNKNOWN_RESOURCE_TYPE . ":" . $resourceType);
-            break;
+                throw new CentreonClapiException(self::UNKNOWN_RESOURCE_TYPE . ':' . $resourceType);
+                break;
         }
         $pollerIds = $this->findPollersForConfigChangeFlagFromHostIds(
             $hostIds,
@@ -349,4 +266,73 @@ class CentreonConfigurationChange
 
         $this->definePollersToUpdated(array_merge($pollerIds, $previousPollers));
     }
+
+    /**
+     * Return ids of services linked to templates recursively
+     *
+     * @param int[] $serviceTemplateIds
+     * @throws Exception
+     * @return int[]
+     */
+    private function findServicesForConfigChangeFlagFromServiceTemplateIds(array $serviceTemplateIds): array
+    {
+        if ($serviceTemplateIds === []) {
+            return [];
+        }
+
+        $bindedParams = [];
+        foreach ($serviceTemplateIds as $key => $serviceTemplateId) {
+            $bindedParams[':servicetemplate_id_' . $key] = $serviceTemplateId;
+        }
+
+        $query = "SELECT service_id, service_register FROM service
+            WHERE service.service_activate = '1'
+            AND service_template_model_stm_id IN (" . implode(', ', array_keys($bindedParams)) . ')';
+
+        $stmt = $this->db->prepare($query);
+        foreach ($bindedParams as $bindedParam => $bindedValue) {
+            $stmt->bindValue($bindedParam, $bindedValue, PDO::PARAM_INT);
+        }
+        $stmt->execute();
+
+        $serviceIds = [];
+        $serviceTemplateIds2 = [];
+        foreach ($stmt->fetchAll(PDO::FETCH_ASSOC) as $value) {
+            if ($value['service_register'] === '0') {
+                $serviceTemplateIds2[] = $value['service_id'];
+            } else {
+                $serviceIds[] = $value['service_id'];
+            }
+        }
+
+        return array_merge(
+            $serviceIds,
+            $this->findServicesForConfigChangeFlagFromServiceTemplateIds($serviceTemplateIds2)
+        );
+    }
+
+    /**
+     * Set 'updated' flag to '1' for all listed poller ids
+     *
+     * @param int[] $pollerIds
+     * @throws Exception
+     */
+    private function definePollersToUpdated(array $pollerIds): void
+    {
+        if ($pollerIds === []) {
+            return;
+        }
+
+        $bindedParams = [];
+        foreach ($pollerIds as $key => $pollerId) {
+            $bindedParams[':poller_id_' . $key] = $pollerId;
+        }
+        $query = "UPDATE nagios_server SET updated = '1' WHERE id IN ("
+            . implode(', ', array_keys($bindedParams)) . ')';
+        $stmt = $this->db->prepare($query);
+        foreach ($bindedParams as $bindedParam => $bindedValue) {
+            $stmt->bindValue($bindedParam, $bindedValue, PDO::PARAM_INT);
+        }
+        $stmt->execute();
+    }
 }
