@@ -1,34 +1,19 @@
 <?php
 
 /*
- * Copyright 2005-2020 CENTREON
- * Centreon is developped by : Julien Mathis and Romain Le Merlus under
- * GPL Licence 2.0.
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
- * This program is free software; you can redistribute it and/or modify it under
- * the terms of the GNU General Public License as published by the Free Software
- * Foundation ; either version 2 of the License.
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
- * This program is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
- * PARTICULAR PURPOSE. See the GNU General Public License for more details.
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
- * You should have received a copy of the GNU General Public License along with
- * this program; if not, see <http://www.gnu.org/licenses>.
- *
- * Linking this program statically or dynamically with other modules is making a
- * combined work based on this program. Thus, the terms and conditions of the GNU
- * General Public License cover the whole combination.
- *
- * As a special exception, the copyright holders of this program give CENTREON
- * permission to link this program with independent modules to produce an executable,
- * regardless of the license terms of these independent modules, and to copy and
- * distribute the resulting executable under terms of CENTREON choice, provided that
- * CENTREON also meet, for each linked independent module, the terms  and conditions
- * of the license of that module. An independent module is a module which is not
- * derived from this program. If you modify this program, you may extend this
- * exception to your version of the program, but you are not obliged to do so. If you
- * do not wish to do so, delete this exception statement from your version.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  *
  * For more information : contact@centreon.com
  *
@@ -43,17 +28,17 @@ use CentreonGMT;
 use PDOException;
 use Pimple\Container;
 
-require_once "centreonObject.class.php";
-require_once "centreonHost.class.php";
-require_once "centreonService.class.php";
-require_once "Centreon/Object/Acknowledgement/RtAcknowledgement.php";
-require_once "Centreon/Object/Host/Host.php";
-require_once "Centreon/Object/Service/Service.php";
+require_once 'centreonObject.class.php';
+require_once 'centreonHost.class.php';
+require_once 'centreonService.class.php';
+require_once 'Centreon/Object/Acknowledgement/RtAcknowledgement.php';
+require_once 'Centreon/Object/Host/Host.php';
+require_once 'Centreon/Object/Service/Service.php';
 require_once dirname(__FILE__, 2) . '/centreonExternalCommand.class.php';
 require_once dirname(__FILE__, 2) . '/centreonDB.class.php';
 require_once dirname(__FILE__, 2) . '/centreonUser.class.php';
 require_once dirname(__FILE__, 2) . '/centreonGMT.class.php';
-require_once __DIR__ . "/Validator/RtValidator.php";
+require_once __DIR__ . '/Validator/RtValidator.php';
 
 /**
  * Class
@@ -69,18 +54,25 @@ class CentreonRtAcknowledgement extends CentreonObject
 
     /** @var array */
     protected $aHosts;
+
     /** @var array */
     protected $aServices;
+
     /** @var CentreonHost */
     protected $hostObject;
+
     /** @var CentreonService */
     protected $serviceObject;
+
     /** @var CentreonGMT */
     protected $GMTObject;
+
     /** @var CentreonExternalCommand */
     protected $externalCmdObj;
+
     /** @var string */
     protected $author;
+
     /** @var RtValidator */
     protected $rtValidator;
 
@@ -99,7 +91,7 @@ class CentreonRtAcknowledgement extends CentreonObject
         $this->serviceObject = new CentreonService($dependencyInjector);
         $this->GMTObject = new CentreonGMT();
         $this->externalCmdObj = new CentreonExternalCommand();
-        $this->action = "RTACKNOWLEDGEMENT";
+        $this->action = 'RTACKNOWLEDGEMENT';
         $this->author = CentreonUtils::getUserName();
         $this->rtValidator = new RtValidator($this->hostObject, $this->serviceObject);
 
@@ -107,66 +99,6 @@ class CentreonRtAcknowledgement extends CentreonObject
         $this->externalCmdObj->setUserId(CentreonUtils::getUserId());
     }
 
-    /**
-     * @param $parameters
-     * @return array
-     * @throws CentreonClapiException
-     */
-    private function parseParameters($parameters)
-    {
-        // Make safe the inputs
-        [$type, $resource, $comment, $sticky, $notify, $persistent] = explode(';', $parameters);
-
-        // Check if object type is supported
-        if (!in_array(strtoupper($type), $this->acknowledgementType)) {
-            throw new CentreonClapiException(self::MISSINGPARAMETER);
-        }
-
-        // Check if sticky is 0 or 2
-        if (!preg_match('/^(0|1|2)$/', $sticky)) {
-            throw new CentreonClapiException('Bad sticky parameter (0 or 1/2)');
-        }
-
-        // Check if notify is 0 or 1
-        if (!preg_match('/^(0|1)$/', $notify)) {
-            throw new CentreonClapiException('Bad notify parameter (0 or 1)');
-        }
-
-        // Check if fixed is 0 or 1
-        if (!preg_match('/^(0|1)$/', $persistent)) {
-            throw new CentreonClapiException('Bad persistent parameter (0 or 1)');
-        }
-
-        // Make safe the comment
-        $comment = escapeshellarg($comment);
-
-        return ['type' => $type, 'resource' => $resource, 'comment' => $comment, 'sticky' => $sticky, 'notify' => $notify, 'persistent' => $persistent];
-    }
-
-    /**
-     * @param $parameters
-     *
-     * @return array
-     * @throws CentreonClapiException
-     */
-    private function parseShowParameters($parameters)
-    {
-        $parameters = explode(';', $parameters);
-        if (count($parameters) === 1) {
-            $resource = '';
-        } elseif (count($parameters) === 2) {
-            $resource = $parameters[1];
-        } else {
-            throw new CentreonClapiException('Bad parameters');
-        }
-        $type = $parameters[0];
-
-        return [
-            'type' => $type,
-            'resource' => $resource,
-        ];
-    }
-
     /**
      * show acknowledgement without option
      *
@@ -182,19 +114,19 @@ class CentreonRtAcknowledgement extends CentreonObject
                 throw new CentreonClapiException(self::UNKNOWNPARAMETER . ' : ' . $parsedParameters['type']);
             }
             $method = 'show' . ucfirst($parsedParameters['type']);
-            $this->$method($parsedParameters['resource']);
+            $this->{$method}($parsedParameters['resource']);
         } else {
             $this->aHosts = $this->object->getLastHostAcknowledgement();
             $this->aServices = $this->object->getLastSvcAcknowledgement();
             $list = '';
-            //all host
+            // all host
             if (count($this->aHosts) !== 0) {
                 foreach ($this->aHosts as $host) {
                     $list .= $host['name'] . ";\n";
                 }
             }
 
-            //all service
+            // all service
             if (count($this->aServices) !== 0) {
                 foreach ($this->aServices as $service) {
                     $list .= $service['name'] . ';' . $service['description'] . " \n";
@@ -213,7 +145,7 @@ class CentreonRtAcknowledgement extends CentreonObject
     {
         $fields = ['id', 'host_name', 'entry_time', 'author', 'comment_data', 'sticky', 'notify_contacts', 'persistent_comment'];
 
-        if (!empty($hostList)) {
+        if (! empty($hostList)) {
             $hostList = array_filter(explode('|', $hostList));
             $db = $this->db;
             $hostList = array_map(
@@ -235,6 +167,7 @@ class CentreonRtAcknowledgement extends CentreonObject
             }
             if ($unknownHost !== []) {
                 echo "\n";
+
                 throw new CentreonClapiException(
                     self::OBJECT_NOT_FOUND . ' : Host : ' . implode('|', $unknownHost) . "\n"
                 );
@@ -249,7 +182,7 @@ class CentreonRtAcknowledgement extends CentreonObject
         $this->GMTObject->getMyGTMFromUser(CentreonUtils::getuserId());
 
         echo implode($this->delim, $fields) . "\n";
-        //Separates hosts
+        // Separates hosts
         if (count($hostAcknowledgementList)) {
             foreach ($hostAcknowledgementList as $hostAcknowledgement) {
                 $hostAcknowledgement['entry_time'] = $this->GMTObject->getDate(
@@ -279,7 +212,7 @@ class CentreonRtAcknowledgement extends CentreonObject
 
         $fields = ['id', 'host_name', 'service_name', 'entry_time', 'author', 'comment_data', 'sticky', 'notify_contacts', 'persistent_comment'];
 
-        if (!empty($svcList)) {
+        if (! empty($svcList)) {
             $svcList = array_filter(explode('|', $svcList));
             $db = $this->db;
             $svcList = array_map(
@@ -303,7 +236,7 @@ class CentreonRtAcknowledgement extends CentreonObject
             if ($existingService !== []) {
                 foreach ($existingService as $svc) {
                     $tmpAcknowledgement = $this->object->getLastSvcAcknowledgement($svc);
-                    if (!empty($tmpAcknowledgement)) {
+                    if (! empty($tmpAcknowledgement)) {
                         $serviceAcknowledgementList[] = array_pop($tmpAcknowledgement);
                     }
                 }
@@ -315,7 +248,7 @@ class CentreonRtAcknowledgement extends CentreonObject
         // Init user timezone
         $this->GMTObject->getMyGTMFromUser(CentreonUtils::getuserId());
 
-        //Separates hosts and services
+        // Separates hosts and services
         echo implode($this->delim, $fields) . "\n";
 
         if (count($serviceAcknowledgementList)) {
@@ -336,6 +269,7 @@ class CentreonRtAcknowledgement extends CentreonObject
 
         if ($unknownService !== []) {
             echo "\n";
+
             throw new CentreonClapiException(
                 self::OBJECT_NOT_FOUND . ' : Service : ' . implode('|', $unknownService) . "\n"
             );
@@ -346,8 +280,8 @@ class CentreonRtAcknowledgement extends CentreonObject
      * redirect on SVC or HOST
      *
      * @param null $parameters
-     * @return void
      * @throws CentreonClapiException
+     * @return void
      */
     public function add($parameters = null): void
     {
@@ -356,7 +290,7 @@ class CentreonRtAcknowledgement extends CentreonObject
         // to choose the best add (addHostAcknowledgement, addSvcAcknowledgement.)
         $method = 'add' . ucfirst($parsedParameters['type']) . 'Acknowledgement';
 
-        $this->$method(
+        $this->{$method}(
             $parsedParameters['resource'],
             $parsedParameters['comment'],
             $parsedParameters['sticky'],
@@ -365,6 +299,116 @@ class CentreonRtAcknowledgement extends CentreonObject
         );
     }
 
+    /**
+     * @param mixed $parameters
+     *
+     * @throws CentreonClapiException
+     * @throws PDOException
+     */
+    public function cancel($parameters = null): void
+    {
+        if (empty($parameters) || is_null($parameters)) {
+            throw new CentreonClapiException(self::MISSINGPARAMETER);
+        }
+        $listAcknowledgement = explode('|', $parameters);
+        $unknownAcknowledgement = [];
+
+        foreach ($listAcknowledgement as $acknowledgement) {
+            [$hostName, $serviceName] = explode(',', $acknowledgement);
+
+            if ($serviceName) {
+                $serviceId = $this->serviceObject->getObjectId($hostName . ';' . $serviceName);
+                if (
+                    $this->rtValidator->isServiceNameValid($hostName, $serviceName)
+                    && $this->object->svcIsAcknowledged($serviceId)
+                ) {
+                    $this->externalCmdObj->deleteAcknowledgement(
+                        'SVC',
+                        [$hostName . ';' . $serviceName => 'on']
+                    );
+                } else {
+                    $unknownAcknowledgement[] = $acknowledgement;
+                }
+            } else {
+                $hostId = $this->hostObject->getHostID($hostName);
+                if ($this->object->hostIsAcknowledged($hostId)) {
+                    $this->externalCmdObj->deleteAcknowledgement(
+                        'HOST',
+                        [$hostName => 'on']
+                    );
+                } else {
+                    $unknownAcknowledgement[] = $acknowledgement;
+                }
+            }
+        }
+
+        if (count($unknownAcknowledgement)) {
+            throw new CentreonClapiException(
+                self::OBJECT_NOT_FOUND . ' OR not acknowledged : ' . implode('|', $unknownAcknowledgement)
+            );
+        }
+    }
+
+    /**
+     * @param $parameters
+     * @throws CentreonClapiException
+     * @return array
+     */
+    private function parseParameters($parameters)
+    {
+        // Make safe the inputs
+        [$type, $resource, $comment, $sticky, $notify, $persistent] = explode(';', $parameters);
+
+        // Check if object type is supported
+        if (! in_array(strtoupper($type), $this->acknowledgementType)) {
+            throw new CentreonClapiException(self::MISSINGPARAMETER);
+        }
+
+        // Check if sticky is 0 or 2
+        if (! preg_match('/^(0|1|2)$/', $sticky)) {
+            throw new CentreonClapiException('Bad sticky parameter (0 or 1/2)');
+        }
+
+        // Check if notify is 0 or 1
+        if (! preg_match('/^(0|1)$/', $notify)) {
+            throw new CentreonClapiException('Bad notify parameter (0 or 1)');
+        }
+
+        // Check if fixed is 0 or 1
+        if (! preg_match('/^(0|1)$/', $persistent)) {
+            throw new CentreonClapiException('Bad persistent parameter (0 or 1)');
+        }
+
+        // Make safe the comment
+        $comment = escapeshellarg($comment);
+
+        return ['type' => $type, 'resource' => $resource, 'comment' => $comment, 'sticky' => $sticky, 'notify' => $notify, 'persistent' => $persistent];
+    }
+
+    /**
+     * @param $parameters
+     *
+     * @throws CentreonClapiException
+     * @return array
+     */
+    private function parseShowParameters($parameters)
+    {
+        $parameters = explode(';', $parameters);
+        if (count($parameters) === 1) {
+            $resource = '';
+        } elseif (count($parameters) === 2) {
+            $resource = $parameters[1];
+        } else {
+            throw new CentreonClapiException('Bad parameters');
+        }
+        $type = $parameters[0];
+
+        return [
+            'type' => $type,
+            'resource' => $resource,
+        ];
+    }
+
     /**
      * @param $resource
      * @param $comment
@@ -382,7 +426,7 @@ class CentreonRtAcknowledgement extends CentreonObject
         $notify,
         $persistent
     ): void {
-        if ($resource === "") {
+        if ($resource === '') {
             throw new CentreonClapiException(self::MISSINGPARAMETER);
         }
         $unknownHost = [];
@@ -425,7 +469,7 @@ class CentreonRtAcknowledgement extends CentreonObject
         $notify,
         $persistent
     ): void {
-        if ($resource === "") {
+        if ($resource === '') {
             throw new CentreonClapiException(self::MISSINGPARAMETER);
         }
         $unknownService = [];
@@ -460,55 +504,4 @@ class CentreonRtAcknowledgement extends CentreonObject
             throw new CentreonClapiException(self::OBJECT_NOT_FOUND . ' SERVICE : ' . implode('|', $unknownService));
         }
     }
-
-
-    /**
-     * @param mixed $parameters
-     *
-     * @throws CentreonClapiException
-     * @throws PDOException
-     */
-    public function cancel($parameters = null): void
-    {
-        if (empty($parameters) || is_null($parameters)) {
-            throw new CentreonClapiException(self::MISSINGPARAMETER);
-        }
-        $listAcknowledgement = explode('|', $parameters);
-        $unknownAcknowledgement = [];
-
-        foreach ($listAcknowledgement as $acknowledgement) {
-            [$hostName, $serviceName] = explode(',', $acknowledgement);
-
-            if ($serviceName) {
-                $serviceId = $this->serviceObject->getObjectId($hostName . ";" . $serviceName);
-                if (
-                    $this->rtValidator->isServiceNameValid($hostName, $serviceName)
-                    && $this->object->svcIsAcknowledged($serviceId)
-                ) {
-                    $this->externalCmdObj->deleteAcknowledgement(
-                        'SVC',
-                        [$hostName . ';' . $serviceName => 'on']
-                    );
-                } else {
-                    $unknownAcknowledgement[] = $acknowledgement;
-                }
-            } else {
-                $hostId = $this->hostObject->getHostID($hostName);
-                if ($this->object->hostIsAcknowledged($hostId)) {
-                    $this->externalCmdObj->deleteAcknowledgement(
-                        'HOST',
-                        [$hostName => 'on']
-                    );
-                } else {
-                    $unknownAcknowledgement[] = $acknowledgement;
-                }
-            }
-        }
-
-        if (count($unknownAcknowledgement)) {
-            throw new CentreonClapiException(
-                self::OBJECT_NOT_FOUND . ' OR not acknowledged : ' . implode('|', $unknownAcknowledgement)
-            );
-        }
-    }
 }
