@@ -127,7 +127,7 @@ class CentreonAuth
         $pearDB,
         $CentreonLog,
         $encryptType = self::ENCRYPT_MD5,
-        $token = '',
+        $token = ''
     ) {
         $this->dependencyInjector = $dependencyInjector;
         $this->CentreonLog = $CentreonLog;
@@ -255,7 +255,6 @@ class CentreonAuth
             }
 
             // Check password matching
-            $this->getCryptFunction(); // FIXME expression not used
             $this->checkPassword($password, $token);
             if ($this->passwdOk == self::PASSWORD_VALID) {
                 $this->CentreonLog->setUID($this->userInfos['contact_id']);
@@ -307,24 +306,6 @@ class CentreonAuth
         }
     }
 
-    /**
-     * Check crypt system
-     * @return string
-     */
-    protected function getCryptFunction()
-    {
-        if (isset($this->cryptEngine)) {
-            switch ($this->cryptEngine) {
-                case self::ENCRYPT_SHA1:
-                    return 'SHA1';
-                default:
-                    return 'MD5';
-            }
-        } else {
-            return 'MD5';
-        }
-    }
-
     /**
      * Crypt String
      * @param $str
@@ -428,7 +409,7 @@ class CentreonAuth
      *
      * @throws PDOException
      */
-    private function checkLdapPassword(string $password, bool $autoImport): void
+    private function checkLdapPassword($password, $autoImport): void
     {
         $res = $this->pearDB->query("SELECT ar_id FROM auth_ressource WHERE ar_enable = '1'");
         $authResources = [];
@@ -442,7 +423,7 @@ class CentreonAuth
 
         foreach ($authResources as $arId) {
             if ($autoImport && ! isset($this->ldap_auto_import[$arId])) {
-                continue;
+                break;
             }
             if ($this->passwdOk == self::PASSWORD_VALID) {
                 break;
