@@ -1,33 +1,19 @@
 <?php
+
 /*
- * Copyright 2005-2015 Centreon
- * Centreon is developped by : Julien Mathis and Romain Le Merlus under
- * GPL Licence 2.0.
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
- * This program is free software; you can redistribute it and/or modify it under
- * the terms of the GNU General Public License as published by the Free Software
- * Foundation ; either version 2 of the License.
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
- * This program is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
- * PARTICULAR PURPOSE. See the GNU General Public License for more details.
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
- * You should have received a copy of the GNU General Public License along with
- * this program; if not, see <http://www.gnu.org/licenses>.
- *
- * Linking this program statically or dynamically with other modules is making a
- * combined work based on this program. Thus, the terms and conditions of the GNU
- * General Public License cover the whole combination.
- *
- * As a special exception, the copyright holders of this program give Centreon
- * permission to link this program with independent modules to produce an executable,
- * regardless of the license terms of these independent modules, and to copy and
- * distribute the resulting executable under terms of Centreon choice, provided that
- * Centreon also meet, for each linked independent module, the terms  and conditions
- * of the license of that module. An independent module is a module which is not
- * derived from this program. If you modify this program, you may extend this
- * exception to your version of the program, but you are not obliged to do so. If you
- * do not wish to do so, delete this exception statement from your version.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  *
  * For more information : contact@centreon.com
  *
@@ -42,20 +28,23 @@
 class CentreonCfgWriter
 {
     /** @var string */
-    private $buffer = "";
+    private $buffer = '';
+
     /** @var CentreonXML */
     private $xmlBuffer;
+
     /** @var Centreon */
     private $centreon;
+
     /** @var string */
     private $file_path;
 
     /**
      *  CentreonCfgWriter constructor
      *
-     *  @param Centreon $centreon
-     *  @param string $file_full_path
-     *  @return void
+     * @param Centreon $centreon
+     * @param string $file_full_path
+     * @return void
      */
     public function __construct($centreon, $file_full_path)
     {
@@ -64,88 +53,22 @@ class CentreonCfgWriter
         $this->file_path = $file_full_path;
     }
 
-    /**
-     *  Creates the file
-     *
-     *  @return void
-     */
-    protected function createFile()
-    {
-        $this->createFileHeader();
-    }
-
-    /**
-     *  Writes basic text line to buffer
-     *  Returns the length of written text
-     *
-     *  @param string $text
-     *
-     *  @return int
-     */
-    protected function writeText($text)
-    {
-        $this->buffer .= $text;
-        return (strlen($text));
-    }
-
-    /**
-     *  Inserts Header of the file
-     *
-     *  @return void
-     */
-    protected function createFileHeader()
-    {
-        $time = date("F j, Y, g:i a");
-        $by = $this->centreon->user->get_name();
-        $len = $this->writeText("###################################################################\n");
-        $this->writeText("#                                                                 #\n");
-        $this->writeText("#                       GENERATED BY CENTREON                     #\n");
-        $this->writeText("#                                                                 #\n");
-        $this->writeText("#               Developped by :                                   #\n");
-        $this->writeText("#                   - Julien Mathis                               #\n");
-        $this->writeText("#                   - Romain Le Merlus                            #\n");
-        $this->writeText("#                                                                 #\n");
-        $this->writeText("#                           www.centreon.com                      #\n");
-        $this->writeText("#                For information : contact@centreon.com           #\n");
-        $this->writeText("###################################################################\n");
-        $this->writeText("#                                                                 #\n");
-        $this->writeText("#         Last modification " . $time);
-
-        $margin = strlen($time);
-        $margin = $len - 28 - $margin - 2;
-
-        for ($i = 0; $i != $margin; $i++) {
-            $this->writeText(" ");
-        }
-
-        $this->writeText("#\n");
-        $this->writeText("#         By " . $by);
-        $margin = $len - 13 - strlen($by) - 2;
-
-        for ($i = 0; $i != $margin; $i++) {
-            $this->writeText(" ");
-        }
-        $this->writeText("#\n");
-        $this->writeText("#                                                                 #\n");
-        $this->writeText("###################################################################\n\n");
-    }
-
     /**
      *  Defines cfg type
      *
-     *  @param string $type
-     *  @return void
+     * @param string $type
+     * @return void
      */
     public function startCfg($type): void
     {
-        $this->writeText("define " . $type . "{\n");
+        $this->writeText('define ' . $type . "{\n");
         $this->xmlBuffer->startElement($type);
     }
 
     /**
      *  Ends cfg
      *
-     *  @return void
+     * @return void
      */
     public function endCfg(): void
     {
@@ -194,4 +117,71 @@ class CentreonCfgWriter
     {
         return $this->xmlBuffer;
     }
+
+    /**
+     *  Creates the file
+     *
+     * @return void
+     */
+    protected function createFile()
+    {
+        $this->createFileHeader();
+    }
+
+    /**
+     *  Writes basic text line to buffer
+     *  Returns the length of written text
+     *
+     * @param string $text
+     *
+     * @return int
+     */
+    protected function writeText($text)
+    {
+        $this->buffer .= $text;
+
+        return strlen($text);
+    }
+
+    /**
+     *  Inserts Header of the file
+     *
+     * @return void
+     */
+    protected function createFileHeader()
+    {
+        $time = date('F j, Y, g:i a');
+        $by = $this->centreon->user->get_name();
+        $len = $this->writeText("###################################################################\n");
+        $this->writeText("#                                                                 #\n");
+        $this->writeText("#                       GENERATED BY CENTREON                     #\n");
+        $this->writeText("#                                                                 #\n");
+        $this->writeText("#               Developped by :                                   #\n");
+        $this->writeText("#                   - Julien Mathis                               #\n");
+        $this->writeText("#                   - Romain Le Merlus                            #\n");
+        $this->writeText("#                                                                 #\n");
+        $this->writeText("#                           www.centreon.com                      #\n");
+        $this->writeText("#                For information : contact@centreon.com           #\n");
+        $this->writeText("###################################################################\n");
+        $this->writeText("#                                                                 #\n");
+        $this->writeText('#         Last modification ' . $time);
+
+        $margin = strlen($time);
+        $margin = $len - 28 - $margin - 2;
+
+        for ($i = 0; $i != $margin; $i++) {
+            $this->writeText(' ');
+        }
+
+        $this->writeText("#\n");
+        $this->writeText('#         By ' . $by);
+        $margin = $len - 13 - strlen($by) - 2;
+
+        for ($i = 0; $i != $margin; $i++) {
+            $this->writeText(' ');
+        }
+        $this->writeText("#\n");
+        $this->writeText("#                                                                 #\n");
+        $this->writeText("###################################################################\n\n");
+    }
 }
