@@ -87,11 +87,12 @@ class CentreonDowntime
 
         $this->periods = [];
 
-        $statement = $this->db->query(<<<'SQL'
-            SELECT dt_id, dtp_start_time, dtp_end_time, dtp_day_of_week, dtp_month_cycle,
-                   dtp_day_of_month, dtp_fixed, dtp_duration
-            FROM downtime_period
-            SQL
+        $statement = $this->db->query(
+            <<<'SQL'
+                SELECT dt_id, dtp_start_time, dtp_end_time, dtp_day_of_week, dtp_month_cycle,
+                       dtp_day_of_month, dtp_fixed, dtp_duration
+                FROM downtime_period
+                SQL
         );
 
         while ($row = $statement->fetch()) {
@@ -110,7 +111,7 @@ class CentreonDowntime
     public function setSearch(string $search = ''): void
     {
         $this->safeSearch = '';
-        if ($search !== '') {
+        if ('' !== $search) {
             $this->safeSearch = htmlentities($search, ENT_QUOTES, 'UTF-8');
             $this->search = 'dt_name LIKE :search';
         }
@@ -177,39 +178,42 @@ class CentreonDowntime
         $searchSubRequest = $this->search !== '' ? 'AND ' . $this->search : '';
 
         if ($type === self::HOST_DOWNTIME) {
-            $statement = $this->db->prepare(<<<SQL
-                SELECT SQL_CALC_FOUND_ROWS dt_id, dt_name, dt_description, dt_activate
-                FROM downtime
-                WHERE (
-                    downtime.dt_id IN(SELECT dt_id FROM downtime_host_relation)
-                    OR downtime.dt_id IN (SELECT dt_id FROM downtime_hostgroup_relation))
-                    {$searchSubRequest}
-                ORDER BY dt_name
-                LIMIT :from, :limit
-                SQL
+            $statement = $this->db->prepare(
+                <<<SQL
+                    SELECT SQL_CALC_FOUND_ROWS dt_id, dt_name, dt_description, dt_activate
+                    FROM downtime
+                    WHERE (
+                        downtime.dt_id IN(SELECT dt_id FROM downtime_host_relation)
+                        OR downtime.dt_id IN (SELECT dt_id FROM downtime_hostgroup_relation))
+                        {$searchSubRequest}
+                    ORDER BY dt_name
+                    LIMIT :from, :limit
+                    SQL
             );
         } elseif ($type == self::SERVICE_DOWNTIME) {
-            $statement = $this->db->prepare(<<<SQL
-                SELECT SQL_CALC_FOUND_ROWS dt_id, dt_name, dt_description, dt_activate
-                FROM downtime
-                WHERE (
-                    downtime.dt_id IN (SELECT dt_id FROM downtime_service_relation)
-                    OR downtime.dt_id IN (SELECT dt_id FROM downtime_servicegroup_relation))
-                    {$searchSubRequest}
-                ORDER BY dt_name
-                LIMIT :from, :limit
-                SQL
+            $statement = $this->db->prepare(
+                <<<SQL
+                    SELECT SQL_CALC_FOUND_ROWS dt_id, dt_name, dt_description, dt_activate
+                    FROM downtime
+                    WHERE (
+                        downtime.dt_id IN (SELECT dt_id FROM downtime_service_relation)
+                        OR downtime.dt_id IN (SELECT dt_id FROM downtime_servicegroup_relation))
+                        {$searchSubRequest}
+                    ORDER BY dt_name
+                    LIMIT :from, :limit
+                    SQL
             );
         } else {
             $searchSubRequest = $this->search !== '' ? 'WHERE ' . $this->search : '';
 
-            $statement = $this->db->prepare(<<<SQL
-                SELECT SQL_CALC_FOUND_ROWS dt_id, dt_name, dt_description, dt_activate
-                FROM downtime
-                {$searchSubRequest}
-                ORDER BY dt_name
-                LIMIT :from, :limit
-                SQL
+            $statement = $this->db->prepare(
+                <<<SQL
+                    SELECT SQL_CALC_FOUND_ROWS dt_id, dt_name, dt_description, dt_activate
+                    FROM downtime
+                    {$searchSubRequest}
+                    ORDER BY dt_name
+                    LIMIT :from, :limit
+                    SQL
             );
         }
         try {
@@ -692,7 +696,7 @@ class CentreonDowntime
      */
     public function duplicate($ids, $nb): void
     {
-        $ids = is_array($ids) === false ? [$ids] : array_keys($ids);
+        $ids = false === is_array($ids) ? [$ids] : array_keys($ids);
         foreach ($ids as $id) {
             if (isset($nb[$id])) {
                 $query = 'SELECT dt_id, dt_name, dt_description, dt_activate FROM downtime WHERE dt_id = :id';
@@ -900,15 +904,16 @@ class CentreonDowntime
             self::TYPE_HOST_GROUP => $this->db->prepare(
                 'INSERT INTO downtime_hostgroup_relation (dt_id, hg_hg_id) VALUES (:id, :obj_id)'
             ),
-            self::TYPE_SERVICE => $this->db->prepare(<<<'SQL'
-                INSERT INTO downtime_service_relation (dt_id, host_host_id, service_service_id)
-                VALUES (:id, :host_id, :service_id)
-                SQL
+            self::TYPE_SERVICE => $this->db->prepare(
+                <<<'SQL'
+                    INSERT INTO downtime_service_relation (dt_id, host_host_id, service_service_id)
+                    VALUES (:id, :host_id, :service_id)
+                    SQL
             ),
             self::TYPE_SERVICE_GROUP => $this->db->prepare(
                 'INSERT INTO downtime_servicegroup_relation (dt_id, sg_sg_id) VALUES (:id, :obj_id)'
             ),
-            default => null,
+            default => null
         };
 
         if ($statement === null) {
@@ -1166,11 +1171,12 @@ class CentreonDowntime
         }
 
         [$bindValues, $subRequest] = $this->createMultipleBindQuery($ids, ':id_');
-        $statement = $this->db->prepare(<<<SQL
-            UPDATE downtime
-                SET dt_activate = :status
-            WHERE dt_id IN ({$subRequest})
-            SQL
+        $statement = $this->db->prepare(
+            <<<SQL
+                UPDATE downtime
+                    SET dt_activate = :status
+                WHERE dt_id IN ({$subRequest})
+                SQL
         );
         foreach ($bindValues as $key => $value) {
             $statement->bindValue($key, $value, PDO::PARAM_INT);
@@ -1257,14 +1263,15 @@ class CentreonDowntime
      */
     private function createDowntimePeriods(array $params): void
     {
-        $statement = $this->db->prepare(<<<'SQL'
-            INSERT INTO downtime_period (dt_id, dtp_start_time, dtp_end_time,
-                dtp_day_of_week, dtp_month_cycle, dtp_day_of_month, dtp_fixed, dtp_duration,
-                dtp_activate)
-            SELECT :dt_id_new, dtp_start_time, dtp_end_time, dtp_day_of_week, dtp_month_cycle,
-                dtp_day_of_month, dtp_fixed, dtp_duration, dtp_activate
-            FROM downtime_period WHERE dt_id = :dt_id
-            SQL
+        $statement = $this->db->prepare(
+            <<<'SQL'
+                INSERT INTO downtime_period (dt_id, dtp_start_time, dtp_end_time,
+                    dtp_day_of_week, dtp_month_cycle, dtp_day_of_month, dtp_fixed, dtp_duration,
+                    dtp_activate)
+                SELECT :dt_id_new, dtp_start_time, dtp_end_time, dtp_day_of_week, dtp_month_cycle,
+                    dtp_day_of_month, dtp_fixed, dtp_duration, dtp_activate
+                FROM downtime_period WHERE dt_id = :dt_id
+                SQL
         );
         $statement->bindValue(':dt_id_new', (int) $params['dt_id_new'], PDO::PARAM_INT);
         $statement->bindValue(':dt_id', (int) $params['dt_id'], PDO::PARAM_INT);
@@ -1316,12 +1323,13 @@ class CentreonDowntime
      */
     private function createDowntimeServicesRelations(array $params): void
     {
-        $statement = $this->db->prepare(<<<'SQL'
-            INSERT INTO downtime_service_relation (dt_id, host_host_id, service_service_id)
-            SELECT :dt_id_new, host_host_id, service_service_id
-            FROM downtime_service_relation
-            WHERE dt_id = :dt_id
-            SQL
+        $statement = $this->db->prepare(
+            <<<'SQL'
+                INSERT INTO downtime_service_relation (dt_id, host_host_id, service_service_id)
+                SELECT :dt_id_new, host_host_id, service_service_id
+                FROM downtime_service_relation
+                WHERE dt_id = :dt_id
+                SQL
         );
         $statement->bindValue(':dt_id_new', (int) $params['dt_id_new'], PDO::PARAM_INT);
         $statement->bindValue(':dt_id', (int) $params['dt_id'], PDO::PARAM_INT);
@@ -1337,12 +1345,13 @@ class CentreonDowntime
      */
     private function createDowntimeServiceGroupsRelations(array $params): void
     {
-        $statement = $this->db->prepare(<<<'SQL'
-            INSERT INTO downtime_servicegroup_relation (dt_id, sg_sg_id)
-            SELECT :dt_id_new, sg_sg_id
-            FROM downtime_servicegroup_relation
-            WHERE dt_id = :dt_id
-            SQL
+        $statement = $this->db->prepare(
+            <<<'SQL'
+                INSERT INTO downtime_servicegroup_relation (dt_id, sg_sg_id)
+                SELECT :dt_id_new, sg_sg_id
+                FROM downtime_servicegroup_relation
+                WHERE dt_id = :dt_id
+                SQL
         );
         $statement->bindValue(':dt_id_new', (int) $params['dt_id_new'], PDO::PARAM_INT);
         $statement->bindValue(':dt_id', (int) $params['dt_id'], PDO::PARAM_INT);
