@@ -183,22 +183,24 @@ class CentreonExternalCommand
         $db = CentreonDBInstance::getDbCentreonStorageInstance();
         // Check if $host is an id or a name
         if (preg_match("/^\d+$/", $host)) {
-            $statement = $db->prepare(<<<'SQL'
-                SELECT instance_id
-                FROM hosts
-                WHERE hosts.host_id = :host_id
-                  AND hosts.enabled = '1'
-                SQL
+            $statement = $db->prepare(
+                <<<'SQL'
+                    SELECT instance_id
+                    FROM hosts
+                    WHERE hosts.host_id = :host_id
+                      AND hosts.enabled = '1'
+                    SQL
             );
             $statement->bindValue(':host_id', (int) $host, PDO::PARAM_INT);
             $statement->execute();
         } else {
-            $statement = $db->prepare(<<<'SQL'
-                SELECT instance_id
-                FROM hosts
-                WHERE hosts.name = :host_name
-                  AND hosts.enabled = '1' LIMIT 1
-                SQL
+            $statement = $db->prepare(
+                <<<'SQL'
+                    SELECT instance_id
+                    FROM hosts
+                    WHERE hosts.name = :host_name
+                      AND hosts.enabled = '1' LIMIT 1
+                    SQL
             );
             $statement->bindValue(':host_name', $host);
             $statement->execute();
@@ -273,7 +275,7 @@ class CentreonExternalCommand
         $notify,
         $persistent,
         $author,
-        $comment,
+        $comment
     ): void {
         $pollerId = $this->getPollerID($hostName);
 
@@ -304,7 +306,7 @@ class CentreonExternalCommand
         $notify,
         $persistent,
         $author,
-        $comment,
+        $comment
     ): void {
         $pollerId = $this->getPollerID($hostName);
 
@@ -380,7 +382,7 @@ class CentreonExternalCommand
         $persistant,
         $duration = null,
         $withServices = false,
-        $hostOrCentreonTime = '0',
+        $hostOrCentreonTime = '0'
     ): void {
         global $centreon;
 
@@ -456,7 +458,7 @@ class CentreonExternalCommand
         $end,
         $persistant,
         $duration = null,
-        $hostOrCentreonTime = '0',
+        $hostOrCentreonTime = '0'
     ): void {
         global $centreon;
 
