@@ -19,8 +19,6 @@
  *
  */
 
-use Centreon\Domain\Service\I18nService;
-
 /**
  * Class
  *
@@ -176,7 +174,37 @@ class CentreonLang
      */
     private function getBrowserDefaultLanguage()
     {
-        return I18nService::guessLocaleFromRequest();
+        $currentLocale = '';
+
+        if (version_compare(PHP_VERSION, '5.2.0') >= 0 && isset($_SERVER['HTTP_ACCEPT_LANGUAGE'])) {
+            $browserLocale = $_SERVER['HTTP_ACCEPT_LANGUAGE'];
+            $currentLocale .= Locale::acceptFromHttp($browserLocale);
+        } else {
+            $currentLocale .= $this->parseHttpAcceptHeader();
+        }
+
+        return $this->getFullLocale($currentLocale);
+    }
+
+    /**
+     * Used to convert the browser language's from a short string to a string
+     *
+     * @param string $shortLocale
+     * @return string $fullLocale
+     */
+    private function getFullLocale($shortLocale)
+    {
+        $fullLocale = '';
+
+        $as = ['fr' => 'fr_FR', 'fr_FR' => 'fr_FR', 'en' => 'en_US', 'en_US' => 'en_US'];
+
+        if (isset($as[$shortLocale])) {
+            $fullLocale .= $as[$shortLocale];
+        } else {
+            $fullLocale = 'en_US';
+        }
+
+        return $fullLocale;
     }
 
     /**
