@@ -1,33 +1,19 @@
 <?php
+
 /*
- * Copyright 2005-2016 Centreon
- * Centreon is developped by : Julien Mathis and Romain Le Merlus under
- * GPL Licence 2.0.
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
- * This program is free software; you can redistribute it and/or modify it under
- * the terms of the GNU General Public License as published by the Free Software
- * Foundation ; either version 2 of the License.
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
- * This program is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
- * PARTICULAR PURPOSE. See the GNU General Public License for more details.
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
- * You should have received a copy of the GNU General Public License along with
- * this program; if not, see <http://www.gnu.org/licenses>.
- *
- * Linking this program statically or dynamically with other modules is making a
- * combined work based on this program. Thus, the terms and conditions of the GNU
- * General Public License cover the whole combination.
- *
- * As a special exception, the copyright holders of this program give Centreon
- * permission to link this program with independent modules to produce an executable,
- * regardless of the license terms of these independent modules, and to copy and
- * distribute the resulting executable under terms of Centreon choice, provided that
- * Centreon also meet, for each linked independent module, the terms  and conditions
- * of the license of that module. An independent module is a module which is not
- * derived from this program. If you modify this program, you may extend this
- * exception to your version of the program, but you are not obliged to do so. If you
- * do not wish to do so, delete this exception statement from your version.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  *
  * For more information : contact@centreon.com
  *
@@ -43,6 +29,7 @@ class CentreonPerformanceService
 {
     /** @var CentreonDB */
     protected $dbMon;
+
     /** @var CentreonACL */
     protected $aclObj;
 
@@ -61,9 +48,9 @@ class CentreonPerformanceService
     /**
      * @param array $filters
      *
-     * @return array
      * @throws PDOException
      * @throws RestBadRequestException
+     * @return array
      */
     public function getList($filters = [])
     {
@@ -72,7 +59,7 @@ class CentreonPerformanceService
 
         $serviceDescription = false === isset($filters['service']) ? '' : $filters['service'];
 
-        if (isset($filters['page_limit']) && isset($filters['page'])) {
+        if (isset($filters['page_limit'], $filters['page'])) {
             $limit = ($filters['page'] - 1) * $filters['page_limit'];
             $range = 'LIMIT ' . $limit . ',' . $filters['page_limit'];
         } else {
@@ -81,8 +68,8 @@ class CentreonPerformanceService
 
         if (isset($filters['hostgroup'])) {
             $additionnalTables .= ',hosts_hostgroups hg ';
-            $additionnalCondition .= 'AND (hg.host_id = i.host_id AND hg.hostgroup_id IN (' .
-                implode(',', $filters['hostgroup']) . ')) ';
+            $additionnalCondition .= 'AND (hg.host_id = i.host_id AND hg.hostgroup_id IN ('
+                . implode(',', $filters['hostgroup']) . ')) ';
         }
         if (isset($filters['servicegroup'])) {
             $additionnalTables .= ',services_servicegroups sg ';
@@ -99,12 +86,12 @@ class CentreonPerformanceService
             . 'FROM ( '
             . '( SELECT CONCAT(i.host_name, " - ", i.service_description) as fullname, '
             . 'i.host_id, i.service_id, m.index_id '
-            . 'FROM index_data i, metrics m ' . (!$this->aclObj->admin ? ', centreon_acl acl ' : '')
+            . 'FROM index_data i, metrics m ' . (! $this->aclObj->admin ? ', centreon_acl acl ' : '')
             . 'WHERE i.id = m.index_id '
             . 'AND i.host_name NOT LIKE "\_Module\_%" '
-            . (!$this->aclObj->admin
-                ? ' AND acl.host_id = i.host_id AND acl.service_id = i.service_id AND acl.group_id IN (' .
-                $this->aclObj->getAccessGroupsString() . ') ' : '')
+            . (! $this->aclObj->admin
+                ? ' AND acl.host_id = i.host_id AND acl.service_id = i.service_id AND acl.group_id IN ('
+                . $this->aclObj->getAccessGroupsString() . ') ' : '')
             . $additionnalCondition
             . ') '
             . $virtualServicesCondition
@@ -114,7 +101,6 @@ class CentreonPerformanceService
             . 'ORDER BY fullname '
             . $range;
 
-
         $DBRESULT = $this->dbMon->query($query);
         $serviceList = [];
         while ($data = $DBRESULT->fetchRow()) {
@@ -133,9 +119,9 @@ class CentreonPerformanceService
      */
     private function getVirtualServicesCondition($additionnalCondition)
     {
-        /* First, get virtual services for metaservices */
+        // First, get virtual services for metaservices
         $metaServiceCondition = '';
-        if (!$this->aclObj->admin) {
+        if (! $this->aclObj->admin) {
             $metaServices = $this->aclObj->getMetaServices();
             $virtualServices = [];
             foreach ($metaServices as $metaServiceId => $metaServiceName) {
@@ -159,20 +145,20 @@ class CentreonPerformanceService
             . 'AND i.service_id = s.service_id '
             . ') ';
 
-        /* Then, get virtual services for modules*/
+        // Then, get virtual services for modules
         $allVirtualServiceIds = CentreonHook::execute('Service', 'getVirtualServiceIds');
         foreach ($allVirtualServiceIds as $moduleVirtualServiceIds) {
             foreach ($moduleVirtualServiceIds as $hostname => $virtualServiceIds) {
                 if (count($virtualServiceIds)) {
-                    $virtualServicesCondition .= 'UNION ALL (' .
-                        'SELECT CONCAT("' . $hostname . ' - ", s.display_name) as fullname, i.host_id, ' .
-                        'i.service_id, m.index_id ' .
-                        'FROM index_data i, metrics m, services s ' .
-                        'WHERE i.id = m.index_id ' .
-                        $additionnalCondition .
-                        'AND s.service_id IN (' . implode(',', $virtualServiceIds) . ') ' .
-                        'AND i.service_id = s.service_id ' .
-                        ') ';
+                    $virtualServicesCondition .= 'UNION ALL ('
+                        . 'SELECT CONCAT("' . $hostname . ' - ", s.display_name) as fullname, i.host_id, '
+                        . 'i.service_id, m.index_id '
+                        . 'FROM index_data i, metrics m, services s '
+                        . 'WHERE i.id = m.index_id '
+                        . $additionnalCondition
+                        . 'AND s.service_id IN (' . implode(',', $virtualServiceIds) . ') '
+                        . 'AND i.service_id = s.service_id '
+                        . ') ';
                 }
             }
         }
