@@ -34,6 +34,7 @@ class CentreonService
 {
     private const TABLE_SERVICE_CONFIGURATION = 'service';
     private const TABLE_SERVICE_REALTIME = 'services';
+    private const PASSWORD_REPLACEMENT_VALUE = '**********';
 
     /** @var CentreonDB */
     protected $db;
@@ -463,9 +464,9 @@ class CentreonService
         $macroDescription = [],
         $isMassiveChange = false,
         $cmdId = false,
-        $macroFrom = false,
+        $macroFrom = false
     ): void {
-        if ($isMassiveChange === false) {
+        if (false === $isMassiveChange) {
             $this->db->query('DELETE FROM on_demand_macro_service
 							WHERE svc_svc_id = ' . $this->db->escape($serviceId));
         } else {
@@ -609,6 +610,8 @@ class CentreonService
                 $valPassword = null;
                 if (isset($_REQUEST['is_password'][$key])) {
                     $valPassword = $_REQUEST['is_password'][$key] === '1' ? '1' : null;
+                } elseif ($_REQUEST['macroValue'][$key]) {
+                    $valPassword = $_REQUEST['macroValue'][$key] === self::PASSWORD_REPLACEMENT_VALUE ? '1' : null;
                 }
                 $arr[$i]['macroPassword_#index#'] = $valPassword;
 
@@ -730,7 +733,7 @@ class CentreonService
         &$macroValue,
         $cmdId = false,
         $isMassiveChange = false,
-        $macroFrom = false,
+        $macroFrom = false
     ): void {
         $aListTemplate = getListTemplates($pearDB, $serviceId);
 
@@ -1672,14 +1675,15 @@ class CentreonService
         $searchTable = ($monitoringDB === true) ? self::TABLE_SERVICE_REALTIME : self::TABLE_SERVICE_CONFIGURATION;
         $database = ($monitoringDB === true) ? $this->dbMon : $this->db;
 
-        $statement = $database->prepare(<<<SQL
-            SELECT
-                {$searchColumns}
-            FROM
-                {$searchTable}
-            WHERE
-                service_id = :serviceId
-            SQL
+        $statement = $database->prepare(
+            <<<SQL
+                SELECT
+                    {$searchColumns}
+                FROM
+                    {$searchTable}
+                WHERE
+                    service_id = :serviceId
+                SQL
         );
         $statement->bindValue(':serviceId', (int) $id, PDO::PARAM_INT);
         $statement->execute();
