@@ -1,34 +1,19 @@
 <?php
 
 /*
- * Copyright 2005-2021 Centreon
- * Centreon is developed by : Julien Mathis and Romain Le Merlus under
- * GPL Licence 2.0.
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
- * This program is free software; you can redistribute it and/or modify it under
- * the terms of the GNU General Public License as published by the Free Software
- * Foundation ; either version 2 of the License.
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
- * This program is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
- * PARTICULAR PURPOSE. See the GNU General Public License for more details.
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
- * You should have received a copy of the GNU General Public License along with
- * this program; if not, see <http://www.gnu.org/licenses>.
- *
- * Linking this program statically or dynamically with other modules is making a
- * combined work based on this program. Thus, the terms and conditions of the GNU
- * General Public License cover the whole combination.
- *
- * As a special exception, the copyright holders of this program give Centreon
- * permission to link this program with independent modules to produce an executable,
- * regardless of the license terms of these independent modules, and to copy and
- * distribute the resulting executable under terms of Centreon choice, provided that
- * Centreon also meet, for each linked independent module, the terms  and conditions
- * of the license of that module. An independent module is a module which is not
- * derived from this program. If you modify this program, you may extend this
- * exception to your version of the program, but you are not obliged to do so. If you
- * do not wish to do so, delete this exception statement from your version.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  *
  * For more information : contact@centreon.com
  *
@@ -76,8 +61,8 @@ class CentreonSession
     /**
      * Write value in php session and close it
      *
-     * @param  string $key   session attribute
-     * @param  mixed  $value session value to save
+     * @param string $key session attribute
+     * @param mixed $value session value to save
      */
     public static function writeSessionClose($key, $value): void
     {
@@ -99,18 +84,18 @@ class CentreonSession
      */
     public function registerVar($registerVar): void
     {
-        if (!isset($_SESSION[$registerVar])) {
-            $_SESSION[$registerVar] = $$registerVar;
+        if (! isset($_SESSION[$registerVar])) {
+            $_SESSION[$registerVar] = ${$registerVar};
         }
     }
 
     /**
      * Check user session status
      *
-     * @param  string        $sessionId Session id to check
-     * @param  CentreonDB    $db
-     * @return bool
+     * @param string $sessionId Session id to check
+     * @param CentreonDB $db
      * @throws PDOException
+     * @return bool
      */
     public static function checkSession($sessionId, CentreonDB $db): bool
     {
@@ -120,6 +105,7 @@ class CentreonSession
         $prepare = $db->prepare('SELECT `session_id` FROM session WHERE `session_id` = :session_id');
         $prepare->bindValue(':session_id', $sessionId, PDO::PARAM_STR);
         $prepare->execute();
+
         return $prepare->fetch(PDO::FETCH_ASSOC) !== false;
     }
 
@@ -128,8 +114,8 @@ class CentreonSession
      *
      * @param CentreonDB $pearDB
      *
-     * @return bool If the session is updated or not
      * @throws PDOException
+     * @return bool If the session is updated or not
      */
     public function updateSession($pearDB): bool
     {
@@ -141,12 +127,12 @@ class CentreonSession
         if (self::checkSession($sessionId, $pearDB)) {
             try {
                 $sessionStatement = $pearDB->prepare(
-                    "UPDATE `session`
+                    'UPDATE `session`
                     SET `last_reload` = :lastReload, `ip_address` = :ipAddress
-                    WHERE `session_id` = :sessionId"
+                    WHERE `session_id` = :sessionId'
                 );
                 $sessionStatement->bindValue(':lastReload', time(), PDO::PARAM_INT);
-                $sessionStatement->bindValue(':ipAddress', $_SERVER["REMOTE_ADDR"], PDO::PARAM_STR);
+                $sessionStatement->bindValue(':ipAddress', $_SERVER['REMOTE_ADDR'], PDO::PARAM_STR);
                 $sessionStatement->bindValue(':sessionId', $sessionId, PDO::PARAM_STR);
                 $sessionStatement->execute();
 
@@ -156,7 +142,7 @@ class CentreonSession
                     FROM `options`
                     WHERE `key` = 'session_expire'"
                 );
-                if (($option = $optionResult->fetch()) && !empty($option['value'])) {
+                if (($option = $optionResult->fetch()) && ! empty($option['value'])) {
                     $sessionExpire = (int) $option['value'];
                 }
 
@@ -164,9 +150,9 @@ class CentreonSession
                     ->add(new DateInterval('PT' . $sessionExpire . 'M'))
                     ->getTimestamp();
                 $tokenStatement = $pearDB->prepare(
-                    "UPDATE `security_token`
+                    'UPDATE `security_token`
                     SET `expiration_date` = :expirationDate
-                    WHERE `token` = :sessionId"
+                    WHERE `token` = :sessionId'
                 );
                 $tokenStatement->bindValue(':expirationDate', $expirationDate, PDO::PARAM_INT);
                 $tokenStatement->bindValue(':sessionId', $sessionId, PDO::PARAM_STR);
@@ -187,20 +173,21 @@ class CentreonSession
      * @param string $sessionId
      * @param CentreonDB $pearDB
      *
-     * @return int|string
      * @throws PDOException
+     * @return int|string
      */
     public static function getUser($sessionId, $pearDB)
     {
         $sessionId = str_replace(['_', '%'], ['', ''], $sessionId);
         $DBRESULT = $pearDB->query(
             "SELECT user_id FROM session
-                WHERE `session_id` = '" . htmlentities(trim($sessionId), ENT_QUOTES, "UTF-8") . "'"
+                WHERE `session_id` = '" . htmlentities(trim($sessionId), ENT_QUOTES, 'UTF-8') . "'"
         );
         $row = $DBRESULT->fetchRow();
-        if (!$row) {
+        if (! $row) {
             return 0;
         }
+
         return $row['user_id'];
     }
 }
