@@ -1,34 +1,19 @@
 <?php
 
 /*
- * Copyright 2005-2012 Centreon
- * Centreon is developped by : Julien Mathis and Romain Le Merlus under
- * GPL Licence 2.0.
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
- * This program is free software; you can redistribute it and/or modify it under
- * the terms of the GNU General Public License as published by the Free Software
- * Foundation ; either version 2 of the License.
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
- * This program is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
- * PARTICULAR PURPOSE. See the GNU General Public License for more details.
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
- * You should have received a copy of the GNU General Public License along with
- * this program; if not, see <http://www.gnu.org/licenses>.
- *
- * Linking this program statically or dynamically with other modules is making a
- * combined work based on this program. Thus, the terms and conditions of the GNU
- * General Public License cover the whole combination.
- *
- * As a special exception, the copyright holders of this program give Centreon
- * permission to link this program with independent modules to produce an executable,
- * regardless of the license terms of these independent modules, and to copy and
- * distribute the resulting executable under terms of Centreon choice, provided that
- * Centreon also meet, for each linked independent module, the terms  and conditions
- * of the license of that module. An independent module is a module which is not
- * derived from this program. If you modify this program, you may extend this
- * exception to your version of the program, but you are not obliged to do so. If you
- * do not wish to do so, delete this exception statement from your version.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  *
  * For more information : contact@centreon.com
  *
@@ -43,10 +28,13 @@ class Centreon_Wizard
 {
     /** @var string */
     private $_uuid = null;
+
     /** @var string */
     private $_name = null;
+
     /** @var array */
     private $_values = [];
+
     /** @var int */
     private $_lastUpdate = 0;
 
@@ -63,6 +51,28 @@ class Centreon_Wizard
         $this->_lastUpdate = time();
     }
 
+    /**
+     * Magic method __sleep
+     *
+     * @return string[]
+     */
+    public function __sleep()
+    {
+        $this->_lastUpdate = time();
+
+        return ['_uuid', '_lastUpdate', '_name', '_values'];
+    }
+
+    /**
+     * Magic method __wakeup
+     *
+     * @return void
+     */
+    public function __wakeup()
+    {
+        $this->_lastUpdate = time();
+    }
+
     /**
      * Get values for a step
      *
@@ -75,6 +85,7 @@ class Centreon_Wizard
         if (false === isset($this->_values[$step])) {
             return [];
         }
+
         return $this->_values[$step];
     }
 
@@ -92,6 +103,7 @@ class Centreon_Wizard
         if (false === isset($this->_values[$step]) || false === isset($this->_values[$step][$name])) {
             return $default;
         }
+
         return $this->_values[$step][$name];
     }
 
@@ -105,7 +117,7 @@ class Centreon_Wizard
      */
     public function addValues($step, $post): void
     {
-        /* Reinit */
+        // Reinit
         $this->_values[$step] = [];
         foreach ($post as $key => $value) {
             if (strncmp($key, 'step' . $step . '_', 6) === 0) {
@@ -124,30 +136,6 @@ class Centreon_Wizard
      */
     public function testUuid($uuid)
     {
-        if ($uuid == $this->_uuid) {
-            return true;
-        }
-        return false;
-    }
-
-    /**
-     * Magic method __sleep
-     *
-     * @return string[]
-     */
-    public function __sleep()
-    {
-        $this->_lastUpdate = time();
-        return ['_uuid', '_lastUpdate', '_name', '_values'];
-    }
-
-    /**
-     * Magic method __wakeup
-     *
-     * @return void
-     */
-    public function __wakeup()
-    {
-        $this->_lastUpdate = time();
+        return (bool) ($uuid == $this->_uuid);
     }
 }
