@@ -20,6 +20,8 @@
  */
 
 use App\Kernel;
+use Core\Common\Application\UseCase\VaultTrait;
+use Core\MonitoringServer\Application\Repository\ReadMonitoringServerRepositoryInterface;
 use Pimple\Container;
 use Symfony\Component\DependencyInjection\Exception\ServiceCircularReferenceException;
 use Symfony\Component\DependencyInjection\Exception\ServiceNotFoundException;
@@ -31,6 +33,7 @@ use Symfony\Component\DependencyInjection\Exception\ServiceNotFoundException;
  */
 class Broker extends AbstractObjectJSON
 {
+    use VaultTrait;
     private const STREAM_BBDO_SERVER = 'bbdo_server';
     private const STREAM_BBDO_CLIENT = 'bbdo_client';
 
@@ -116,6 +119,8 @@ class Broker extends AbstractObjectJSON
     /** @var object|null */
     protected $readVaultConfigurationRepository = null;
 
+    private ReadMonitoringServerRepositoryInterface $readMonitoringServerRepository;
+
     /**
      * Broker constructor
      *
@@ -134,6 +139,9 @@ class Broker extends AbstractObjectJSON
         $this->readVaultConfigurationRepository = $kernel->getContainer()->get(
             Core\Security\Vault\Application\Repository\ReadVaultConfigurationRepositoryInterface::class
         );
+        $this->readMonitoringServerRepository = $kernel->getContainer()->get(
+            ReadMonitoringServerRepositoryInterface::class
+        );
     }
 
     /**
@@ -199,12 +207,13 @@ class Broker extends AbstractObjectJSON
     /**
      * @param $poller_id
      * @param $localhost
+     * @param mixed $pollerId
      *
      * @throws PDOException
      * @throws RuntimeException
      * @return void
      */
-    private function generate($poller_id, $localhost): void
+    private function generate($pollerId, $localhost): void
     {
         $this->getExternalValues();
 
@@ -216,10 +225,10 @@ class Broker extends AbstractObjectJSON
             AND config_activate = '1'
             ");
         }
-        $this->stmt_broker->bindParam(':poller_id', $poller_id, PDO::PARAM_INT);
+        $this->stmt_broker->bindParam(':poller_id', $pollerId, PDO::PARAM_INT);
         $this->stmt_broker->execute();
 
-        $this->getEngineParameters($poller_id);
+        $this->getEngineParameters($pollerId);
 
         if (is_null($this->stmt_broker_parameters)) {
             $this->stmt_broker_parameters = $this->backend_instance->db->prepare("SELECT
@@ -362,10 +371,10 @@ class Broker extends AbstractObjectJSON
                             $object[$key][$subvalue['config_group_id']]['name'],
                             'forward-to-anomaly-detection'
                         ) == 0)
-                        && (strcmp(
-                            $object[$key][$subvalue['config_group_id']]['path'],
-                            '/usr/share/centreon-broker/lua/centreon-anomaly-detection.lua'
-                        ) == 0)
+                            && (strcmp(
+                                $object[$key][$subvalue['config_group_id']]['path'],
+                                '/usr/share/centreon-broker/lua/centreon-anomaly-detection.lua'
+                            ) == 0)
                         ) {
                             $anomalyDetectionLuaOutputGroupID = $subvalue['config_group_id'];
                         }
@@ -435,6 +444,38 @@ class Broker extends AbstractObjectJSON
                 $object['vault_configuration'] = $this->readVaultConfigurationRepository->getLocation();
             }
 
+            if ($this->isVaultEnabled && $this->readVaultRepository !== null) {
+                foreach ($object['output'] as $outputIndex => $output) {
+                    $this->processVaultOutput($output, $outputIndex, $object);
+                }
+            }
+
+            $shouldBeEncrypted = $this->readMonitoringServerRepository->isEncryptionReady($pollerId);
+            foreach ($object['output'] as &$output) {
+                if (
+                    ($output['type'] === 'sql' || $output['type'] === 'storage')
+                    && array_key_exists('db_password', $output)
+                ) {
+                    $output['db_password'] = $shouldBeEncrypted
+                        ? 'encrypt::' . $this->engineContextEncryption->crypt($output['db_password'])
+                        : $output['db_password'];
+                }
+                if (! isset($output['lua_parameter']) || ! is_array($output['lua_parameter'])) {
+                    continue;
+                }
+
+                foreach ($output['lua_parameter'] as &$luaParameter) {
+                    if (
+                        isset($luaParameter['type'], $luaParameter['value'])
+                        && $luaParameter['type'] === 'password'
+                        && is_string($luaParameter['value'])
+                    ) {
+                        $luaParameter['value'] = $shouldBeEncrypted
+                        ? 'encrypt::' . $this->engineContextEncryption->crypt($luaParameter['value'])
+                        : $luaParameter['value'];
+                    }
+                }
+            }
             // Generate file
             $this->generateFile($object);
             $this->writeFile($this->backend_instance->getPath());
@@ -758,4 +799,76 @@ class Broker extends AbstractObjectJSON
 
         return $luaParameters;
     }
+
+    /**
+     * Process vault output and update object with vault data.
+     *
+     * @param array $output
+     * @param int $outputIndex
+     * @param array $object
+     * @return void
+     */
+    private function processVaultOutput(array &$output, int $outputIndex, array &$object): void
+    {
+        foreach ($output as $outputKey => $outputValue) {
+            if (is_string($outputValue) && $this->isAVaultPath($outputValue)) {
+                $this->updateVaultData($output, $outputKey, $outputValue, $object['output'][$outputIndex]);
+            }
+
+            if ($outputKey === 'lua_parameter' && is_array($outputValue)) {
+                $this->processLuaParameters($output, $outputKey, $outputValue, $object['output'][$outputIndex]);
+            }
+        }
+    }
+
+    /**
+     * Update vault data for a given key.
+     *
+     * @param array $output
+     * @param string $outputKey
+     * @param string $outputValue
+     * @param array $outputReference
+     * @return void
+     */
+    private function updateVaultData(
+        array &$output,
+        string $outputKey,
+        string $outputValue,
+        array &$outputReference
+    ): void {
+        $vaultData = $this->readVaultRepository->findFromPath($outputValue);
+        $vaultKey = $output['name'] . '_' . $outputKey;
+        if (array_key_exists($vaultKey, $vaultData)) {
+            $outputReference[$outputKey] = $vaultData[$vaultKey];
+        }
+    }
+
+    /**
+     * Process Lua parameters and update with vault data if applicable.
+     *
+     * @param array $output
+     * @param string $outputKey
+     * @param array $luaParameters
+     * @param array $outputReference
+     * @return void
+     */
+    private function processLuaParameters(
+        array &$output,
+        string $outputKey,
+        array $luaParameters,
+        array &$outputReference
+    ): void {
+        foreach ($luaParameters as $parameterIndex => $luaParameter) {
+            if ($luaParameter['type'] === 'password'
+                && is_string($luaParameter['value'])
+                && $this->isAVaultPath($luaParameter['value'])
+            ) {
+                $vaultData = $this->readVaultRepository->findFromPath($luaParameter['value']);
+                $vaultKey = $output['name'] . '_' . $outputKey . '_' . $luaParameter['name'];
+                if (array_key_exists($vaultKey, $vaultData)) {
+                    $outputReference[$outputKey][$parameterIndex]['value'] = $vaultData[$vaultKey];
+                }
+            }
+        }
+    }
 }
