@@ -1,12 +1,5 @@
 import { makeStyles } from 'tss-react/mui';
 
-export const useStyles = makeStyles()((theme) => ({
-  modalHeader: {
-    fontSize: theme.typography.h5.fontSize,
-    fontWeight: theme.typography.fontWeightBold
-  }
-}));
-
 export const useFormStyles = makeStyles()((theme) => ({
   groups: {
     '&:hover': {
