@@ -37,8 +37,7 @@ export const labelAddAHost = 'Add a host';
 export const labelParameters = 'Parameters';
 export const labelDNSIP = 'DNS/IP';
 export const labelSelectHost = 'Select host';
-export const labelConnectionInitiatedByPoller =
-  'Connection initiated by poller';
+
 export const labelAgent = 'Agent';
 export const labelConfigurationServer = 'Configuration provider';
 export const labelAgentConfigurationCreated = 'Agent configuration created';
@@ -90,6 +89,3 @@ export const labelByPollerTooltip =
 
 export const labelAtLeastOneConnexionMode =
   'Au moins un des modes de connexion doit être activé.';
-
-export const labelSelectAtLeastOneColumn =
-  'At least one column must be selected';
