@@ -241,9 +241,7 @@ const rolesMapping: Array<InputProps> = [
         {
           connectedAutocomplete: {
             additionalConditionParameters: [],
-            endpoint: accessGroupsEndpoint,
-            getOptionLabel: (option) => option?.name?.toString() || '',
-            optionProperty: 'name'
+            endpoint: accessGroupsEndpoint
           },
           dataTestId: 'oidc_accessGroup',
           fieldName: 'accessGroup',
@@ -324,9 +322,7 @@ const groupsMapping: Array<InputProps> = [
         {
           connectedAutocomplete: {
             additionalConditionParameters: [],
-            endpoint: contactGroupsEndpoint,
-            getOptionLabel: (option) => option?.name?.toString() || '',
-            optionProperty: 'name'
+            endpoint: contactGroupsEndpoint
           },
           dataTestId: 'oidc_contactGroup',
           fieldName: 'contactGroup',
@@ -496,9 +492,7 @@ export const inputs: Array<InputProps> = [
   {
     connectedAutocomplete: {
       additionalConditionParameters: [],
-      endpoint: contactTemplatesEndpoint,
-      getOptionLabel: (option) => option?.name?.toString() || '',
-      optionProperty: 'name'
+      endpoint: contactTemplatesEndpoint
     },
     dataTestId: 'oidc_contactTemplate',
     fieldName: 'contactTemplate',
