@@ -1,12 +1,13 @@
 import { useMemo } from 'react';
 
 import { ResponseError, useSnackbar } from '@centreon/ui';
-import { useAtom, useSetAtom } from 'jotai';
+import { useAtom } from 'jotai';
 import { isEmpty } from 'ramda';
 import { useTranslation } from 'react-i18next';
 
 import { useDisable as useDisableRequest } from '../../api';
-import { isRevokingDialogCanceledAtom, tokensToDisableAtom } from '../../atoms';
+
+import { tokensToDisableAtom } from '../../atoms';
 import { labelTokenDisabled } from '../../translatedLabels';
 
 interface UseDeleteState {
@@ -23,18 +24,12 @@ const useDisable = (): UseDeleteState => {
 
   const [tokensToDisable, setTokensToDisable] = useAtom(tokensToDisableAtom);
 
-  const setIsRevokingDialogCanceled = useSetAtom(isRevokingDialogCanceledAtom);
-
   const name = tokensToDisable[0]?.name;
   const userId =
     tokensToDisable[0]?.user?.id || tokensToDisable[0]?.creator?.id;
 
   const isOpened = useMemo(() => !isEmpty(tokensToDisable), [tokensToDisable]);
-  const resetSelections = (): void => {
-    setTokensToDisable([]);
-
-    setIsRevokingDialogCanceled(true);
-  };
+  const resetSelections = (): void => setTokensToDisable([]);
 
   const { disableMutation, isMutating } = useDisableRequest();
 
@@ -46,7 +41,7 @@ const useDisable = (): UseDeleteState => {
         return;
       }
 
-      setTokensToDisable([]);
+      resetSelections();
 
       showSuccessMessage(t(labelTokenDisabled));
     });
