@@ -1,13 +1,13 @@
 import { useMemo } from 'react';
 
 import { ResponseError, useSnackbar } from '@centreon/ui';
-import { useAtom, useSetAtom } from 'jotai';
+import { useAtom } from 'jotai';
 import { isEmpty } from 'ramda';
 import { useTranslation } from 'react-i18next';
 
 import { useEnable as useEnableRequest } from '../../api';
 
-import { isRevokingDialogCanceledAtom, tokensToEnableAtom } from '../../atoms';
+import { tokensToEnableAtom } from '../../atoms';
 import { labelTokenEnabled } from '../../translatedLabels';
 
 interface UseDeleteState {
@@ -23,18 +23,12 @@ const useEnable = (): UseDeleteState => {
   const { showSuccessMessage } = useSnackbar();
 
   const [tokensToEnable, setTokensToEnable] = useAtom(tokensToEnableAtom);
-  const setIsRevokingDialogCanceled = useSetAtom(isRevokingDialogCanceledAtom);
 
   const name = tokensToEnable[0]?.name;
   const userId = tokensToEnable[0]?.user?.id || tokensToEnable[0]?.creator?.id;
 
   const isOpened = useMemo(() => !isEmpty(tokensToEnable), [tokensToEnable]);
-
-  const resetSelections = (): void => {
-    setTokensToEnable([]);
-
-    setIsRevokingDialogCanceled(true);
-  };
+  const resetSelections = (): void => setTokensToEnable([]);
 
   const { enableMutation, isMutating } = useEnableRequest();
 
@@ -46,7 +40,7 @@ const useEnable = (): UseDeleteState => {
         return;
       }
 
-      setTokensToEnable([]);
+      resetSelections();
 
       showSuccessMessage(t(labelTokenEnabled));
     });
