@@ -2,7 +2,7 @@ import { userAtom } from '@centreon/ui-context';
 import { useAtomValue } from 'jotai';
 import { find, pick, propEq } from 'ramda';
 import { useTranslation } from 'react-i18next';
-import { useSearchParams } from 'react-router-dom';
+import { useSearchParams } from 'react-router';
 import { dataDuration, tokenTypes } from '../utils';
 
 const useInitilialValues = () => {
@@ -14,7 +14,7 @@ const useInitilialValues = () => {
 
   const user = currentUser.canManageApiTokens
     ? null
-    : pick(['id', 'alias'], currentUser);
+    : pick(['id', 'name'], currentUser);
 
   const duration = find(propEq('neverExpire', 'id'), dataDuration);
 
