@@ -1,7 +1,9 @@
 export interface Breadcrumb {
   index?: number;
+  is_react?: boolean;
   label: string;
   link: string;
+  options?: string;
 }
 
 export interface BreadcrumbsByPath {
