@@ -14,8 +14,6 @@ export const widgetPropertiesAtom = atom<FederatedWidgetProperties | undefined>(
   undefined
 );
 
-export const singleMetricSelectionAtom = atom<boolean | undefined>(undefined);
-
 export const singleResourceSelectionAtom = atom<boolean | undefined>(undefined);
 
 export const customBaseColorAtom = atom<boolean | undefined>(undefined);
@@ -125,7 +123,7 @@ export const timezoneInputKeyDerivedAtom = atom<string | undefined>((get) => {
 
 export const widgetPropertiesMetaPropertiesDerivedAtom = atom<Pick<
   FederatedWidgetProperties,
-  'singleResourceSelection' | 'customBaseColor' | 'singleMetricSelection'
+  'singleResourceSelection' | 'customBaseColor'
 > | null>((get) => {
   const widgetProperties = get(widgetPropertiesAtom);
 
@@ -135,7 +133,6 @@ export const widgetPropertiesMetaPropertiesDerivedAtom = atom<Pick<
 
   return {
     customBaseColor: widgetProperties.customBaseColor,
-    singleMetricSelection: widgetProperties.singleMetricSelection,
     singleResourceSelection: widgetProperties.singleResourceSelection
   };
 });
