@@ -1,8 +1,6 @@
 import { UseMutationResult, useQueryClient } from '@tanstack/react-query';
-import { pick } from 'ramda';
 
 import { Method, ResponseError, useMutationQuery } from '@centreon/ui';
-
 import { getDashboardEndpoint } from './endpoints';
 import { Dashboard, resource } from './models';
 
@@ -15,7 +13,6 @@ type UseUpdateDashboard = {
 
 const useUpdateDashboard = (): UseUpdateDashboard => {
   const queryClient = useQueryClient();
-
   const invalidateQueries = (): void => {
     queryClient.invalidateQueries({
       queryKey: [resource.dashboards]
@@ -30,17 +27,33 @@ const useUpdateDashboard = (): UseUpdateDashboard => {
     Dashboard
   >({
     getEndpoint: ({ id }) => getDashboardEndpoint(id),
-    method: Method.PATCH,
+    method: Method.POST,
     onSuccess: invalidateQueries
   });
 
-  const mutate = (variables: Dashboard): Promise<Dashboard | ResponseError> =>
-    mutateAsync({
+  const mutate = (variables: Dashboard): Promise<Dashboard | ResponseError> => {
+    const formData = new FormData();
+
+    formData.append('name', variables.name);
+    formData.append('description', variables.description || '');
+
+    if (variables?.refresh) {
+      formData.append('refresh[type]', variables.refresh.type);
+      if (variables.refresh.interval) {
+        formData.append(
+          'refresh[interval]',
+          JSON.stringify(variables.refresh.interval)
+        );
+      }
+    }
+
+    return mutateAsync({
       _meta: {
         id: variables.id
       },
-      payload: pick(['name', 'description', 'refresh'], variables)
+      payload: formData
     });
+  };
 
   return {
     mutate,
