@@ -54,7 +54,7 @@ const LoginForm = (): JSX.Element => {
     fieldName: aliasFieldName,
     touched
   });
-
+  const passwordValue = prop(passwordFieldName, values);
   const passwordError = getTouchedError({
     errors,
     fieldName: passwordFieldName,
@@ -84,25 +84,27 @@ const LoginForm = (): JSX.Element => {
         value={aliasValue || ''}
         onBlur={handleBlur(aliasFieldName)}
         onChange={handleChange(aliasFieldName)}
-        dataTestId={labelAlias}
       />
       <TextField
         fullWidth
         required
-        forceUncontrolled
         EndAdornment={passwordEndAdornment}
         StartAdornment={LockIcon}
         ariaLabel={labelPassword}
         error={passwordError}
-        inputProps={{
-          'aria-label': t(labelPassword) as string,
-          autocomplete: 'current-password'
+        textFieldSlotsAndSlotProps={{
+          slotProps: {
+            htmlInput: {
+              'aria-label': t(labelPassword) as string,
+              autoComplete: 'new-password'
+            }
+          }
         }}
         label={t(labelPassword)}
         type={isVisible ? 'text' : 'password'}
+        value={passwordValue || ''}
         onBlur={handleBlur(passwordFieldName)}
         onChange={handleChange(passwordFieldName)}
-        dataTestId={labelPassword}
       />
       <Button
         fullWidth
