@@ -1,13 +1,14 @@
-import { Typography, TypographyVariant } from '@mui/material';
-import makeStyles from '@mui/styles/makeStyles';
+import { makeStyles } from 'tss-react/mui';
 
-const useStyles = makeStyles(() => ({
+import { Typography, TypographyVariant } from '@mui/material';
+
+const useStyles = makeStyles()(() => ({
   name: {
     cursor: 'pointer',
     overflow: 'hidden',
     textOverflow: 'ellipsis',
-    whiteSpace: 'nowrap',
-  },
+    whiteSpace: 'nowrap'
+  }
 }));
 
 interface Props {
@@ -19,9 +20,9 @@ interface Props {
 const SelectableResourceName = ({
   name,
   onSelect,
-  variant = 'body1',
+  variant = 'body1'
 }: Props): JSX.Element => {
-  const classes = useStyles();
+  const { classes } = useStyles();
 
   return (
     <Typography className={classes.name} variant={variant} onClick={onSelect}>
