@@ -8,6 +8,7 @@ import {
   labelAnomalyDetection,
   labelCritical,
   labelDown,
+  labelFlapping,
   labelHard,
   labelHost,
   labelHostCategory,
@@ -79,6 +80,7 @@ const criteriaValueNameById = {
   hard: labelHard,
   host: labelHost,
   in_downtime: labelInDowntime,
+  in_flapping: labelFlapping,
   metaservice: labelMetaService,
   service: labelService,
   soft: labelSoft,
@@ -103,7 +105,18 @@ const inDowntimeState = {
   name: criteriaValueNameById[inDowntimeStateId]
 };
 
-const selectableStates = [unhandledState, acknowledgedState, inDowntimeState];
+const inFlappingStateId = 'in_flapping';
+const inFlappingState = {
+  id: inFlappingStateId,
+  name: criteriaValueNameById[inFlappingStateId]
+};
+
+const selectableStates = [
+  unhandledState,
+  acknowledgedState,
+  inDowntimeState,
+  inFlappingState
+];
 
 const hostResourceTypeId = 'host';
 const hostResourceType = {
