@@ -43,6 +43,7 @@ import { applyFilterDerivedAtom } from './filterAtoms';
 import { allFilter, unhandledProblemsFilter } from './models';
 
 import Filter from '.';
+import { serviceNamesEndpoint } from './api/endpoint';
 
 const emptyListData = {
   meta: { limit: 10, page: 1, search: {}, sort_by: {}, total: 0 },
@@ -118,7 +119,7 @@ const CriteriaParams = ({ view }): Array<unknown> => {
       'Basic criterias',
       [
         {
-          criteria: labelHost,
+          criteria: 'host',
           requestToWait: '@GetResourcesByHostType',
           searchValue: getSearchValue({
             value: getValueByTypeSelecton({
@@ -133,7 +134,7 @@ const CriteriaParams = ({ view }): Array<unknown> => {
           views: allViews
         },
         {
-          criteria: labelService,
+          criteria: 'service',
           requestToWait: '@GetResourcesByServiceType',
           searchValue: getSearchValue({
             value: getValueByTypeSelecton({
@@ -332,7 +333,7 @@ const initializeRequests = (): void => {
   setupIntercept({
     alias: 'GetResourcesByServiceType',
     fixtureFile: 'resources/filter/resourcesByServiceType.json',
-    path: `${resourcesEndpoint}**`,
+    path: `${serviceNamesEndpoint}**`,
     query: {
       name: 'types',
       value: '["service"]'
@@ -643,6 +644,103 @@ describe('Replaces whitespace with the \\s regex pattern', () => {
   });
 });
 
+const staticFilters = [
+  {
+    criteriaName: 'status_type',
+    criteriaInitialValue: 'HARD',
+    expectedCriteriaValue: 'hard',
+    id: 'Hard',
+    containerId: 'status_types',
+    expectedSuggestedCriteria: ',soft'
+  },
+  {
+    criteriaName: 'type',
+    criteriaInitialValue: 'HOST',
+    expectedCriteriaValue: 'host',
+    id: 'Host',
+    containerId: 'resource_types',
+    expectedSuggestedCriteria: ',service'
+  },
+  {
+    criteriaName: 'state',
+    criteriaInitialValue: 'UNHANDLED',
+    expectedCriteriaValue: 'unhandled',
+    id: 'Unhandled ',
+    containerId: 'states',
+    expectedSuggestedCriteria: ',acknowledged'
+  },
+  {
+    criteriaName: 'status',
+    criteriaInitialValue: 'UP',
+    expectedCriteriaValue: 'up',
+    id: 'Up',
+    containerId: 'statuses-host',
+    expectedSuggestedCriteria: ',down'
+  }
+];
+
+describe('search bar:ignores case sensitivity when searching static filters', () => {
+  beforeEach(() => {
+    const updatedStore = setView({
+      name: Visualization.All,
+      store: getStore()
+    });
+    mount({ store: updatedStore });
+  });
+
+  for (const data of staticFilters) {
+    const {
+      criteriaName,
+      criteriaInitialValue,
+      expectedCriteriaValue,
+      id,
+      containerId,
+      expectedSuggestedCriteria
+    } = data;
+
+    it('ignores case sensitivity when searching static filters', () => {
+      const getSearch = ({ value, name }) => `${name}:${value}`;
+
+      cy.findByPlaceholderText(labelSearch).type(
+        `${getSearch({ value: criteriaInitialValue, name: criteriaName })}{esc}{enter}`
+      );
+
+      cy.findByPlaceholderText(labelSearch)
+        .invoke('val')
+        .should(
+          'equal',
+          `${getSearch({ value: expectedCriteriaValue, name: criteriaName })} `
+        );
+
+      cy.findByLabelText(labelSearchOptions).click();
+
+      cy.findByText(labelShowMoreFilters).click();
+
+      cy.findByTestId(containerId).find(`#${id}`).should('be.checked');
+    });
+
+    it('displays the corresponding suggestoins when searching static filters', () => {
+      cy.findByPlaceholderText(labelSearch).type(
+        `${criteriaName}:${criteriaInitialValue.substring(0, 1)}`
+      );
+      cy.findByRole('menuitem', { name: expectedCriteriaValue });
+
+      cy.makeSnapshot(`suggestion for ${criteriaName} static filter`);
+
+      cy.findByPlaceholderText(labelSearch).clear();
+      cy.findByPlaceholderText(labelSearch).type(
+        `${criteriaName}:${criteriaInitialValue}`
+      );
+      cy.findByRole('menuitem', { name: expectedCriteriaValue }).should(
+        'not.exist'
+      );
+      cy.findByRole('menuitem', { name: expectedSuggestedCriteria }).should(
+        'exist'
+      );
+    });
+  }
+});
+
 describe('Keyboard actions', () => {
   beforeEach(() => {
     initializeRequests();
