@@ -1,5 +1,5 @@
 import { atom } from 'jotai';
-import { atomWithStorage, atomWithDefault } from 'jotai/utils';
+import { atomWithDefault, atomWithStorage } from 'jotai/utils';
 import {
   find,
   findIndex,
@@ -24,15 +24,15 @@ import { baseKey } from '../storage';
 import { labelNewFilter } from '../translatedLabels';
 
 import { Criteria, CriteriaValue } from './Criterias/models';
+import { build, parse } from './Criterias/searchQueryLanguage';
 import {
-  allFilter,
   Filter,
+  allFilter,
   isCustom,
   newFilter,
   resourceProblemsFilter,
   unhandledProblemsFilter
 } from './models';
-import { build, parse } from './Criterias/searchQueryLanguage';
 import { getStoredOrDefaultFilter } from './storedFilter';
 
 export const filterKey = `${baseKey}filter`;
@@ -153,11 +153,14 @@ export const setCriteriaDerivedAtom = atom(
   }
 );
 
-export const applyFilterDerivedAtom = atom(null, (get, set, filter: Filter) => {
-  set(currentFilterAtom, filter);
-  set(appliedFilterAtom, filter);
-  set(searchAtom, build(filter.criterias));
-});
+export const applyFilterDerivedAtom = atom(
+  null,
+  (_get, set, filter: Filter) => {
+    set(currentFilterAtom, filter);
+    set(appliedFilterAtom, filter);
+    set(searchAtom, build(filter.criterias));
+  }
+);
 
 export const setCriteriaAndNewFilterDerivedAtom = atom(
   null,
