@@ -1,6 +1,6 @@
 import {
-  MutableRefObject,
-  ReactNode,
+  type MutableRefObject,
+  type ReactNode,
   useEffect,
   useRef,
   useState
@@ -8,14 +8,12 @@ import {
 
 import { useAtomValue } from 'jotai';
 import {
-  add,
   equals,
   find,
   head,
   isEmpty,
   isNil,
   map,
-  negate,
   not,
   or,
   pipe,
@@ -31,22 +29,19 @@ import { makeStyles } from 'tss-react/mui';
 import { Skeleton, Typography } from '@mui/material';
 
 import {
+  type LineChartData,
+  ParentSize,
   getData,
   timeFormat,
   useLocaleDateTimeFormat,
-  useRequest,
-  ParentSize
+  useRequest
 } from '@centreon/ui';
 
-import { CommentParameters } from '../../Actions/api';
+import type { CommentParameters } from '../../Actions/api';
 import { selectedResourcesDetailsAtom } from '../../Details/detailsAtoms';
-import { ResourceDetails } from '../../Details/models';
-import {
-  CustomTimePeriod,
-  CustomTimePeriodProperty
-} from '../../Details/tabs/Graph/models';
-import { TimelineEvent } from '../../Details/tabs/Timeline/models';
-import { Resource } from '../../models';
+import type { ResourceDetails } from '../../Details/models';
+import type { TimelineEvent } from '../../Details/tabs/Timeline/models';
+import type { Resource } from '../../models';
 import { labelNoDataForThisPeriod } from '../../translatedLabels';
 
 import Graph from './Graph';
@@ -54,26 +49,24 @@ import {
   isListingGraphOpenAtom,
   timeValueAtom
 } from './Graph/mouseTimeValueAtoms';
-import { TimeShiftDirection } from './Graph/TimeShiftZones';
 import Legend from './Legend';
 import LoadingSkeleton from './LoadingSkeleton';
-import {
-  AdditionalLines,
-  AdjustTimePeriodProps,
+import type {
   FilterLines,
   GraphData,
   Line as LineModel,
+  LinesProps,
   NewLines,
   TimeValue
 } from './models';
 import { getLineData, getMetrics, getTimeSeries } from './timeSeries';
 
 interface Props {
-  adjustTimePeriod?: (props: AdjustTimePeriodProps) => void;
-  customTimePeriod?: CustomTimePeriod;
+  canAdjustTimePeriod?: boolean;
   displayCompleteGraph?: () => void;
   displayEventAnnotations?: boolean;
   displayTitle?: boolean;
+  end: string;
   endpoint?: string;
   filterLines?: ({ lines, resource }: FilterLines) => NewLines;
   getPerformanceGraphRef?: (
@@ -85,9 +78,9 @@ interface Props {
   isInViewport?: boolean;
   limitLegendRows?: boolean;
   onAddComment?: (commentParameters: CommentParameters) => void;
-  renderAdditionalLines?: (args: AdditionalLines) => ReactNode;
+  renderAdditionalLines?: (args: LinesProps) => ReactNode;
   resource: Resource | ResourceDetails;
-  resourceDetailsUpdated?: boolean;
+  start: string;
   timeline?: Array<TimelineEvent>;
   toggableLegend?: boolean;
   xAxisTickFormat?: string;
@@ -145,8 +138,6 @@ const useStyles = makeStyles<MakeStylesProps>()(
   })
 );
 
-const shiftRatio = 2;
-
 const PerformanceGraph = <T,>({
   endpoint,
   graphHeight,
@@ -155,9 +146,7 @@ const PerformanceGraph = <T,>({
   timeline,
   resource,
   onAddComment,
-  adjustTimePeriod,
-  customTimePeriod,
-  resourceDetailsUpdated = true,
+  canAdjustTimePeriod = false,
   displayEventAnnotations = false,
   displayTitle = true,
   limitLegendRows,
@@ -167,10 +156,12 @@ const PerformanceGraph = <T,>({
   graphActions,
   getPerformanceGraphRef,
   renderAdditionalLines,
+  end,
+  start,
   filterLines
 }: Props): JSX.Element => {
   const { classes } = useStyles({
-    canAdjustTimePeriod: not(isNil(adjustTimePeriod)),
+    canAdjustTimePeriod,
     displayTitle,
     graphHeight
   });
@@ -180,6 +171,8 @@ const PerformanceGraph = <T,>({
   const [lineData, setLineData] = useState<Array<LineModel>>();
   const [title, setTitle] = useState<string>();
   const [base, setBase] = useState<number>();
+  const [performanceGraphData, setPerformanceGraphData] =
+    useState<LineChartData>();
 
   const performanceGraphRef = useRef<HTMLDivElement | null>(null);
   const performanceGraphHeightRef = useRef<number>(0);
@@ -207,6 +200,7 @@ const PerformanceGraph = <T,>({
       endpoint
     })
       .then((graphData) => {
+        setPerformanceGraphData(graphData);
         setTimeSeries(getTimeSeries(graphData));
         setBase(graphData.global.base);
         setTitle(graphData.global.title);
@@ -345,39 +339,6 @@ const PerformanceGraph = <T,>({
     );
   };
 
-  const getShiftedDate = ({ property, direction, timePeriod }): Date => {
-    const adjustTimePeriodProps =
-      (timePeriod.end.getTime() - timePeriod.start.getTime()) / shiftRatio;
-
-    return new Date(
-      add(
-        prop(property, timePeriod).getTime(),
-        equals(direction, TimeShiftDirection.backward)
-          ? negate(adjustTimePeriodProps)
-          : adjustTimePeriodProps
-      )
-    );
-  };
-
-  const shiftTime = (direction: TimeShiftDirection): void => {
-    if (isNil(customTimePeriod)) {
-      return;
-    }
-
-    adjustTimePeriod?.({
-      end: getShiftedDate({
-        direction,
-        property: CustomTimePeriodProperty.end,
-        timePeriod: customTimePeriod
-      }),
-      start: getShiftedDate({
-        direction,
-        property: CustomTimePeriodProperty.start,
-        timePeriod: customTimePeriod
-      })
-    });
-  };
-
   const timeTick = propOr<string, TimeValue | null, string>(
     '',
     'timeTick',
@@ -422,21 +383,20 @@ const PerformanceGraph = <T,>({
         <ParentSize>
           {({ width, height }): JSX.Element => (
             <Graph<T>
-              applyZoom={adjustTimePeriod}
               base={base as number}
-              canAdjustTimePeriod={not(isNil(adjustTimePeriod))}
+              canAdjustTimePeriod={canAdjustTimePeriod}
               containsMetrics={containsMetrics}
               displayEventAnnotations={displayEventAnnotations}
               displayTimeValues={displayTimeValues}
+              end={end}
               height={height}
               interactWithGraph={interactWithGraph}
               lines={displayedLines}
-              loading={
-                not(resourceDetailsUpdated) && sendingGetGraphDataRequest
-              }
+              loading={sendingGetGraphDataRequest}
+              performanceGraphData={performanceGraphData}
               renderAdditionalLines={renderAdditionalLines}
               resource={resource}
-              shiftTime={shiftTime}
+              start={start}
               timeSeries={timeSeries}
               timeline={timeline}
               width={width}
