@@ -1,9 +1,11 @@
-import type { ComponentColumnProps } from '@centreon/ui';
+import { type ComponentColumnProps, SeverityCode } from '@centreon/ui';
 
+import { useMemo } from 'react';
 import StatusChip from './ServiceSubItemColumn/StatusChip';
 import { getStatus } from './ServiceSubItemColumn/SubItem';
+import useColumnStyles from './colomuns.style';
 
-import { useColumnStyles } from '.';
+const fallbackContent = { label: 'D', severity: SeverityCode.High };
 
 const ParentResourceColumn = ({
   row,
@@ -14,6 +16,16 @@ const ParentResourceColumn = ({
 
   const status = row?.parent?.status?.name;
 
+  const content = useMemo(
+    () => getStatus(status?.toLowerCase())?.label || fallbackContent.label,
+    [status]
+  );
+  const severityCode = useMemo(
+    () =>
+      getStatus(status?.toLowerCase())?.severity || fallbackContent.severity,
+    [status]
+  );
+
   if (!row.parent) {
     return null;
   }
@@ -21,10 +33,7 @@ const ParentResourceColumn = ({
   return (
     <>
       <div className={classes.resourceDetailsCell}>
-        <StatusChip
-          content={getStatus(status?.toLowerCase())?.label}
-          severityCode={getStatus(status?.toLowerCase())?.severity}
-        />
+        <StatusChip content={content} severityCode={severityCode} />
       </div>
       {renderEllipsisTypography?.({
         className: classes.resourceNameText,
