@@ -2,19 +2,19 @@ import { path } from 'ramda';
 
 import IconLink from '@mui/icons-material/Link';
 
-import { ComponentColumnProps } from '@centreon/ui';
+import type { ComponentColumnProps } from '@centreon/ui';
 
 import UrlColumn from '.';
 
 const NotesUrlColumn = ({ row }: ComponentColumnProps): JSX.Element => {
   const endpoint = path<string | undefined>(
     ['links', 'externals', 'notes', 'url'],
-    row,
+    row
   );
 
   const title = path<string | undefined>(
     ['links', 'externals', 'notes', 'label'],
-    row,
+    row
   );
 
   return (
