@@ -5,7 +5,6 @@ import {
   always,
   equals,
   ifElse,
-  isEmpty,
   isNil,
   map,
   mergeRight,
@@ -17,13 +16,11 @@ import {
 import { useTranslation } from 'react-i18next';
 
 import type { SelectEntry } from '@centreon/ui';
+import { getData, getUrlQueryParameters, useRequest } from '@centreon/ui';
 import {
-  getData,
-  getFoundFields,
-  getUrlQueryParameters,
-  useRequest
-} from '@centreon/ui';
-import { refreshIntervalAtom } from '@centreon/ui-context';
+  isResourceStatusFullSearchEnabledAtom,
+  refreshIntervalAtom
+} from '@centreon/ui-context';
 
 import { selectedVisualizationAtom } from '../../Actions/actionsAtoms';
 import {
@@ -34,8 +31,7 @@ import {
   selectedResourcesDetailsAtom,
   sendingDetailsAtom
 } from '../../Details/detailsAtoms';
-import { ResourceDetails } from '../../Details/models';
-import { searchableFields } from '../../Filter/Criterias/searchQueryLanguage';
+import type { ResourceDetails } from '../../Details/models';
 import {
   appliedFilterAtom,
   customFiltersAtom,
@@ -46,7 +42,7 @@ import {
   hostsEndpoint
 } from '../../api/endpoint';
 import { resourceDetailsDecoder } from '../../decoders';
-import { ResourceListing, SortOrder, Visualization } from '../../models';
+import { type ResourceListing, SortOrder, Visualization } from '../../models';
 import {
   labelNoResourceFound,
   labelSomethingWentWrong
@@ -59,8 +55,8 @@ import {
   pageAtom,
   sendingAtom
 } from '../listingAtoms';
-
-import { Search } from './models';
+import useGetCriteriaName from './useGetCriteriaName';
+import { getSearch } from './utils';
 
 export interface LoadResources {
   initAutorefreshAndLoad: () => void;
@@ -72,6 +68,8 @@ const defaultSecondSortCriteria = { [secondSortField]: SortOrder.desc };
 const useLoadResources = (): LoadResources => {
   const { t } = useTranslation();
 
+  const { getCriteriaNames } = useGetCriteriaName();
+
   const { sendRequest, sending } = useRequest<ResourceListing>({
     getErrorMessage: ifElse(
       pathEq(404, ['response', 'status']),
@@ -106,6 +104,9 @@ const useLoadResources = (): LoadResources => {
   const getCriteriaValue = useAtomValue(getCriteriaValueDerivedAtom);
   const appliedFilter = useAtomValue(appliedFilterAtom);
   const visualization = useAtomValue(selectedVisualizationAtom);
+  const isResourceStatusFullSearchEnabled = useAtomValue(
+    isResourceStatusFullSearchEnabledAtom
+  );
   const setListing = useSetAtom(listingAtom);
   const setSending = useSetAtom(sendingAtom);
   const setSendingDetails = useSetAtom(sendingDetailsAtom);
@@ -150,49 +151,6 @@ const useLoadResources = (): LoadResources => {
       });
   };
 
-  const getSearch = (): Search | undefined => {
-    const searchCriteria = getCriteriaValue('search');
-
-    if (!searchCriteria) {
-      return undefined;
-    }
-
-    const fieldMatches = getFoundFields({
-      fields: searchableFields,
-      value: searchCriteria as string
-    });
-
-    if (!isEmpty(fieldMatches)) {
-      const matches = fieldMatches.map((item) => {
-        const field = item?.field;
-        const values = item.value?.split(',')?.join('|');
-
-        return { field, value: `${field}:${values}` };
-      });
-
-      const formattedValue = matches.reduce((accumulator, previousValue) => {
-        return {
-          ...accumulator,
-          value: `${accumulator.value} ${previousValue.value}`
-        };
-      });
-
-      return {
-        regex: {
-          fields: matches.map(({ field }) => field),
-          value: formattedValue.value
-        }
-      };
-    }
-
-    return {
-      regex: {
-        fields: searchableFields,
-        value: searchCriteria as string
-      }
-    };
-  };
-
   const load = (): void => {
     const getCriteriaIds = (
       name: string
@@ -204,14 +162,6 @@ const useLoadResources = (): LoadResources => {
       return criteriaValue?.map(prop('id'));
     };
 
-    const getCriteriaNames = (name: string): Array<string> => {
-      const criteriaValue = getCriteriaValue(name) as
-        | Array<SelectEntry>
-        | undefined;
-
-      return (criteriaValue || []).map(prop('name')) as Array<string>;
-    };
-
     const getCriteriaLevels = (name: string): Array<number> => {
       const criteriaValue = getCriteriaValue(name) as
         | Array<SelectEntry>
@@ -239,22 +189,28 @@ const useLoadResources = (): LoadResources => {
       monitoringServers: getCriteriaNames('monitoring_servers'),
       page,
       resourceTypes: getCriteriaIds('resource_types'),
-      search: mergeRight(getSearch() || {}, {
-        conditions: [
-          ...names.map((name) => ({
-            field: 'name',
-            values: {
-              $rg: name
-            }
-          })),
-          ...parentNames.map((name) => ({
-            field: 'parent_name',
-            values: {
-              $rg: name
-            }
-          }))
-        ]
-      }),
+      search: mergeRight(
+        getSearch({
+          searchCriteria: getCriteriaValue('search'),
+          isResourceStatusFullSearchEnabled
+        }) || {},
+        {
+          conditions: [
+            ...names.map((name) => ({
+              field: 'name',
+              values: {
+                $rg: name
+              }
+            })),
+            ...parentNames.map((name) => ({
+              field: 'parent_name',
+              values: {
+                $rg: name
+              }
+            }))
+          ]
+        }
+      ),
       serviceCategories: getCriteriaNames('service_categories'),
       serviceGroups: getCriteriaNames('service_groups'),
       serviceSeverities: getCriteriaNames('service_severities'),
