@@ -1,5 +1,6 @@
 import { ReactNode, useMemo } from 'react';
 
+import { useAtomValue } from 'jotai';
 import {
   concat,
   equals,
@@ -10,14 +11,13 @@ import {
   reject,
   type
 } from 'ramda';
-import { useAtomValue } from 'jotai';
 
 import { useMemoComponent } from '@centreon/ui';
-
 import {
   federatedModulesAtom,
   federatedWidgetsAtom
-} from '../../federatedModules/atoms';
+} from '@centreon/ui-context';
+
 import { Remote } from '../../federatedModules/Load';
 import {
   FederatedComponentsConfiguration,
