@@ -1,37 +1,53 @@
 <?php
+
+/*
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ * https://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * For more information : contact@centreon.com
+ *
+ */
+
 $help = [];
 
 /**
  * Monitoring Engine
  */
-
 $help['tip_default_engine'] = dgettext('help', 'Default monitoring engine.');
 $help['tip_images_directory'] = dgettext('help', 'Directory where images are stored.');
 $help['tip_plugins_directory'] = dgettext('help', 'Directory where check plugins are stored.');
-$help["tip_interval_length"] = dgettext(
-    "help",
-    "This is the number of seconds per \"unit interval\" used for timing in the scheduling queue,"
-    . " re-notifications, etc. \"Units intervals\" are used in the object configuration file to determine how"
-    . " often to run a service check, how often to re-notify a contact, etc. The default value for this is set to 60,"
-    . " which means that a \"unit value\" of 1 in the object configuration file will mean 60 seconds (1 minute)."
+$help['tip_interval_length'] = dgettext(
+    'help',
+    'This is the number of seconds per "unit interval" used for timing in the scheduling queue,'
+    . ' re-notifications, etc. "Units intervals" are used in the object configuration file to determine how'
+    . ' often to run a service check, how often to re-notify a contact, etc. The default value for this is set to 60,'
+    . ' which means that a "unit value" of 1 in the object configuration file will mean 60 seconds (1 minute).'
 );
 
 /**
  * Monitoring database layer
  */
-
 $help['tip_broker_engine_used_by_centreon'] = dgettext('help', 'Broker module used by Centreon.');
 
 /**
  * Correlation Engine
  */
-
 $help['tip_start_script_for_correlator_engine'] = dgettext('help', 'Init script for broker daemon.');
 
 /**
  * Mailer path
  */
-
 $help['tip_directory+mailer_binary'] = dgettext(
     'help',
     'Mailer binary with complete path. This define the @MAILER@ macro used in notification commands.'
@@ -40,7 +56,6 @@ $help['tip_directory+mailer_binary'] = dgettext(
 /**
  * Tactical Overview
  */
-
 $help['tip_maximum_number_of_hosts_to_show'] = dgettext(
     'help',
     'Maximum number of hosts to show in the Tactical Overview page.'
@@ -54,7 +69,6 @@ $help['tip_page_refresh_interval'] = dgettext('help', 'Refresh interval used in
 /**
  * Default acknowledgement settings
  */
-
 $help['tip_sticky'] = dgettext('help', '[Sticky] option is enabled by default.');
 $help['tip_notify'] = dgettext('help', '[Notify] option is enabled by default.');
 $help['tip_persistent'] = dgettext('help', '[Persistent] option is enabled by default.');
@@ -67,7 +81,6 @@ $help['tip_force_active_checks'] = dgettext('help', '[Force Active Checks] optio
 /**
  * Default downtime settings
  */
-
 $help['tip_fixed'] = dgettext('help', 'Fixed.');
 $help['tip_set_downtimes_on_services_attached_to_hosts'] = dgettext(
     'help',
