@@ -93,7 +93,7 @@ class HTML_QuickForm_select2 extends HTML_QuickForm_select
         $elementLabel = null,
         $options = null,
         $attributes = null,
-        $sort = null,
+        $sort = null
     ) {
         global $centreon;
         parent::__construct($elementName, $elementLabel, $options, $attributes);
@@ -231,7 +231,7 @@ class HTML_QuickForm_select2 extends HTML_QuickForm_select
         $allowClear = 'true';
         $additionnalJs = '';
 
-        if ($this->_allowClear === false || $this->_flagFrozen) {
+        if (false === $this->_allowClear || $this->_flagFrozen) {
             $allowClear = 'false';
         }
 
@@ -429,20 +429,20 @@ class HTML_QuickForm_select2 extends HTML_QuickForm_select
      */
     public function onQuickFormEvent($event, $arg, &$caller)
     {
-        if ($event == 'updateValue') {
+        if ('updateValue' == $event) {
             $value = $this->_findValue($caller->_constantValues);
 
-            if ($value === null) {
+            if (null === $value) {
                 $value = is_null($this->_defaultDataset) ? $this->_findValue($caller->_submitValues) : $this->_defaultDataset;
 
                 // Fix for bug #4465 & #5269
                 // XXX: should we push this to element::onQuickFormEvent()?
-                if ($value === null && (! $caller->isSubmitted() || ! $this->getMultiple())) {
+                if (null === $value && (! $caller->isSubmitted() || ! $this->getMultiple())) {
                     $value = $this->_findValue($caller->_defaultValues);
                 }
             }
 
-            if ($value !== null) {
+            if (null !== $value) {
                 if (! is_array($value)) {
                     $value = [$value];
                 }
