@@ -1,34 +1,19 @@
 <?php
 
 /*
- * Copyright 2005-2020 Centreon
- * Centreon is developed by : Julien Mathis and Romain Le Merlus under
- * GPL Licence 2.0.
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
- * This program is free software; you can redistribute it and/or modify it under
- * the terms of the GNU General Public License as published by the Free Software
- * Foundation ; either version 2 of the License.
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
- * This program is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
- * PARTICULAR PURPOSE. See the GNU General Public License for more details.
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
- * You should have received a copy of the GNU General Public License along with
- * this program; if not, see <http://www.gnu.org/licenses>.
- *
- * Linking this program statically or dynamically with other modules is making a
- * combined work based on this program. Thus, the terms and conditions of the GNU
- * General Public License cover the whole combination.
- *
- * As a special exception, the copyright holders of this program give Centreon
- * permission to link this program with independent modules to produce an executable,
- * regardless of the license terms of these independent modules, and to copy and
- * distribute the resulting executable under terms of Centreon choice, provided that
- * Centreon also meet, for each linked independent module, the terms  and conditions
- * of the license of that module. An independent module is a module which is not
- * derived from this program. If you modify this program, you may extend this
- * exception to your version of the program, but you are not obliged to do so. If you
- * do not wish to do so, delete this exception statement from your version.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  *
  * For more information : contact@centreon.com
  *
@@ -52,7 +37,7 @@ require_once $centreon_path . 'www/class/centreonMedia.class.php';
 require_once $centreon_path . 'www/class/centreonCriticality.class.php';
 
 CentreonSession::start(1);
-if (!isset($_SESSION['centreon']) || !isset($_REQUEST['widgetId']) || !isset($_REQUEST['page'])) {
+if (! isset($_SESSION['centreon']) || ! isset($_REQUEST['widgetId']) || ! isset($_REQUEST['page'])) {
     exit;
 }
 
@@ -62,17 +47,17 @@ if (CentreonSession::checkSession(session_id(), $db) == 0) {
 }
 
 /**
- * @var $dbb CentreonDB
+ * @var CentreonDB $dbb
  */
 $dbb = $dependencyInjector['realtime_db'];
 
-/* Init Objects */
+// Init Objects
 $criticality = new CentreonCriticality($db);
 $media = new CentreonMedia($db);
 
+// Smarty template initialization
 $path = $centreon_path . 'www/widgets/host-monitoring/src/';
-$template = new Smarty();
-$template = initSmartyTplForPopup($path, $template, './', $centreon_path);
+$template = SmartyBC::createSmartyTemplate($path, './');
 
 $centreon = $_SESSION['centreon'];
 
@@ -101,6 +86,7 @@ try {
         ['widget_id' => $widgetId],
         $e
     );
+
     throw $e;
 }
 
@@ -164,10 +150,10 @@ if (isset($preferences['host_name_search']) && $preferences['host_name_search']
 }
 
 if (isset($preferences['notification_filter']) && $preferences['notification_filter']) {
-    if ($preferences['notification_filter'] == "enabled") {
-        $query = CentreonUtils::conditionBuilder($query, " notify = 1");
-    } elseif ($preferences['notification_filter'] == "disabled") {
-        $query = CentreonUtils::conditionBuilder($query, " notify = 0");
+    if ($preferences['notification_filter'] == 'enabled') {
+        $query = CentreonUtils::conditionBuilder($query, ' notify = 1');
+    } elseif ($preferences['notification_filter'] == 'disabled') {
+        $query = CentreonUtils::conditionBuilder($query, ' notify = 0');
     }
 }
 
@@ -218,11 +204,11 @@ if (isset($preferences['hostgroup']) && $preferences['hostgroup']) {
         if ($queryHg != '') {
             $queryHg .= ', ';
         }
-        $queryHg .= ":id_" . $result;
+        $queryHg .= ':id_' . $result;
         $mainQueryParameters[] = [
             'parameter' => ':id_' . $result,
-            'value' => (int)$result,
-            'type' => PDO::PARAM_INT
+            'value' => (int) $result,
+            'type' => PDO::PARAM_INT,
         ];
     }
     $hostgroupHgIdCondition = <<<SQL
@@ -233,52 +219,83 @@ if (isset($preferences['hostgroup']) && $preferences['hostgroup']) {
         SQL;
     $query = CentreonUtils::conditionBuilder($query, $hostgroupHgIdCondition);
 }
-if (!empty($preferences['criticality_filter'])) {
+if (! empty($preferences['criticality_filter'])) {
     $tab = explode(',', $preferences['criticality_filter']);
     $labels = '';
     foreach ($tab as $p) {
         if ($labels != '') {
             $labels .= ',';
         }
-        $labels .= ":severity_id_" . $p;
+        $labels .= ':severity_id_' . $p;
         $mainQueryParameters[] = [
-            'parameter' => ":severity_id_" . $p,
-            'value' => (int)$p,
-            'type' => PDO::PARAM_INT
+            'parameter' => ':severity_id_' . $p,
+            'value' => (int) $p,
+            'type' => PDO::PARAM_INT,
         ];
     }
     $severityIdCondition = 'cv2.value IN (' . $labels . ')';
     $query = CentreonUtils::conditionBuilder($query, $severityIdCondition);
 }
-if (!$centreon->user->admin) {
+if (! $centreon->user->admin) {
     $pearDB = $db;
     $aclObj = new CentreonACL($centreon->user->user_id, $centreon->user->admin);
     $query .= $aclObj->queryBuilder('AND', 'h.host_id', $aclObj->getHostsString('ID', $dbb));
 }
 
-// prepare order_by and limit of the query
-$query .= " ORDER BY :order_by LIMIT :limit OFFSET :offset";
+// prepare order_by
+$orderBy = 'h.name ASC';
 
-$orderBy = 'host_name ASC';
-if (isset($preferences['order_by']) && trim($preferences['order_by']) !== '') {
-    $orderBy = $preferences['order_by'];
-}
-$mainQueryParameters[] = [
-    'parameter' => "order_by",
-    'value' => $orderBy,
-    'type' => PDO::PARAM_STR
+// Define allowed columns and directions
+$allowedOrderColumns = [
+    'h.name',
+    'h.alias',
+    'criticality',
+    'address',
+    'state',
+    'output',
+    'check_attempt',
+    'last_check',
+    'last_state_change',
+    'last_hard_state_change',
+    'scheduled_downtime_depth',
+    'acknowledged',
+    'notify',
+    'active_checks',
+    'passive_checks',
 ];
 
+const ORDER_DIRECTION_ASC = 'ASC';
+const ORDER_DIRECTION_DESC = 'DESC';
+
+$allowedDirections = [ORDER_DIRECTION_ASC, ORDER_DIRECTION_DESC];
+$defaultDirection = ORDER_DIRECTION_ASC;
+
+$orderByToAnalyse = isset($preferences['order_by'])
+    ? trim($preferences['order_by'])
+    : null;
+
+if ($orderByToAnalyse !== null) {
+    $orderByToAnalyse .= " {$defaultDirection}";
+    [$column, $direction] = explode(' ', $orderByToAnalyse);
+
+    if (in_array($column, $allowedOrderColumns, true) && in_array($direction, $allowedDirections, true)) {
+        $orderBy = $column . ' ' . $direction;
+    }
+}
+
+// concatenate order by + limit + offset  to the query
+$query .= 'ORDER BY ' . $orderBy . ' LIMIT :limit OFFSET :offset';
+
 $num = filter_var($preferences['entries'], FILTER_VALIDATE_INT) ?: 10;
 $mainQueryParameters[] = [
-    'parameter' => "limit",
+    'parameter' => 'limit',
     'value' => $num,
-    'type' => PDO::PARAM_INT
+    'type' => PDO::PARAM_INT,
 ];
 $mainQueryParameters[] = [
-    'parameter' => "offset",
+    'parameter' => 'offset',
     'value' => ($page * $num),
-    'type' => PDO::PARAM_INT
+    'type' => PDO::PARAM_INT,
 ];
 
 try {
@@ -294,12 +311,12 @@ try {
         ['pdo_info' => $e->errorInfo, 'query_parameters' => $mainQueryParameters],
         $e
     );
+
     throw $e;
 }
 
 unset($mainQueryParameters);
 
-
 try {
     $nbRows = (int) $dbb->query('SELECT FOUND_ROWS() AS REALTIME')->fetchColumn();
 } catch (PDOException $e) {
@@ -309,6 +326,7 @@ try {
         ['pdo_info' => $e->errorInfo],
         $e
     );
+
     throw $e;
 }
 
@@ -325,6 +343,7 @@ try {
         ['pdo_info' => $e->errorInfo],
         $e
     );
+
     throw $e;
 }
 
@@ -340,7 +359,7 @@ while ($row = $res->fetch()) {
     }
 
     // last_check
-    $valueLastCheck = (int)$row['last_check'];
+    $valueLastCheck = (int) $row['last_check'];
     $valueLastCheckTimestamp = time() - $valueLastCheck;
     if (
         $valueLastCheckTimestamp > 0
@@ -351,7 +370,7 @@ while ($row = $res->fetch()) {
     $data[$row['host_id']]['last_check'] = $valueLastCheck;
 
     // last_state_change
-    $valueLastState = (int)$row['last_state_change'];
+    $valueLastState = (int) $row['last_state_change'];
     if ($valueLastState > 0) {
         $valueLastStateTimestamp = time() - $valueLastState;
         $valueLastState = CentreonDuration::toString($valueLastStateTimestamp) . ' ago';
@@ -361,7 +380,7 @@ while ($row = $res->fetch()) {
     $data[$row['host_id']]['last_state_change'] = $valueLastState;
 
     // last_hard_state_change
-    $valueLastHardState = (int)$row['last_hard_state_change'];
+    $valueLastHardState = (int) $row['last_hard_state_change'];
     if ($valueLastHardState > 0) {
         $valueLastHardStateTimestamp = time() - $valueLastHardState;
         $valueLastHardState = CentreonDuration::toString($valueLastHardStateTimestamp) . ' ago';
@@ -383,7 +402,6 @@ while ($row = $res->fetch()) {
     // output
     $data[$row['host_id']]['output'] = substr($row['output'], 0, $outputLength);
 
-
     $resourceController = $kernel->getContainer()->get(MonitoringResourceController::class);
     $data[$row['host_id']]['details_uri'] = $useDeprecatedPages
         ? '../../main.php?p=20202&o=hd&host_name=' . $row['host_name']
@@ -391,10 +409,10 @@ while ($row = $res->fetch()) {
 
     // action_url
     $valueActionUrl = $row['action_url'];
-    if (!empty($valueActionUrl)) {
+    if (! empty($valueActionUrl)) {
         if (preg_match('#^\./(.+)#', $valueActionUrl, $matches)) {
             $valueActionUrl = '../../' . $matches[1];
-        } elseif (!preg_match($allowedProtocolsRegex, $valueActionUrl)) {
+        } elseif (! preg_match($allowedProtocolsRegex, $valueActionUrl)) {
             $valueActionUrl = '//' . $valueActionUrl;
         }
 
@@ -406,10 +424,10 @@ while ($row = $res->fetch()) {
 
     // notes_url
     $valueNotesUrl = $row['notes_url'];
-    if (!empty($valueNotesUrl)) {
+    if (! empty($valueNotesUrl)) {
         if (preg_match('#^\./(.+)#', $valueNotesUrl, $matches)) {
             $valueNotesUrl = '../../' . $matches[1];
-        } elseif (!preg_match($allowedProtocolsRegex, $valueNotesUrl)) {
+        } elseif (! preg_match($allowedProtocolsRegex, $valueNotesUrl)) {
             $valueNotesUrl = '//' . $valueNotesUrl;
         }
 
@@ -423,18 +441,18 @@ while ($row = $res->fetch()) {
     // criticality
     $valueCriticality = $row['criticality'];
     if ($valueCriticality != '') {
-        $critData = $criticality->getData($row["criticality_id"]);
-        $valueCriticality = "<img src='../../img/media/" . $media->getFilename($critData['icon_id']) .
-            "' title='" . $critData["hc_name"] . "' width='16' height='16'>";
+        $critData = $criticality->getData($row['criticality_id']);
+        $valueCriticality = "<img src='../../img/media/" . $media->getFilename($critData['icon_id'])
+            . "' title='" . $critData['hc_name'] . "' width='16' height='16'>";
         $data[$row['host_id']]['criticality'] = $valueCriticality;
     }
 
     if (isset($preferences['display_last_comment']) && $preferences['display_last_comment']) {
         try {
-            $query = <<<SQL
-                SELECT data FROM comments where host_id = :hostId
-                AND service_id = 0 ORDER BY entry_time DESC LIMIT 1
-            SQL;
+            $query = <<<'SQL'
+                    SELECT data FROM comments where host_id = :hostId
+                    AND service_id = 0 ORDER BY entry_time DESC LIMIT 1
+                SQL;
             $res2 = $dbb->prepare($query);
             $res2->bindValue(':hostId', $row['host_id'], PDO::PARAM_INT);
             $res2->execute();
@@ -447,6 +465,7 @@ while ($row = $res->fetch()) {
                 ['pdo_info' => $e->errorInfo, 'host_id' => $row['host_id'] ?? null],
                 $e
             );
+
             throw $e;
         }
     }
@@ -470,11 +489,11 @@ $aColorHost = [
     0 => 'host_up',
     1 => 'host_down',
     2 => 'host_unreachable',
-    4 => 'host_pending'
+    4 => 'host_pending',
 ];
 
-$autoRefresh = (isset($preferences['refresh_interval']) && (int)$preferences['refresh_interval'] > 0)
-    ? (int)$preferences['refresh_interval']
+$autoRefresh = (isset($preferences['refresh_interval']) && (int) $preferences['refresh_interval'] > 0)
+    ? (int) $preferences['refresh_interval']
     : 30;
 $template->assign('widgetId', $widgetId);
 $template->assign('autoRefresh', $autoRefresh);
@@ -501,13 +520,14 @@ try {
     $template->display('table.ihtml');
 } catch (Exception $e) {
     $logger->error(
-        "Error while displaying the host monitoring custom view",
+        'Error while displaying the host monitoring custom view',
         [
             'file' => $e->getFile(),
             'line' => $e->getLine(),
             'exception_type' => $e::class,
-            'exception_message' => $e->getMessage()
+            'exception_message' => $e->getMessage(),
         ]
     );
+
     throw $e;
 }
