@@ -1,43 +1,29 @@
 <?php
 
 /*
- * Copyright 2005-2020 Centreon
- * Centreon is developed by : Julien Mathis and Romain Le Merlus under
- * GPL Licence 2.0.
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
- * This program is free software; you can redistribute it and/or modify it under
- * the terms of the GNU General Public License as published by the Free Software
- * Foundation ; either version 2 of the License.
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
- * This program is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
- * PARTICULAR PURPOSE. See the GNU General Public License for more details.
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
- * You should have received a copy of the GNU General Public License along with
- * this program; if not, see <http://www.gnu.org/licenses>.
- *
- * Linking this program statically or dynamically with other modules is making a
- * combined work based on this program. Thus, the terms and conditions of the GNU
- * General Public License cover the whole combination.
- *
- * As a special exception, the copyright holders of this program give Centreon
- * permission to link this program with independent modules to produce an executable,
- * regardless of the license terms of these independent modules, and to copy and
- * distribute the resulting executable under terms of Centreon choice, provided that
- * Centreon also meet, for each linked independent module, the terms  and conditions
- * of the license of that module. An independent module is a module which is not
- * derived from this program. If you modify this program, you may extend this
- * exception to your version of the program, but you are not obliged to do so. If you
- * do not wish to do so, delete this exception statement from your version.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  *
  * For more information : contact@centreon.com
  *
  */
 
-require_once "../../require.php";
+require_once '../../require.php';
 require_once $centreon_path . 'www/class/centreon.class.php';
 require_once $centreon_path . 'www/class/centreonSession.class.php';
 require_once $centreon_path . 'www/class/centreonDB.class.php';
+require_once $centreon_path . 'www/class/centreonACL.class.php';
 require_once $centreon_path . 'www/class/centreonHost.class.php';
 require_once $centreon_path . 'www/class/centreonService.class.php';
 require_once $centreon_path . 'www/class/centreonExternalCommand.class.php';
@@ -47,11 +33,11 @@ session_start();
 
 try {
     if (
-        !isset($_SESSION['centreon']) ||
-        !isset($_POST['cmdType']) ||
-        !isset($_POST['selection']) ||
-        !isset($_POST['author']) ||
-        !isset($_POST['cmd'])
+        ! isset($_SESSION['centreon'])
+        || ! isset($_POST['cmdType'])
+        || ! isset($_POST['selection'])
+        || ! isset($_POST['author'])
+        || ! isset($_POST['cmd'])
     ) {
         throw new Exception('Missing data');
     }
@@ -88,11 +74,11 @@ try {
         if (isset($_POST['notify'])) {
             $notify = 1;
         }
-        $command = "ACKNOWLEDGE_HOST_PROBLEM;%s;$sticky;$notify;$persistent;$author;$comment";
-        $commandSvc = "ACKNOWLEDGE_SVC_PROBLEM;%s;%s;$sticky;$notify;$persistent;$author;$comment";
+        $command = "ACKNOWLEDGE_HOST_PROBLEM;%s;{$sticky};{$notify};{$persistent};{$author};{$comment}";
+        $commandSvc = "ACKNOWLEDGE_SVC_PROBLEM;%s;%s;{$sticky};{$notify};{$persistent};{$author};{$comment}";
         if (isset($_POST['forcecheck'])) {
-            $forceCmd = "SCHEDULE_FORCED_HOST_CHECK;%s;" . time();
-            $forceCmdSvc = "SCHEDULE_FORCED_SVC_CHECK;%s;%s;" . time();
+            $forceCmd = 'SCHEDULE_FORCED_HOST_CHECK;%s;' . time();
+            $forceCmdSvc = 'SCHEDULE_FORCED_SVC_CHECK;%s;%s;' . time();
         }
     } elseif ($type === 'downtime') {
         $fixed = 0;
@@ -110,19 +96,19 @@ try {
             $duration += ($_POST['minuteduration'] * 60);
         }
 
-        if (!isset($_POST['start_time']) || !isset($_POST['end_time'])) {
+        if (! isset($_POST['start_time']) || ! isset($_POST['end_time'])) {
             throw new Exception('Missing downtime start/end');
         }
         [$tmpHstart, $tmpMstart] = array_map('trim', explode(':', $_POST['start_time']));
         [$tmpHend, $tmpMend] = array_map('trim', explode(':', $_POST['end_time']));
         $dateStart = $_POST['alternativeDateStart'];
-        $start = $dateStart . " " . $tmpHstart . ":" . $tmpMstart;
+        $start = $dateStart . ' ' . $tmpHstart . ':' . $tmpMstart;
         $start = CentreonUtils::getDateTimeTimestamp($start);
         $dateEnd = $_POST['alternativeDateEnd'];
-        $end = $dateEnd . " " . $tmpHend . ":" . $tmpMend;
+        $end = $dateEnd . ' ' . $tmpHend . ':' . $tmpMend;
         $end = CentreonUtils::getDateTimeTimestamp($end);
-        $command = "SCHEDULE_HOST_DOWNTIME;%s;$start;$end;$fixed;0;$duration;$author;$comment";
-        $commandSvc = "SCHEDULE_SVC_DOWNTIME;%s;%s;$start;$end;$fixed;0;$duration;$author;$comment";
+        $command = "SCHEDULE_HOST_DOWNTIME;%s;{$start};{$end};{$fixed};0;{$duration};{$author};{$comment}";
+        $commandSvc = "SCHEDULE_SVC_DOWNTIME;%s;%s;{$start};{$end};{$fixed};0;{$duration};{$author};{$comment}";
     } else {
         throw new Exception('Unknown command');
     }
@@ -132,7 +118,7 @@ try {
             $externalCommandMethod = 'setProcessCommand';
         }
         foreach ($selections as $selection) {
-            $tmp = explode(";", $selection);
+            $tmp = explode(';', $selection);
             if (count($tmp) != 2) {
                 throw new Exception('Incorrect id format');
             }
@@ -143,22 +129,22 @@ try {
                 $svcDesc = $svcObj->getServiceDesc($svcId);
                 $pollerId = $hostObj->getHostPollerId($hostId);
                 if ($cmd === 70 || $cmd === 74) {
-                    $externalCmd->$externalCommandMethod(sprintf($commandSvc, $hostname, $svcDesc), $pollerId);
+                    $externalCmd->{$externalCommandMethod}(sprintf($commandSvc, $hostname, $svcDesc), $pollerId);
                     if (isset($forceCmdSvc)) {
-                        $externalCmd->$externalCommandMethod(sprintf($forceCmdSvc, $hostname, $svcDesc), $pollerId);
+                        $externalCmd->{$externalCommandMethod}(sprintf($forceCmdSvc, $hostname, $svcDesc), $pollerId);
                     }
                 } else {
-                    $externalCmd->$externalCommandMethod(sprintf($command, $hostname), $pollerId);
+                    $externalCmd->{$externalCommandMethod}(sprintf($command, $hostname), $pollerId);
                 }
                 if (isset($forceCmd)) {
-                    $externalCmd->$externalCommandMethod(sprintf($forceCmd, $hostname), $pollerId);
+                    $externalCmd->{$externalCommandMethod}(sprintf($forceCmd, $hostname), $pollerId);
                 }
                 if (isset($_POST['processServices'])) {
                     $services = $svcObj->getServiceId(null, $hostname);
                     foreach ($services as $svcDesc => $svcId) {
-                        $externalCmd->$externalCommandMethod(sprintf($commandSvc, $hostname, $svcDesc), $pollerId);
+                        $externalCmd->{$externalCommandMethod}(sprintf($commandSvc, $hostname, $svcDesc), $pollerId);
                         if (isset($forceCmdSvc)) {
-                            $externalCmd->$externalCommandMethod(sprintf($forceCmdSvc, $hostname, $svcDesc), $pollerId);
+                            $externalCmd->{$externalCommandMethod}(sprintf($forceCmdSvc, $hostname, $svcDesc), $pollerId);
                         }
                     }
                 }
